@@ -10,12 +10,12 @@
 #ifndef FORECAST_H
 #define FORECAST_H
 
-#include <qmap.h>
-#include <qdatetime.h>
-#include <qvaluelist.h>
+#include <QtCore/QMap>
+#include <QtCore/QDateTime>
+#include <QtCore/QVector>
 
 /**
-	Zawiera list wartoci opisujacych pogod. Dozwolone wartoci:
+	Zawiera liste wartosci opisujacych pogode. Dozwolone wartosci:
 	"Name", "Icon", "Temperature", "Pressure", "Rain", "Snow", "Wind Speed", "Description"
 	"Humidity", "Dew point", "Visibility"
 **/
@@ -24,8 +24,8 @@ typedef QMap<QString, QString> ForecastDay;
 /**
 	\struct Forecast
 	Zawiera informacj o jednym dniu z prognozy pogody.
-	LocationName - nazwa miejscowoci
-	LocationID - kod miejscowoci
+	LocationName - nazwa miejscowosci
+	LocationID - kod miejscowosci
 	config - nazwa pliku konfiguracyjnego
 	loadTime - data pobrania prognozy
 	Days - poszczeglne dni prognozy
@@ -34,7 +34,7 @@ struct Forecast
 {
 	QString LocationName;
 	QString LocationID;
-	QValueList<ForecastDay> Days;
+	QVector<ForecastDay> Days;
 	QString config;
 	QString serverName;
 	QTime loadTime;
