@@ -5,6 +5,8 @@
 #include <qstring.h>
 #include <qpixmap.h>
 
+class QPainter;
+
 namespace MimeTeX
 {
 	/*!
@@ -30,7 +32,7 @@ namespace MimeTeX
 
 			public slots:
 				//! Cleans the view
-				void cleanView();
+				void cleanView(QPainter &p);
 
 			/*!
 			 * This slot calles the cleanView() automaticly before
@@ -38,7 +40,7 @@ namespace MimeTeX
 			 * before calling fillView()
 			 * \brief Fills the view with the proper GIF
 			 */
-			void fillView();
+			void fillView(QPainter &p);
 
 		protected:
 			/*!
