@@ -1,20 +1,21 @@
 #ifndef COLOR_BUTTON_H
 #define COLOR_BUTTON_H
 
-#include <qcolor.h>
-#include <qpushbutton.h>
+#include <QtGui/QPushButton>
+
+#include "exports.h"
 
 /**
     Kontrolka do wyboru koloru
 **/
-class ColorButton : public QPushButton
+class KADUAPI ColorButton : public QPushButton
 {
 	Q_OBJECT
 
 	QColor currentColor;
 
 public:
-	ColorButton(QWidget *parent = 0, const char * name = 0);
+	ColorButton(QWidget *parent = 0);
 	const QColor &color() const;
 	bool setColor(const QColor &color);
 
