@@ -7,11 +7,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qapplication.h>
-#include <qlistbox.h>
-#include <qobjectlist.h>
-#include <qscrollview.h>
-#include <qtabwidget.h>
+#include <QtGui/QApplication>
+#include <QtGui/QGroupBox>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QScrollArea>
+#include <QtGui/QDialogButtonBox>
 
 #include "config_file.h"
 #include "configuration_aware_object.h"
@@ -33,12 +33,12 @@ class ConfigTab
 
 	QMap<QString, ConfigGroupBox *> configGroupBoxes;
 
-	QScrollView *scrollView;
+	QScrollArea *scrollArea;
 	QVBoxLayout *mainLayout;
 	QWidget *mainWidget;
 
 public:
-	ConfigTab(const QString &name, ConfigSection *configSection, QTabWidget *parentConfigGroupBoxWidget);
+	ConfigTab(const QString &name, ConfigSection *configSection, QTabWidget *tabWidget);
 	~ConfigTab();
 
 	ConfigGroupBox * configGroupBox(const QString &name, bool create = true);
@@ -46,7 +46,7 @@ public:
 	void removedConfigGroupBox(const QString &groupBoxName);
 
 	QWidget *widget() { return mainWidget; }
-	QWidget *tabWidget() { return scrollView; }
+	QWidget *tabWidget() { return mainWidget; }
 
 };
 
@@ -54,7 +54,7 @@ ConfigGroupBox::ConfigGroupBox(const QString &name, ConfigTab *configTab, QGroup
 	: name(name), configTab(configTab), groupBox(groupBox)
 {
 	container = new QWidget(groupBox);
-
+	groupBox->layout()->addWidget(container);
 	gridLayout = new QGridLayout(container);
 	gridLayout->setAutoAdd(false);
 	gridLayout->setSpacing(5);
@@ -70,7 +70,7 @@ ConfigGroupBox::~ConfigGroupBox()
 
 bool ConfigGroupBox::empty()
 {
-	return container->children()->count() == 1;
+	return container->children().count() == 1;
 }
 
 void ConfigGroupBox::addWidget(QWidget *widget, bool fullSpace)
@@ -94,27 +94,50 @@ void ConfigGroupBox::addWidgets(QWidget *widget1, QWidget *widget2)
 		gridLayout->addWidget(widget2, numRows, 1);
 }
 
-ConfigTab::ConfigTab(const QString &name, ConfigSection *configSection, QTabWidget *parentConfigGroupBoxWidget)
+class KaduScrollArea : public QScrollArea
+{
+public:
+	KaduScrollArea(QWidget *parent)
+		: QScrollArea(parent)
+	{
+	}
+
+	QSize sizeHint() const
+	{
+	    int f = 2 * frameWidth();
+		QSize sz(f, f);
+		sz += widget()->sizeHint();
+
+		if (verticalScrollBarPolicy() == Qt::ScrollBarAlwaysOn)
+			sz.setWidth(sz.width() + verticalScrollBar()->sizeHint().width());
+		if (horizontalScrollBarPolicy() == Qt::ScrollBarAlwaysOn)
+			sz.setHeight(sz.height() + horizontalScrollBar()->sizeHint().height());
+
+		return sz;
+	}
+};
+
+ConfigTab::ConfigTab(const QString &name, ConfigSection *configSection, QTabWidget *tabWidget)
 	: name(name), configSection(configSection)
 {
-	scrollView = new QScrollView(parentConfigGroupBoxWidget);
-	scrollView->setFrameStyle(QFrame::NoFrame);
-	scrollView->setResizePolicy(QScrollView::AutoOneFit);
-	scrollView->setVScrollBarMode(QScrollView::Auto);
-	scrollView->setHScrollBarMode(QScrollView::AlwaysOff);
+	scrollArea = new KaduScrollArea(tabWidget);
+	scrollArea->setFrameStyle(QFrame::NoFrame);
+	scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+	scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+	scrollArea->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
 
-	mainWidget = new QWidget(scrollView->viewport());
-	scrollView->addChild(mainWidget);
-
-	mainLayout = new QVBoxLayout(mainWidget, 10, 10);
+	mainWidget = new QWidget(tabWidget);
+	mainLayout = new QVBoxLayout(mainWidget);
 	mainLayout->addStretch(1);
 
-	parentConfigGroupBoxWidget->addTab(scrollView, name);
+	tabWidget->addTab(scrollArea, name);
+	scrollArea->setWidget(mainWidget);
+	scrollArea->setWidgetResizable(true);
 }
 
 ConfigTab::~ConfigTab()
 {
-	delete scrollView;
+	delete scrollArea;
 }
 
 ConfigGroupBox *ConfigTab::configGroupBox(const QString &name, bool create)
@@ -125,9 +148,10 @@ ConfigGroupBox *ConfigTab::configGroupBox(const QString &name, bool create)
 	if (!create)
 		return 0;
 
-	QGroupBox *groupBox = new QGroupBox(1, Qt::Horizontal, name, mainWidget);
+	QGroupBox *groupBox = new QGroupBox(name, mainWidget);
 	groupBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-
+	new QHBoxLayout(groupBox);
+	
 	mainLayout->insertWidget(configGroupBoxes.count(), groupBox);
 
 	ConfigGroupBox *newConfigGroupBox = new ConfigGroupBox(name, this, groupBox);
@@ -149,11 +173,12 @@ void ConfigTab::removedConfigGroupBox(const QString &groupBoxName)
 	}
 }
 
-ConfigSection::ConfigSection(const QString &name, ConfigurationWindow *configurationWindow, QListBoxItem *listBoxItem, QWidget *parentConfigGroupBoxWidget,
+ConfigSection::ConfigSection(const QString &name, ConfigurationWindow *configurationWindow, QListWidgetItem *listWidgetItem, QWidget *parentConfigGroupBoxWidget,
 		const QString &pixmap)
-	: name(name), configurationWindow(configurationWindow), pixmap(pixmap), listBoxItem(listBoxItem), activated(false)
+	: name(name), configurationWindow(configurationWindow), pixmap(pixmap), listWidgetItem(listWidgetItem), activated(false)
 {
 	mainWidget = new QTabWidget(parentConfigGroupBoxWidget);
+	parentConfigGroupBoxWidget->layout()->addWidget(mainWidget);
 	mainWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	mainWidget->hide();
 
@@ -178,7 +203,7 @@ ConfigGroupBox * ConfigSection::configGroupBox(const QString &tab, const QString
 
 void ConfigSection::activate()
 {
-	listBoxItem->listBox()->setCurrentItem(listBoxItem);
+	listWidgetItem->listWidget()->setCurrentItem(listWidgetItem);
 
 	if (activated)
 		return;
@@ -217,57 +242,70 @@ void ConfigSection::removedConfigTab(const QString &configTabName)
 
 void ConfigSection::iconThemeChanged()
 {
-	QListBox *listBox = listBoxItem->listBox();
-	bool current = listBoxItem->isSelected();
-	delete listBoxItem;
+	QListWidget *listWidget = listWidgetItem->listWidget();
+	bool current = listWidgetItem->isSelected();
+	delete listWidgetItem;
 
-	listBoxItem = new QListBoxPixmap(listBox, icons_manager->loadIcon(pixmap), name);
+	listWidgetItem = new QListWidgetItem(icons_manager->loadPixmap(pixmap), name, listWidget);
 	if (current)
-		listBox->setCurrentItem(listBoxItem);
+		listWidget->setCurrentItem(listWidgetItem);
 }
 
 ConfigurationWindow::ConfigurationWindow(const QString &name, const QString &caption)
-	: QVBox(0, "configuration_window:" + name), Name(name), currentSection(0)
+	: QWidget(kadu, Qt::Window), Name(name), currentSection(0)
 {
-	setWFlags(getWFlags() | Qt::WDestructiveClose);
-	setCaption(caption);
+	setAttribute(Qt::WA_DeleteOnClose);
+	setWindowTitle(caption);
 
-	QHBox *center = new QHBox(this);
-	center->setMargin(10);
-	center->setSpacing(10);
+	QVBoxLayout *main_layout = new QVBoxLayout(this);
 
-	left = new QVBox(center);
+	QWidget *center = new QWidget();
+	QHBoxLayout *center_layout = new QHBoxLayout(center);
+	center_layout->setMargin(0);
+	center_layout->setSpacing(0);
+
+	left = new QWidget();
 	left->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
 	left->hide();
+	QVBoxLayout *left_layout = new QVBoxLayout(left);
+	left_layout->setMargin(0);
+	left_layout->setSpacing(0);
 
-	container = new QHBox(center);
-	container->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+	container = new QWidget;
+	QHBoxLayout *container_layout = new QHBoxLayout(container);
+	Q_UNUSED(container_layout)
 
-	QHBox *buttons = new QHBox(this);
-	buttons->setMargin(10);
-	buttons->setSpacing(5);
-	(new QWidget(buttons))->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
+	QDialogButtonBox *buttons_layout = new QDialogButtonBox(Qt::Horizontal, this);
 
-	QPushButton *okButton = new QPushButton(icons_manager->loadIcon("OkWindowButton"), tr("Ok"), buttons);
-	QPushButton *applyButton = new QPushButton(icons_manager->loadIcon("ApplyWindowButton"), tr("Apply"), buttons);
-	QPushButton *cancelButton = new QPushButton(icons_manager->loadIcon("CloseWindowButton"), tr("Cancel"), buttons);
+	QPushButton *okButton = new QPushButton(icons_manager->loadIcon("OkWindowButton"), tr("Ok"), this);
+	buttons_layout->addButton(okButton, QDialogButtonBox::AcceptRole);
+	QPushButton *applyButton = new QPushButton(icons_manager->loadIcon("ApplyWindowButton"), tr("Apply"), this);
+	buttons_layout->addButton(applyButton, QDialogButtonBox::ApplyRole);
+	QPushButton *cancelButton = new QPushButton(icons_manager->loadIcon("CloseWindowButton"), tr("Cancel"), this);
+	buttons_layout->addButton(cancelButton, QDialogButtonBox::RejectRole);
 
 	connect(okButton, SIGNAL(clicked()), this, SLOT(updateAndCloseConfig()));
 	connect(applyButton, SIGNAL(clicked()), this, SLOT(updateConfig()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(close()));
 
-	sectionsListBox = new QListBox(left);
-	sectionsListBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-	sectionsListBox->setHScrollBarMode(QScrollView::AlwaysOff);
-	connect(sectionsListBox, SIGNAL(highlighted(const QString &)), this, SLOT(changeSection(const QString &)));
+	sectionsListWidget = new QListWidget(this);
+	sectionsListWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
+ 	sectionsListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+	sectionsListWidget->setIconSize(QSize(32, 32));
+	connect(sectionsListWidget, SIGNAL(currentTextChanged(const QString &)), this, SLOT(changeSection(const QString &)));
+	left_layout->addWidget(sectionsListWidget);
+
+	main_layout->addWidget(center);
+	main_layout->addWidget(buttons_layout);
+	center_layout->addWidget(left);
+	center_layout->addWidget(container);
 }
 
 ConfigurationWindow::~ConfigurationWindow()
 {
-	config_file.writeEntry("General", "ConfigurationWindow_" + Name, sectionsListBox->currentText());
-
-	FOREACH(configSection, configSections)
-		delete *configSection;
+	if (sectionsListWidget->currentItem())
+		config_file.writeEntry("General", "ConfigurationWindow_" + Name, sectionsListWidget->currentItem()->text());
+	qDeleteAll(configSections);
 }
 
 void ConfigurationWindow::show()
@@ -278,10 +316,10 @@ void ConfigurationWindow::show()
 		if (configSections.contains(lastSection))
 			configSections[lastSection]->activate();
 		else
-			sectionsListBox->setCurrentItem(0);
+			sectionsListWidget->setCurrentItem(0);
 
 		loadConfiguration(this);
-		QVBox::show();
+		QWidget::show();
 	}
 	else
 	{
@@ -290,14 +328,16 @@ void ConfigurationWindow::show()
 	}
 }
 
-QValueList<ConfigWidget *> ConfigurationWindow::appendUiFile(const QString &fileName, bool load)
+QList<ConfigWidget *> ConfigurationWindow::appendUiFile(const QString &fileName, bool load)
 {
-	QValueList<ConfigWidget *> widgets = processUiFile(fileName);
+	QList<ConfigWidget *> widgets = processUiFile(fileName);
 
 	if (load)
-		FOREACH(widget, widgets)
-			if (*widget)
-				(*widget)->loadConfiguration();
+		foreach(ConfigWidget *widget, widgets)
+			if (widget)
+				widget->loadConfiguration();
+
+	changeSection(*configSections.keys().begin());
 
 	return widgets;
 }
@@ -307,15 +347,15 @@ void ConfigurationWindow::removeUiFile(const QString &fileName)
 	processUiFile(fileName, false);
 }
 
-QValueList<ConfigWidget *>  ConfigurationWindow::processUiFile(const QString &fileName, bool append)
+QList<ConfigWidget *>  ConfigurationWindow::processUiFile(const QString &fileName, bool append)
 {
 	kdebugf();
 
-	QValueList<ConfigWidget *> result;
+	QList<ConfigWidget *> result;
 	QFile file(fileName);
 
 	QDomDocument uiFile;
-	file.open(IO_ReadOnly);
+	file.open(QIODevice::ReadOnly);
 
 	if (!uiFile.setContent(&file))
 	{
@@ -342,11 +382,11 @@ QValueList<ConfigWidget *>  ConfigurationWindow::processUiFile(const QString &fi
 	return result;
 }
 
-QValueList<ConfigWidget *> ConfigurationWindow::processUiSectionFromDom(QDomNode sectionNode, bool append)
+QList<ConfigWidget *> ConfigurationWindow::processUiSectionFromDom(QDomNode sectionNode, bool append)
 {
 	kdebugf();
 
-	QValueList<ConfigWidget *> result;
+	QList<ConfigWidget *> result;
 	if (!sectionNode.isElement())
 	{
 		kdebugf2();
@@ -369,7 +409,7 @@ QValueList<ConfigWidget *> ConfigurationWindow::processUiSectionFromDom(QDomNode
 		return result;
 	}
 
-	configSection(iconName, qApp->translate("@default", sectionName), append);
+	configSection(iconName, qApp->translate("@default", sectionName), true);
 
 	const QDomNodeList children = sectionElement.childNodes();
 	int length = children.length();
@@ -380,12 +420,12 @@ QValueList<ConfigWidget *> ConfigurationWindow::processUiSectionFromDom(QDomNode
 	return result;
 }
 
-QValueList<ConfigWidget *> ConfigurationWindow::processUiTabFromDom(QDomNode tabNode, const QString &iconName,
+QList<ConfigWidget *> ConfigurationWindow::processUiTabFromDom(QDomNode tabNode, const QString &iconName,
 	const QString &sectionName, bool append)
 {
 	kdebugf();
 
-	QValueList<ConfigWidget *> result;
+	QList<ConfigWidget *> result;
 	if (!tabNode.isElement())
 	{
 		kdebugf2();
@@ -415,11 +455,11 @@ QValueList<ConfigWidget *> ConfigurationWindow::processUiTabFromDom(QDomNode tab
 	return result;
 }
 
-QValueList<ConfigWidget *> ConfigurationWindow::processUiGroupBoxFromDom(QDomNode groupBoxNode, const QString &sectionName, const QString &tabName, bool append)
+QList<ConfigWidget *> ConfigurationWindow::processUiGroupBoxFromDom(QDomNode groupBoxNode, const QString &sectionName, const QString &tabName, bool append)
 {
 	kdebugf();
 
-	QValueList<ConfigWidget *> result;
+	QList<ConfigWidget *> result;
 	if (!groupBoxNode.isElement())
 	{
 		kdebugf2();
@@ -509,7 +549,7 @@ ConfigWidget * ConfigurationWindow::appendUiElementFromDom(QDomNode uiElementNod
 	else if (tagName == "label")
 		widget = new ConfigLabel(configGroupBox);
 	else if (tagName == "list-box")
-		widget = new ConfigListBox(configGroupBox);
+		widget = new ConfigListWidget(configGroupBox);
 	else
 	{
 		kdebugf2();
@@ -546,9 +586,9 @@ void ConfigurationWindow::removeUiElementFromDom(QDomNode uiElementNode, ConfigG
 	const QDomElement &uiElement = uiElementNode.toElement();
 	const QString &caption = uiElement.attribute("caption");
 
-	FOREACH(child, *configGroupBox->widget()->children())
+	foreach(QObject *child, configGroupBox->widget()->children())
 	{
-		ConfigWidget *configWidget = dynamic_cast<ConfigWidget *>(*child);
+		ConfigWidget *configWidget = dynamic_cast<ConfigWidget *>(child);
 		if (!configWidget)
 			continue;
 
@@ -595,13 +635,24 @@ ConfigSection *ConfigurationWindow::configSection(const QString &pixmap, const Q
 	if (!create)
 		return 0;
 
-	QListBoxItem *newConfigSectionListBoxItem = new QListBoxPixmap(sectionsListBox, icons_manager->loadIcon(pixmap), name);
+	QListWidgetItem *newConfigSectionListWidgetItem = new QListWidgetItem(icons_manager->loadPixmap(pixmap), name, sectionsListWidget);
 
-	ConfigSection *newConfigSection = new ConfigSection(name, this, newConfigSectionListBoxItem, container, pixmap);
+	QFontMetrics fontMetrics = sectionsListWidget->fontMetrics();
+	// TODO: 48 = margins + scrollbar - get real scrollbar width
+	int width = fontMetrics.width(name) + icons_manager->loadPixmap(pixmap).width() + 48;
+
+	ConfigSection *newConfigSection = new ConfigSection(name, this, newConfigSectionListWidgetItem, container, pixmap);
 	configSections[name] = newConfigSection;
 
+	if (configSections.count() == 1)
+		sectionsListWidget->setFixedWidth(width);
+
 	if (configSections.count() > 1)
+	{
+		if (sectionsListWidget->width() < width)
+			sectionsListWidget->setFixedWidth(width);
 		left->show();
+	}
 
 	return newConfigSection;
 }
@@ -613,10 +664,9 @@ void ConfigurationWindow::loadConfiguration(QObject *object)
 	if (!object)
 		return;
 
-	const QObjectList *children = object->children();
-	if (children)
-		FOREACH(child, *children)
-			loadConfiguration(*child);
+	const QObjectList children = object->children();
+	foreach(QObject *child, children)
+		loadConfiguration(child);
 
 	ConfigWidget *configWidget = dynamic_cast<ConfigWidget *>(object);
 	if (configWidget)
@@ -630,10 +680,9 @@ void ConfigurationWindow::saveConfiguration(QObject *object)
 	if (!object)
 		return;
 
-	const QObjectList *children = object->children();
-	if (children)
-		FOREACH(child, *children)
-			saveConfiguration(*child);
+	const QObjectList children = object->children();
+	foreach(QObject *child, children)
+		saveConfiguration(child);
 
 	ConfigWidget *configWidget = dynamic_cast<ConfigWidget *>(object);
 	if (configWidget)
@@ -675,23 +724,24 @@ void ConfigurationWindow::removedConfigSection(const QString &sectionName)
 {
 	configSections.remove(sectionName);
 
-	for (unsigned int i = 0; i < sectionsListBox->count(); i++)
-		if (sectionsListBox->item(i)->text() == tr(sectionName))
+	for (unsigned int i = 0; i < sectionsListWidget->count(); i++)
+		if (sectionsListWidget->item(i)->text() == tr(sectionName))
 		{
-			sectionsListBox->removeItem(i);
+			QListWidgetItem *item = sectionsListWidget->takeItem(i);
+			delete item;
 			break;
 		}
 }
 
 void ConfigurationWindow::keyPressEvent(QKeyEvent *e)
 {
-	if (e->key() == Key_Escape)
+	if (e->key() == Qt::Key_Escape)
 	{
 		e->accept();
 		close();
 	}
 	else
-		QVBox::keyPressEvent(e);
+		QWidget::keyPressEvent(e);
 }
 
 #ifdef HAVE_OPENSSL
