@@ -7,116 +7,139 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdlib.h>
-
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qsimplerichtext.h>
-#include <qtimer.h>
-#include <qvbox.h>
-#include <qvgroupbox.h>
+#include <QtCore/QAbstractTableModel>
+#include <QtCore/QTimer>
+#include <QtGui/QFileDialog>
+#include <QtGui/QGroupBox>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QListView>
+#include <QtGui/QPushButton>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QVBoxLayout>
 
 #include "debug.h"
-#include "expimp.h"
 #include "gadu.h"
 #include "icons_manager.h"
 #include "ignore.h"
-#include "kadu.h"
 #include "message_box.h"
 #include "misc.h"
-#include "userlist.h"
 
-void UserlistImportExport::resizeEvent(QResizeEvent * /*e*/)
-{
-	layoutHelper->resizeLabels();
-}
+#include "expimp.h"
 
-UserlistImportExport::UserlistImportExport(QWidget *parent, const char *name) :
-	QHBox(parent, name, WType_TopLevel | WDestructiveClose),
-	pb_fetch(0), importedUserlist(), pb_send(0), pb_delete(0), pb_tofile(0),
-	l_itemscount(0), layoutHelper(new LayoutHelper()), lv_userlist(0)
+UserlistImportExport::UserlistImportExport(QWidget *parent)
+	: QWidget(parent, Qt::Window), pb_fetch(0), importedUserlist(), pb_send(0), pb_delete(0), pb_tofile(0), l_itemscount(0), lv_userlist(0)
 {
 	kdebugf();
-	setCaption(tr("Import / export userlist"));
-	layout()->setResizeMode(QLayout::Minimum);
+	setWindowTitle(tr("Import / export userlist"));
+	setAttribute(Qt::WA_DeleteOnClose);
 
 	// create main QLabel widgets (icon and app info)
-	QVBox *left = new QVBox(this);
-	left->setMargin(10);
-	left->setSpacing(10);
+	QWidget *left = new QWidget;
 
-	QLabel *l_icon = new QLabel(left);
-	QWidget *w_blank = new QWidget(left);
-	w_blank->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Expanding));
+	QLabel *l_icon = new QLabel;
+	l_icon->setPixmap(icons_manager->loadPixmap("ImportExportWindowIcon"));
 
-	QVBox *center = new QVBox(this);
-	center->setMargin(10);
-	center->setSpacing(10);
+	QVBoxLayout *left_layout = new QVBoxLayout;
+	left_layout->addWidget(l_icon);
+	left_layout->addStretch();
 
-	QLabel *l_info = new QLabel(center);
-	l_icon->setPixmap(icons_manager->loadIcon("ImportExportWindowIcon"));
+	left->setLayout(left_layout);
+
+	QWidget *center = new QWidget;
+	QVBoxLayout *center_layout = new QVBoxLayout;
+	center_layout->setSpacing(5);
+	QLabel *l_info = new QLabel;
 	l_info->setText(tr("This dialog box allows you to import and export your buddy list to a server or a file."));
-	l_info->setAlignment(Qt::WordBreak);
+	l_info->setWordWrap(true);
+#ifndef Q_OS_MAC
+	l_info->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+#endif
 	// end create main QLabel widgets (icon and app info)
 
 	// our QListView
-	// our QVGroupBox
-	QVGroupBox *vgb_import = new QVGroupBox(center);
-	vgb_import->setTitle(tr("Import userlist"));
+	// our QGroupBox
+	QGroupBox *gb_import = new QGroupBox;
+	QVBoxLayout *import_layout = new QVBoxLayout;
+	import_layout->setSpacing(5);
+	gb_import->setTitle(tr("Import userlist"));
 	// end our QGroupBox
-	lv_userlist = new QListView(vgb_import);
-	lv_userlist->addColumn(tr("UIN"));
-	lv_userlist->addColumn(tr("Nickname"));
-	lv_userlist->addColumn(tr("Disp. nick"));
-	lv_userlist->addColumn(tr("Name"));
-	lv_userlist->addColumn(tr("Surname"));
-	lv_userlist->addColumn(tr("Mobile no."));
-	lv_userlist->addColumn(tr("Group"));
-	lv_userlist->addColumn(tr("Email"));
+	lv_userlist = new QTreeWidget(this);
+
+	QStringList headers;
+	headers << tr("UIN") << tr("Nickname") << tr("Disp. nick") << tr("Name") << tr("Surname") << tr("Mobile no.") << tr("Group") << tr("Email");
+	lv_userlist->setHeaderLabels(headers);
 	lv_userlist->setAllColumnsShowFocus(true);
+	lv_userlist->setIndentation(false);
 	// end our QListView
 
 	// buttons
-	QHBox *hb_importbuttons = new QHBox(vgb_import);
-	QWidget *w_blank2 = new QWidget(hb_importbuttons);
-	hb_importbuttons->setSpacing(5);
-	w_blank2->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
+	QWidget *importbuttons = new QWidget(this);
+	QHBoxLayout *importbuttons_layout = new QHBoxLayout(importbuttons);
+	importbuttons_layout->setSpacing(5);
 
-	pb_fetch = new QPushButton(icons_manager->loadIconSet("FetchUserList"), tr("&Fetch userlist"), hb_importbuttons, "fetch");
-	QPushButton *pb_file = new QPushButton(icons_manager->loadIcon("ImportFromFile"), tr("&Import from file"), hb_importbuttons, "file");
-	QPushButton *pb_save = new QPushButton(icons_manager->loadIcon("SaveUserlist"), tr("&Save results"), hb_importbuttons, "save");
-	QPushButton *pb_merge = new QPushButton(icons_manager->loadIcon("MergeUserlist"), tr("&Merge results"), hb_importbuttons, "merge");
+	pb_fetch = new QPushButton(icons_manager->loadIcon("FetchUserList"), tr("&Fetch userlist"), this, "fetch");
+	QPushButton *pb_file = new QPushButton(icons_manager->loadIcon("ImportFromFile"), tr("&Import from file"), this, "file");
+	QPushButton *pb_save = new QPushButton(icons_manager->loadIcon("SaveUserlist"), tr("&Save results"), this, "save");
+	QPushButton *pb_merge = new QPushButton(icons_manager->loadIcon("MergeUserlist"), tr("&Merge results"), this, "merge");
 	// end buttons
+	
+	importbuttons_layout->addStretch();
+	importbuttons_layout->addWidget(pb_fetch);
+	importbuttons_layout->addWidget(pb_file);
+	importbuttons_layout->addWidget(pb_save);
+	importbuttons_layout->addWidget(pb_merge);
+	importbuttons->setLayout(importbuttons_layout);
+	
+	import_layout->addWidget(lv_userlist);
+	import_layout->addWidget(importbuttons);
+	gb_import->setLayout(import_layout);
 
-	// our QVGroupBox
-	QVGroupBox *vgb_export = new QVGroupBox(center);
-	vgb_export->setTitle(tr("Export userlist"));
+	// our QGroupBox
+	QGroupBox *gb_export = new QGroupBox;
+	QVBoxLayout *export_layout = new QVBoxLayout;
+	export_layout->setSpacing(5);
+	gb_export->setTitle(tr("Export userlist"));
 	// end our QGroupBox
 
-	l_itemscount = new QLabel(vgb_export);
+	l_itemscount = new QLabel;
 	updateUserListCount();
 
 	// export buttons
-	QHBox *hb_exportbuttons = new QHBox(vgb_export);
-	QWidget *w_blank3 = new QWidget(hb_exportbuttons);
-	hb_exportbuttons->setSpacing(5);
+	QWidget *exportbuttons = new QWidget;
+	QHBoxLayout *exportbuttons_layout = new QHBoxLayout;
+	exportbuttons_layout->setSpacing(5);
+	QWidget *w_blank3 = new QWidget;
 	w_blank3->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
 
-	pb_send = new QPushButton(icons_manager->loadIconSet("SendUserlist"),tr("Se&nd userlist"), hb_exportbuttons, "send");
-	pb_delete = new QPushButton(icons_manager->loadIconSet("DeleteUserlist"),tr("&Delete userlist"), hb_exportbuttons, "delete");
-	pb_tofile = new QPushButton(icons_manager->loadIconSet("ExportUserlist"),tr("&Export to file"), hb_exportbuttons, "tofile");
+	pb_send = new QPushButton(icons_manager->loadIcon("SendUserlist"), tr("Se&nd userlist"), this, "send");
+	pb_delete = new QPushButton(icons_manager->loadIcon("DeleteUserlist"), tr("&Delete userlist"), this, "delete");
+	pb_tofile = new QPushButton(icons_manager->loadIcon("ExportUserlist"), tr("&Export to file"), this, "tofile");
 	// end export buttons
 
+	exportbuttons_layout->addWidget(w_blank3);
+	exportbuttons_layout->addWidget(pb_send);
+	exportbuttons_layout->addWidget(pb_delete);
+	exportbuttons_layout->addWidget(pb_tofile);
+	exportbuttons->setLayout(exportbuttons_layout);
+	
+	export_layout->addWidget(l_itemscount);
+	export_layout->addWidget(exportbuttons);
+	gb_export->setLayout(export_layout);
+
 	// buttons
-	QHBox *bottom = new QHBox(center);
-	QWidget *w_blank4 = new QWidget(bottom);
-	bottom->setSpacing(5);
+	QWidget *bottom = new QWidget;
+	QHBoxLayout *bottom_layout = new QHBoxLayout;
+	bottom_layout->setSpacing(5);
+	QWidget *w_blank4 = new QWidget;
 	w_blank4->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
 
-	QPushButton *pb_close = new QPushButton(icons_manager->loadIcon("CloseWindow"), tr("&Close"), bottom, "close");
+	QPushButton *pb_close = new QPushButton(icons_manager->loadIcon("CloseWindow"), tr("&Close"), this, "close");
 	// end buttons
+	bottom_layout->addWidget(w_blank4);
+	bottom_layout->addWidget(pb_close);
+	bottom->setLayout(bottom_layout);
 
 	// connect
 	connect(pb_close, SIGNAL(clicked()), this, SLOT(close()));
@@ -130,21 +153,36 @@ UserlistImportExport::UserlistImportExport(QWidget *parent, const char *name) :
 
 	connect(gadu, SIGNAL(userListExported(bool)), this, SLOT(userListExported(bool)));
 	connect(gadu, SIGNAL(userListCleared(bool)), this, SLOT(userListCleared(bool)));
-	connect(gadu, SIGNAL(userListImported(bool, QValueList<UserListElement>)), this, SLOT(userListImported(bool, QValueList<UserListElement>)));
-
-	connect(kadu, SIGNAL(statusPixmapChanged(const QPixmap &, const QString &)), this, SLOT(refreshIcon(const QPixmap &)));
+	connect(gadu, SIGNAL(userListImported(bool, QList<UserListElement>)), this, SLOT(userListImported(bool, QList<UserListElement>)));
 	// end connect
 
-	layoutHelper->addLabel(l_info);
- 	loadGeometry(this, "General", "ImportExportDialogGeometry", 0, 30, 640, 450);
+	center_layout->addWidget(l_info);
+	center_layout->addWidget(gb_import);
+	center_layout->addWidget(gb_export);
+	center_layout->addWidget(bottom);
+	center->setLayout(center_layout);
+
+	QWidget *sub = new QWidget;
+	QHBoxLayout *sub_layout = new QHBoxLayout;
+	sub_layout->addWidget(left);
+	sub_layout->addWidget(center);
+	sub->setLayout(sub_layout);
+
+	QVBoxLayout *layout = new QVBoxLayout;
+	layout->addWidget(sub);
+	layout->addWidget(bottom);
+
+	setLayout(layout);
+
+ 	loadWindowGeometry(this, "General", "ImportExportDialogGeometry", 0, 50, 640, 450);
 	kdebugf2();
 }
 
 void UserlistImportExport::updateUserListCount()
 {
 	int realUserCount = 0;
-	CONST_FOREACH(user, *userlist)
-		if (!(*user).isAnonymous())
+	foreach(const UserListElement &user, *userlist)
+		if (!user.isAnonymous())
 			++realUserCount;
 	l_itemscount->setText(tr("%1 entries will be exported").arg(realUserCount));
 }
@@ -152,8 +190,7 @@ void UserlistImportExport::updateUserListCount()
 UserlistImportExport::~UserlistImportExport()
 {
 	kdebugf();
-	saveGeometry(this, "General", "ImportExportDialogGeometry");
-	delete layoutHelper;
+ 	saveWindowGeometry(this, "General", "ImportExportDialogGeometry");
 	kdebugf2();
 }
 
@@ -163,11 +200,6 @@ void UserlistImportExport::keyPressEvent(QKeyEvent *ke_event)
 		close();
 }
 
-void UserlistImportExport::refreshIcon(const QPixmap &pix)
-{
-	setIcon(pix);
-}
-
 void UserlistImportExport::fromfile()
 {
 	kdebugf();
@@ -175,22 +207,22 @@ void UserlistImportExport::fromfile()
 	if (!fname.isEmpty())
 	{
 		QFile file(fname);
- 		if (file.open(IO_ReadOnly))
+ 		if (file.open(QIODevice::ReadOnly))
 		{
 			QTextStream stream(&file);
 			importedUserlist = gadu->streamToUserList(stream);
 			file.close();
 
-			CONST_FOREACH(i, importedUserlist)
+			foreach(const UserListElement &user, importedUserlist)
 			{
 				QString id;
-				if ((*i).usesProtocol("Gadu"))
-					id = (*i).ID("Gadu");
-				new QListViewItem(lv_userlist, id,
-					(*i).nickName(),  (*i).altNick(),
-					(*i).firstName(), (*i).lastName(),
-					(*i).mobile(),    (*i).data("Groups").toStringList().join(","),
-					(*i).email());
+				if (user.usesProtocol("Gadu"))
+					id = user.ID("Gadu");
+
+				QStringList values;
+				values << id << user.nickName() << user.altNick() << user.firstName() << user.lastName() << user.mobile() <<
+					user.data("Groups").toStringList().join(",") << user.email();
+				new QTreeWidgetItem(lv_userlist, values);
 			}
 		}
 		else
@@ -238,7 +270,7 @@ void UserlistImportExport::updateUserlist()
 	kdebugf2();
 }
 
-void UserlistImportExport::userListImported(bool ok, QValueList<UserListElement> userList)
+void UserlistImportExport::userListImported(bool ok, QList<UserListElement> userList)
 {
 	kdebugf();
 
@@ -248,14 +280,16 @@ void UserlistImportExport::userListImported(bool ok, QValueList<UserListElement>
 	pb_fetch->setEnabled(true);
 
 	if (ok)
-		CONST_FOREACH(user, userList)
+		foreach(const UserListElement &user, userList)
 		{
 			QString id;
-			if ((*user).usesProtocol("Gadu"))
-				id = (*user).ID("Gadu");
-			new QListViewItem(lv_userlist, id, (*user).nickName(),
-				(*user).altNick(), (*user).firstName(), (*user).lastName(), (*user).mobile(),
-				(*user).data("Groups").toStringList().join(","), (*user).email());
+			if (user.usesProtocol("Gadu"))
+				id = user.ID("Gadu");
+
+			QStringList values;
+			values << id << user.nickName() << user.altNick() << user.firstName() << user.lastName() << user.mobile() <<
+				user.data("Groups").toStringList().join(",") << user.email();
+			new QTreeWidgetItem(lv_userlist, values);
 		}
 	kdebugf2();
 }
@@ -293,7 +327,7 @@ void UserlistImportExport::ExportToFile(void)
 		QFile file(fname);
 		if ((!file.exists()) || (MessageBox::ask(tr("File exists. Are you sure you want to overwrite it?"), QString::null, this)))
 		{
-			if (file.open(IO_WriteOnly))
+			if (file.open(QIODevice::WriteOnly))
 			{
 				QTextStream stream(&file);
 				stream.setCodec(codec_latin2);
