@@ -7,20 +7,25 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qapplication.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qlistview.h>
-#include <qpopupmenu.h>
-#include <qpushbutton.h>
-#include <qtextcodec.h>
-#include <qtranslator.h>
-#include <qvbox.h>
-#include <qvgroupbox.h>
+#include <QtCore/QTextCodec>
+#include <QtCore/QTranslator>
+#include <QtCore/QLibrary>
+#include <QtGui/QApplication>
+#include <QtGui/QCheckBox>
+#include <QtGui/QGroupBox>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QPushButton>
+#include <QtGui/QScrollBar>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QTreeWidgetItem>
+#include <QtGui/QVBoxLayout>
 
+#ifndef Q_WS_WIN
 #include <dlfcn.h>
+#endif
 
-// #include "config_dialog.h"
 #include "config_file.h"
 #include "debug.h"
 #include "hot_key.h"
@@ -28,17 +33,29 @@
 #include "kadu.h"
 #include "message_box.h"
 #include "misc.h"
+
 #include "modules.h"
-#include "modules_static.cpp"
+
+#include "modules/static_modules.cpp"
 
 #ifdef Q_OS_MACX
-	#define SO_EXT "dylib"
-	#define SO_EXT_LEN 5
+	#define SO_EXT "so"
+	#define SO_EXT_LEN 2
+	#define SO_PREFIX "lib"
+	#define SO_PREFIX_LEN 3
+#elif defined(Q_OS_WIN)
+	#define SO_EXT "dll"
+	#define SO_EXT_LEN 3
+	#define SO_PREFIX ""
+	#define SO_PREFIX_LEN 0
 #else
 	#define SO_EXT "so"
 	#define SO_EXT_LEN 2
+	#define SO_PREFIX "lib"
+	#define SO_PREFIX_LEN 3
 #endif
 
+#ifndef Q_WS_WIN
 Library::Library(const QString& file_name) : FileName(file_name), Handle(0)
 {
 }
@@ -53,7 +70,7 @@ Library::~Library()
 
 bool Library::load()
 {
-	Handle = dlopen(FileName.local8Bit().data(), RTLD_NOW | RTLD_GLOBAL);
+	Handle = dlopen(qPrintable(FileName), RTLD_NOW | RTLD_GLOBAL);
 	return (Handle != 0);
 }
 
@@ -61,89 +78,117 @@ void* Library::resolve(const QString& symbol_name)
 {
 	if (Handle == 0)
 		return 0;
-	return dlsym(Handle, symbol_name.local8Bit().data());
+	return dlsym(Handle, qPrintable(symbol_name));
 }
 
-QString Library::error()
+QString Library::errorString()
 {
 	return QString(dlerror());
 }
+#endif
 
 ModuleInfo::ModuleInfo() : depends(), conflicts(), provides(),
 	description(), author(), version(), load_by_def(false)
 {
 }
 
-void ModulesDialog::resizeEvent(QResizeEvent * /*e*/)
-{
-	// TODO: WTF
-	layoutHelper->resizeLabels();
-}
-
-ModulesDialog::ModulesDialog() : QHBox(kadu, "modules_dialog", WType_TopLevel | WDestructiveClose),
-	lv_modules(0), l_moduleinfo(0), layoutHelper(new LayoutHelper())
+ModulesDialog::ModulesDialog(QWidget *parent)
+	: QWidget(parent, Qt::Window),
+	lv_modules(0), l_moduleinfo(0)
 {
 	kdebugf();
-	setCaption(tr("Manage Modules"));
-	layout()->setResizeMode(QLayout::Minimum);
+	setWindowTitle(tr("Manage Modules"));
+	setAttribute(Qt::WA_DeleteOnClose);
 
 	// create main QLabel widgets (icon and app info)
-	QVBox *left=new QVBox(this);
-	left->setMargin(10);
-	left->setSpacing(10);
+	QWidget *left = new QWidget(this);
+	QVBoxLayout *leftLayout = new QVBoxLayout(left);
+	leftLayout->setMargin(10);
+	leftLayout->setSpacing(10);
 
 	QLabel *l_icon = new QLabel(left);
-	QWidget *blank=new QWidget(left);
-	blank->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Expanding));
 
-	QVBox *center=new QVBox(this);
-	center->setMargin(10);
-	center->setSpacing(10);
+	leftLayout->addWidget(l_icon);
+	leftLayout->addStretch(100);
+
+	QWidget *center = new QWidget(this);
+	QVBoxLayout *centerLayout = new QVBoxLayout(center);
+	centerLayout->setMargin(10);
+	centerLayout->setSpacing(10);
 
 	QLabel *l_info = new QLabel(center);
-	l_icon->setPixmap(icons_manager->loadIcon("ManageModulesWindowIcon"));
+	l_icon->setPixmap(icons_manager->loadPixmap("ManageModulesWindowIcon"));
 	l_info->setText(tr("This dialog box allows you to manage installed modules. Modules are responsible "
-			"for numerous vital features like playing sounds or message encryption. "
+			"for numerous vital features like playing sounds or message encryption.\n"
 			"You can load (or unload) them by double-clicking on their names."));
-	l_info->setAlignment(Qt::WordBreak);
+	l_info->setWordWrap(true);
+#ifndef	Q_OS_MAC
+	l_info->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+#endif
 	// end create main QLabel widgets (icon and app info)
 
 	// our QListView
-	lv_modules = new QListView(center);
-	lv_modules->addColumn(tr("Module name"), 160);
-	lv_modules->addColumn(tr("Version"), 100);
-	lv_modules->addColumn(tr("Module type"), 150);
-	lv_modules->addColumn(tr("State"), 120);
+	lv_modules = new QTreeWidget(center);
+	QStringList headers;
+	headers << tr("Module name") << tr("Version") << tr("Module type") << tr("State");
+	lv_modules->setHeaderLabels(headers);
+	lv_modules->setSortingEnabled(true);
 	lv_modules->setAllColumnsShowFocus(true);
+	lv_modules->setIndentation(false);
+	lv_modules->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
+
+	
 	// end our QListView
 
 	//our QVGroupBox
-	QVGroupBox *vgb_info = new QVGroupBox(center);
+	QGroupBox *vgb_info = new QGroupBox(center);
+	QVBoxLayout *infoLayout = new QVBoxLayout(vgb_info);
 	vgb_info->setTitle(tr("Info"));
 	//end our QGroupBox
 
 	l_moduleinfo = new QLabel(vgb_info);
 	l_moduleinfo->setText(tr("<b>Module:</b><br/><b>Depends on:</b><br/><b>Conflicts with:</b><br/><b>Provides:</b><br/><b>Author:</b><br/><b>Version:</b><br/><b>Description:</b>"));
+#ifndef	Q_OS_MAC
+	l_moduleinfo->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+#endif
+	l_moduleinfo->setWordWrap(true);
+
+	infoLayout->addWidget(l_moduleinfo);
 
 	// buttons
-	QHBox *bottom=new QHBox(center);
+	QWidget *bottom = new QWidget(center);
+	QHBoxLayout *bottomLayout = new QHBoxLayout(bottom);
+	bottomLayout->setSpacing(5);
+
 	hideBaseModules = new QCheckBox(tr("Hide base modules"), bottom);
 	hideBaseModules->setChecked(config_file.readBoolEntry("General", "HideBaseModules"));
 	connect(hideBaseModules, SIGNAL(clicked()), this, SLOT(refreshList()));
-	QWidget *blank2 = new QWidget(bottom);
-	bottom->setSpacing(5);
-	blank2->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
 	QPushButton *pb_close = new QPushButton(icons_manager->loadIcon("CloseWindow"), tr("&Close"), bottom, "close");
+
+	bottomLayout->addWidget(hideBaseModules);
+// 	bottomLayout->addStretch();
+	bottomLayout->addWidget(pb_close);
+#ifdef Q_OS_MAC
+	bottom->setMaximumHeight(pb_close->height() + 5);
+#endif
 	// end buttons
 
-	connect(pb_close, SIGNAL(clicked()), this, SLOT(close()));
-	connect(lv_modules, SIGNAL(selectionChanged()), this, SLOT(itemsChanging()));
-	connect(lv_modules, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(moduleAction(QListViewItem *)));
+	centerLayout->addWidget(l_info);
+	centerLayout->addWidget(lv_modules);
+	centerLayout->addWidget(vgb_info);
+	centerLayout->addWidget(bottom);
 
-	layoutHelper->addLabel(l_info);
-	layoutHelper->addLabel(l_moduleinfo);
-	loadGeometry(this, "General", "ModulesDialogGeometry", 0, 30, 600, 620);
+	QHBoxLayout *layout = new QHBoxLayout(this);
+	layout->addWidget(left);
+	layout->addWidget(center);
+
+	connect(pb_close, SIGNAL(clicked()), this, SLOT(close()));
+	connect(lv_modules, SIGNAL(itemSelectionChanged()), this, SLOT(itemsChanging()));
+	connect(lv_modules, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(moduleAction(QTreeWidgetItem *)));
+
+	loadWindowGeometry(this, "General", "ModulesDialogGeometry", 0, 50, 600, 620);
 	refreshList();
+	lv_modules->sortByColumn(0, Qt::AscendingOrder);
 	kdebugf2();
 }
 
@@ -151,44 +196,55 @@ ModulesDialog::~ModulesDialog()
 {
 	kdebugf();
 	config_file.writeEntry("General", "HideBaseModules", hideBaseModules->isChecked());
-	saveGeometry(this, "General", "ModulesDialogGeometry");
-	delete layoutHelper;
+ 	saveWindowGeometry(this, "General", "ModulesDialogGeometry");
 	kdebugf2();
 }
 
+QTreeWidgetItem * ModulesDialog::getSelected()
+{
+	if (lv_modules->selectedItems().count())
+		return lv_modules->selectedItems()[0];
+	else
+		return 0;
+}
+
 void ModulesDialog::itemsChanging()
 {
-	if (lv_modules->selectedItem() != NULL)
+	if (lv_modules->selectedItems().count())
 		getInfo();
 }
 
-void ModulesDialog::moduleAction(QListViewItem *)
+void ModulesDialog::moduleAction(QTreeWidgetItem *)
 {
 	kdebugf();
-	if (lv_modules->selectedItem() != NULL)
-		if ((lv_modules->selectedItem()->text(2) == tr("Dynamic")) &&
-			(lv_modules->selectedItem()->text(3) == tr("Loaded")))
-			unloadItem();
-		else
-		if ((lv_modules->selectedItem()->text(2) == tr("Dynamic")) &&
-			(lv_modules->selectedItem()->text(3) == tr("Not loaded")))
-			loadItem();
+
+	QTreeWidgetItem *selectedItem = getSelected();
+	if (!selectedItem)
+		return;
+
+	// TODO: OH LOL
+	if ((selectedItem->text(2) == tr("Dynamic")) && (selectedItem->text(3) == tr("Loaded")))
+		unloadItem(selectedItem->text(0));
+	else
+		if ((selectedItem->text(2) == tr("Dynamic")) && (selectedItem->text(3) == tr("Not loaded")))
+			loadItem(selectedItem->text(0));
+
 	kdebugf2();
 }
 
-void ModulesDialog::loadItem()
+void ModulesDialog::loadItem(const QString &item)
 {
 	kdebugf();
-	modules_manager->activateModule(lv_modules->selectedItem()->text(0));
+	modules_manager->activateModule(item);
 	refreshList();
 	modules_manager->saveLoadedModules();
 	kdebugf2();
 }
 
-void ModulesDialog::unloadItem()
+void ModulesDialog::unloadItem(const QString &item)
 {
 	kdebugf();
-	modules_manager->deactivateModule(lv_modules->selectedItem()->text(0));
+	modules_manager->deactivateModule(item);
 	refreshList();
 	modules_manager->saveLoadedModules();
 	kdebugf2();
@@ -198,54 +254,73 @@ void ModulesDialog::refreshList()
 {
 	kdebugf();
 
-	int vScrollValue=lv_modules->verticalScrollBar()->value();
+	int vScrollValue = lv_modules->verticalScrollBar()->value();
 
 	QString s_selected;
 
-	if (lv_modules->selectedItem() != NULL)
-		s_selected = lv_modules->selectedItem()->text(0);
+	QTreeWidgetItem *selectedItem = getSelected();
+	if (selectedItem)
+		s_selected = selectedItem->text(0);
 
 	lv_modules->clear();
 
 	QStringList moduleList = modules_manager->staticModules();
 	ModuleInfo info;
 	bool hideBase = hideBaseModules->isChecked();
-	CONST_FOREACH(module, moduleList)
+	foreach(const QString &module, moduleList)
 	{
-		if (modules_manager->moduleInfo(*module,info))
+		QStringList strings;
+
+		if (modules_manager->moduleInfo(module, info))
 		{
-			if (!info.base || !hideBase)
-				new QListViewItem(lv_modules, *module, info.version, tr("Static"), tr("Loaded"));
+			if (info.base && hideBase)
+				continue;
+
+			strings << module << info.version << tr("Static") << tr("Loaded");
 		}
 		else
-			new QListViewItem(lv_modules, *module, QString::null, tr("Static"), tr("Loaded"));
+			strings << module << QString::null << tr("Static") << tr("Loaded");
+	
+		new QTreeWidgetItem(lv_modules, strings);
 	}
 
 	moduleList = modules_manager->loadedModules();
-	CONST_FOREACH(module, moduleList)
+	foreach(const QString &module, moduleList)
 	{
-		if (modules_manager->moduleInfo(*module,info))
+		QStringList strings;
+
+		if (modules_manager->moduleInfo(module, info))
 		{
-			if (!info.base || !hideBase)
-				new QListViewItem(lv_modules, *module, info.version, tr("Dynamic"), tr("Loaded"));
+			if (info.base && hideBase)
+				continue;
+
+			strings << module << info.version << tr("Dynamic") << tr("Loaded");
 		}
 		else
-			new QListViewItem(lv_modules, *module, QString::null, tr("Dynamic"), tr("Loaded"));
+			strings << module << QString::null << tr("Dynamic") << tr("Loaded");
+	
+		new QTreeWidgetItem(lv_modules, strings);
 	}
 
 	moduleList = modules_manager->unloadedModules();
-	CONST_FOREACH(module, moduleList)
+	foreach(const QString &module, moduleList)
 	{
-		if (modules_manager->moduleInfo(*module,info))
+		QStringList strings;
+
+		if (modules_manager->moduleInfo(module, info))
 		{
-			if (!info.base || !hideBase)
-				new QListViewItem(lv_modules, *module, info.version, tr("Dynamic"), tr("Not loaded"));
+			if (info.base && hideBase)
+				continue;
+
+			strings << module << info.version << tr("Dynamic") << tr("Not loaded");
 		}
 		else
-			new QListViewItem(lv_modules, *module, QString::null, tr("Dynamic"), tr("Not loaded"));
+			strings << module << QString::null << tr("Dynamic") << tr("Not loaded");
+	
+		new QTreeWidgetItem(lv_modules, strings);
 	}
-
-	lv_modules->setSelected(lv_modules->findItem(s_selected, 0), true);
+	lv_modules->resizeColumnToContents(0);
+// 	lv_modules->setSelected(lv_modules->findItem(s_selected, 0), true);
 
 	lv_modules->verticalScrollBar()->setValue(vScrollValue);
 	kdebugf2();
@@ -256,7 +331,11 @@ void ModulesDialog::getInfo()
 	kdebugf();
 	ModuleInfo info;
 
-	if (!modules_manager->moduleInfo(lv_modules->selectedItem()->text(0), info))
+	QTreeWidgetItem *selected = getSelected();
+	if (!selected)
+		return;
+
+	if (!modules_manager->moduleInfo(selected->text(0), info))
 	{
 		kdebugf2();
 		return;
@@ -270,14 +349,13 @@ void ModulesDialog::getInfo()
 			"<br/><b>Author: </b>%5"
 			"<br/><b>Version: </b>%6"
 			"<br/><b>Description: </b>%7")
-			.arg(lv_modules->selectedItem()->text(0))
+			.arg(selected->text(0))
 			.arg(info.depends.join(", "))
 			.arg(info.conflicts.join(", "))
 			.arg(info.provides.join(", "))
 			.arg(info.author)
 			.arg(info.version)
 			.arg(info.description));
-	layoutHelper->textChanged(l_moduleinfo);
 	kdebugf2();
 }
 
@@ -311,15 +389,15 @@ ModulesManager::ModulesManager() : QObject(NULL, "modules_manager"),
 	// the same is true for menu - modules should load up at end
 	modules_manager = this;
 
-	QPopupMenu *MainMenu = kadu->mainMenu();
-	MainMenu->insertItem(icons_manager->loadIcon("ManageModules"), tr("&Manage Modules"), this, SLOT(showDialog()), HotKey::shortCutFromFile("ShortCuts", "kadu_modulesmanager"), -1, 2);
-	icons_manager->registerMenuItem(MainMenu, tr("&Manage Modules"), "ManageModules");
+	ActionDescription *manageModulesActionDescription = new ActionDescription(
+		ActionDescription::TypeMainMenu, "manageModulesAction",
+		this, SLOT(showDialog(QAction *, bool)),
+		"ManageModules", tr("&Manage Modules")
+	);
+	manageModulesActionDescription->setShortcut("kadu_modulesmanager", Qt::ApplicationShortcut);
+	kadu->insertMenuActionDescription(2, manageModulesActionDescription);
 
-	registerStaticModules();
-	QStringList static_list = staticModules();
-	CONST_FOREACH(i, static_list)
-		if (!moduleIsActive(*i))
-			activateModule(*i);
+	everLoaded = QStringList::split(',', config_file.readEntry("General", "EverLoaded"));
 
 	// load modules as config file say
 	QStringList installed_list = installedModules();
@@ -328,34 +406,43 @@ ModulesManager::ModulesManager() : QObject(NULL, "modules_manager"),
 	QString unloaded_str = config_file.readEntry("General", "UnloadedModules");
 	QStringList unloaded_list = QStringList::split(',', unloaded_str);
 	bool load_error = false;
-	CONST_FOREACH(i, installed_list)
-		if (!moduleIsActive(*i))
+
+	registerStaticModules();
+	QStringList static_list = staticModules();
+	foreach(const QString &i, static_list)
+		if (!moduleIsActive(i))
+			activateModule(i);
+
+	foreach(const QString &i, installed_list)
+	{
+		if (!moduleIsActive(i))
 		{
 			bool load_module;
-			if (loaded_list.contains(*i))
+			if (loaded_list.contains(i))
 				load_module = true;
-			else if (unloaded_list.contains(*i))
+			else if (unloaded_list.contains(i))
 				load_module = false;
 			else
 			{
 				ModuleInfo m_info;
-				if (moduleInfo(*i, m_info))
+				if (moduleInfo(i, m_info))
 					load_module = m_info.load_by_def;
 				else
 					load_module = false;
 			}
 			if (load_module)
-				if (!activateModule(*i))
+				if (!activateModule(i))
 					load_error = true;
 		}
+	}
 
 	// if not all modules were loaded properly
 	// save the list of modules
 	if (load_error)
 		saveLoadedModules();
 
-	CONST_FOREACH(it, Modules)
-		kdebugm(KDEBUG_INFO, "module: %s, usage: %d\n", it.key().local8Bit().data(), it.data().usage_counter);
+	foreach(const QString &it, Modules.keys())
+		kdebugm(KDEBUG_INFO, "module: %s, usage: %d\n", qPrintable(it), Modules[it].usage_counter);
 
 	kdebugf2();
 }
@@ -364,8 +451,10 @@ ModulesManager::~ModulesManager()
 {
 	kdebugf();
 
-	CONST_FOREACH(it, Modules)
-		kdebugm(KDEBUG_INFO, "module: %s, usage: %d\n", it.key().local8Bit().data(), it.data().usage_counter);
+	saveLoadedModules();
+
+	foreach(const QString &it, Modules.keys())
+		kdebugm(KDEBUG_INFO, "module: %s, usage: %d\n", qPrintable(it), Modules[it].usage_counter);
 
 	// unloading all not used modules
 	// as long as any module were unloaded
@@ -375,9 +464,9 @@ ModulesManager::~ModulesManager()
 	{
 		QStringList active = activeModules();
 		deactivated = false;
-		CONST_FOREACH(i, active)
-			if (Modules[*i].usage_counter == 0)
-				if (deactivateModule(*i))
+		foreach(const QString &i, active)
+			if (Modules[i].usage_counter == 0)
+				if (deactivateModule(i))
 					deactivated = true;
 	}
 	while (deactivated);
@@ -385,10 +474,10 @@ ModulesManager::~ModulesManager()
 	// we cannot unload more modules in normal way
 	// so we are making it brutal ;)
 	QStringList active = activeModules();
-	CONST_FOREACH(i, active)
+	foreach(const QString &i, active)
 	{
-		kdebugm(KDEBUG_PANIC, "WARNING! Could not deactivate module %s, killing\n",(*i).local8Bit().data());
-		deactivateModule((*i), true);
+		kdebugm(KDEBUG_PANIC, "WARNING! Could not deactivate module %s, killing\n",qPrintable(i));
+		deactivateModule(i, true);
 	}
 
 	delete translators;
@@ -415,13 +504,13 @@ QTranslator* ModulesManager::loadModuleTranslation(const QString& module_name)
 bool ModulesManager::satisfyModuleDependencies(const ModuleInfo& module_info)
 {
 	kdebugf();
-	CONST_FOREACH(it, module_info.depends)
+	foreach(const QString &it, module_info.depends)
 	{
-		if (!moduleIsActive(*it))
+		if (!moduleIsActive(it))
 		{
-			if (moduleIsInstalled(*it) || moduleIsStatic(*it))
+			if (moduleIsInstalled(it) || moduleIsStatic(it))
 			{
-				if (!activateModule(*it))
+				if (!activateModule(it))
 				{
 					kdebugf2();
 					return false;
@@ -429,7 +518,7 @@ bool ModulesManager::satisfyModuleDependencies(const ModuleInfo& module_info)
 			}
 			else
 			{
-				MessageBox::msg(tr("Required module %1 was not found").arg(*it));
+				MessageBox::msg(tr("Required module %1 was not found").arg(it));
 				kdebugf2();
 				return false;
 			}
@@ -441,11 +530,11 @@ bool ModulesManager::satisfyModuleDependencies(const ModuleInfo& module_info)
 
 void ModulesManager::incDependenciesUsageCount(const ModuleInfo& module_info)
 {
-	kdebugmf(KDEBUG_FUNCTION_START, "%s\n", module_info.description.local8Bit().data());
-	CONST_FOREACH(it, module_info.depends)
+	kdebugmf(KDEBUG_FUNCTION_START, "%s\n", qPrintable(module_info.description));
+	foreach(const QString &it, module_info.depends)
 	{
-		kdebugm(KDEBUG_INFO, "incUsage: %s\n", (*it).local8Bit().data());
-		moduleIncUsageCount(*it);
+		kdebugm(KDEBUG_INFO, "incUsage: %s\n", qPrintable(it));
+		moduleIncUsageCount(it);
 	}
 	kdebugf2();
 }
@@ -462,28 +551,28 @@ void ModulesManager::registerStaticModule(const QString& module_name,
 QStringList ModulesManager::staticModules() const
 {
 	QStringList static_modules;
-	CONST_FOREACH(i, StaticModules)
-		static_modules.append(i.key());
+	foreach(const QString &i, StaticModules.keys())
+		static_modules.append(i);
 	return static_modules;
 }
 
 QStringList ModulesManager::installedModules() const
 {
-	QDir dir(libPath("kadu/modules"),"*." SO_EXT);
+	QDir dir(libPath("kadu/modules"),SO_PREFIX"*." SO_EXT);
 	dir.setFilter(QDir::Files);
 	QStringList installed;
 	QStringList entries = dir.entryList();
-	CONST_FOREACH(entry, entries)
-		installed.append((*entry).left((*entry).length() - SO_EXT_LEN - 1));
+	foreach(const QString &entry, entries)
+		installed.append(entry.mid(SO_PREFIX_LEN, entry.length() - SO_EXT_LEN - SO_PREFIX_LEN - 1));
 	return installed;
 }
 
 QStringList ModulesManager::loadedModules() const
 {
 	QStringList loaded;
-	CONST_FOREACH(i, Modules)
-		if (i.data().lib!=NULL)
-			loaded.append(i.key());
+	foreach(const QString &i, Modules.keys())
+		if (Modules[i].lib!=NULL)
+			loaded.append(i);
 	return loaded;
 }
 
@@ -493,17 +582,17 @@ QStringList ModulesManager::unloadedModules() const
 	QStringList installed = installedModules();
 	QStringList loaded = loadedModules();
 	QStringList unloaded;
-	CONST_FOREACH(module, installed)
-		if (!loaded.contains(*module))
-			unloaded.append(*module);
+	foreach(const QString &module, installed)
+		if (!loaded.contains(module))
+			unloaded.append(module);
 	return unloaded;
 }
 
 QStringList ModulesManager::activeModules() const
 {
 	QStringList active;
-	CONST_FOREACH(i, Modules)
-		active.append(i.key());
+	foreach(const QString &i, Modules.keys())
+		active.append(i);
 	return active;
 }
 
@@ -512,16 +601,16 @@ QString ModulesManager::moduleProvides(const QString &provides)
 	ModuleInfo info;
 
 	QStringList moduleList = staticModules();
-	CONST_FOREACH(moduleName, moduleList)
-		if (moduleInfo(*moduleName, info))
+	foreach(const QString &moduleName, moduleList)
+		if (moduleInfo(moduleName, info))
 			if (info.provides.contains(provides))
-				return *moduleName;
+				return moduleName;
 
 	moduleList = installedModules();
-	CONST_FOREACH(moduleName, moduleList)
-		if (moduleInfo(*moduleName, info) && info.provides.contains(provides))
-			if (moduleIsLoaded(*moduleName))
-				return *moduleName;
+	foreach(const QString &moduleName, moduleList)
+		if (moduleInfo(moduleName, info) && info.provides.contains(provides))
+			if (moduleIsLoaded(moduleName))
+				return moduleName;
 
 	return "";
 }
@@ -586,36 +675,36 @@ bool ModulesManager::moduleIsActive(const QString& module_name) const
 
 void ModulesManager::saveLoadedModules()
 {
-	config_file.writeEntry("General", "LoadedModules",loadedModules().join(","));
-	config_file.writeEntry("General", "UnloadedModules",unloadedModules().join(","));
+	config_file.writeEntry("General", "LoadedModules", loadedModules().join(","));
+	config_file.writeEntry("General", "UnloadedModules", unloadedModules().join(","));
 	config_file.sync();
 }
 
 bool ModulesManager::conflictsWithLoaded(const QString &module_name, const ModuleInfo& module_info) const
 {
 	kdebugf();
-	CONST_FOREACH(it, module_info.conflicts)
+	foreach(const QString &it, module_info.conflicts)
 	{
-		if (moduleIsActive(*it))
+		if (moduleIsActive(it))
 		{
-			MessageBox::msg(narg(tr("Module %1 conflicts with: %2"), module_name, *it));
+			MessageBox::msg(narg(tr("Module %1 conflicts with: %2"), module_name, it));
 			kdebugf2();
 			return true;
 		}
-		CONST_FOREACH(mit, Modules)
-			CONST_FOREACH(sit, (*mit).info.provides)
-				if ((*it)==(*sit))
+		foreach(const QString &key, Modules.keys())
+			foreach(const QString &sit, Modules[key].info.provides)
+				if (it == sit)
 				{
-					MessageBox::msg(narg(tr("Module %1 conflicts with: %2"), module_name, mit.key()));
+					MessageBox::msg(narg(tr("Module %1 conflicts with: %2"), module_name, key));
 					kdebugf2();
 					return true;
 				}
 	}
-	CONST_FOREACH(it, Modules)
-		CONST_FOREACH(sit, (*it).info.conflicts)
-			if ((*sit)==module_name)
+	foreach(const QString &key, Modules.keys())
+		foreach(const QString &sit, Modules[key].info.conflicts)
+			if (sit == module_name)
 			{
-				MessageBox::msg(narg(tr("Module %1 conflicts with: %2"), module_name, it.key()));
+				MessageBox::msg(narg(tr("Module %1 conflicts with: %2"), module_name, key));
 				kdebugf2();
 				return true;
 			}
@@ -626,7 +715,7 @@ bool ModulesManager::conflictsWithLoaded(const QString &module_name, const Modul
 bool ModulesManager::activateModule(const QString& module_name)
 {
 	Module m;
-	kdebugmf(KDEBUG_FUNCTION_START, "'%s'\n", module_name.local8Bit().data());
+	kdebugmf(KDEBUG_FUNCTION_START, "'%s'\n", qPrintable(module_name));
 
 	if (moduleIsActive(module_name))
 	{
@@ -654,8 +743,7 @@ bool ModulesManager::activateModule(const QString& module_name)
 		return false;
 	}
 
-	typedef int InitModuleFunc();
-	InitModuleFunc* init;
+	InitModuleFunc *init;
 
 	if (moduleIsStatic(module_name))
 	{
@@ -666,18 +754,18 @@ bool ModulesManager::activateModule(const QString& module_name)
 	}
 	else
 	{
-		m.lib = new Library(libPath("kadu/modules/" + module_name + "." SO_EXT));
+		m.lib = new Library(libPath("kadu/modules/"SO_PREFIX + module_name + "." SO_EXT));
 		if (!m.lib->load())
 		{
-			QString err = m.lib->error();
+			QString err = m.lib->errorString();
 			MessageBox::msg(narg(tr("Cannot load %1 module library.:\n%2"), module_name, err));
-			kdebugm(KDEBUG_ERROR, "cannot load %s because of: %s\n", module_name.local8Bit().data(), err.local8Bit().data());
+			kdebugm(KDEBUG_ERROR, "cannot load %s because of: %s\n", qPrintable(module_name), qPrintable(err));
 			delete m.lib;
 			kdebugf2();
 			return false;
 		}
-		init=(InitModuleFunc*)m.lib->resolve(module_name+"_init");
-		m.close=(CloseModuleFunc*)m.lib->resolve(module_name+"_close");
+		init = (InitModuleFunc *)m.lib->resolve(module_name+"_init");
+		m.close = (CloseModuleFunc *)m.lib->resolve(module_name+"_close");
 		if (init==NULL||m.close==NULL)
 		{
 			MessageBox::msg(tr("Cannot find required functions in module %1.\nMaybe it's not Kadu-compatible Module.").arg(module_name));
@@ -689,7 +777,13 @@ bool ModulesManager::activateModule(const QString& module_name)
 
 	m.translator = loadModuleTranslation(module_name);
 
-	int res = init();
+	int res = init(!everLoaded.contains(module_name));
+	if (!everLoaded.contains(module_name))
+	{
+		everLoaded.append(module_name);
+		config_file.writeEntry("General", "EverLoaded", everLoaded.join(","));
+	}
+
 	if (res != 0)
 	{
 		MessageBox::msg(tr("Module initialization routine for %1 failed.").arg(module_name));
@@ -714,7 +808,7 @@ bool ModulesManager::activateModule(const QString& module_name)
 bool ModulesManager::deactivateModule(const QString& module_name, bool force)
 {
 	Module m=Modules[module_name];
-	kdebugmf(KDEBUG_FUNCTION_START, "name:'%s' force:%d usage:%d\n", module_name.local8Bit().data(), force, m.usage_counter);
+	kdebugmf(KDEBUG_FUNCTION_START, "name:'%s' force:%d usage:%d\n", qPrintable(module_name), force, m.usage_counter);
 
 	if (m.usage_counter>0 && !force)
 	{
@@ -723,17 +817,17 @@ bool ModulesManager::deactivateModule(const QString& module_name, bool force)
 		return false;
 	}
 
-	CONST_FOREACH(i, m.info.depends)
-		moduleDecUsageCount(*i);
+	foreach(const QString &i, m.info.depends)
+		moduleDecUsageCount(i);
 
 	m.close();
-	if (m.translator!=NULL)
+	if (m.translator)
 	{
 		qApp->removeTranslator(m.translator);
 		delete m.translator;
 	}
 
-	if (m.lib!=NULL)
+	if (m.lib)
 		m.lib->deleteLater();
 
 	Modules.remove(module_name);
@@ -742,7 +836,7 @@ bool ModulesManager::deactivateModule(const QString& module_name, bool force)
 	return true;
 }
 
-void ModulesManager::showDialog()
+void ModulesManager::showDialog(QAction *sender, bool toggled)
 {
 	kdebugf();
 
