@@ -9,19 +9,28 @@
 
 #include <algorithm>
 
-#include <qapplication.h>
-#include <qcheckbox.h>
-#include <qcursor.h>
-#include <qcombobox.h>
-#include <qdragobject.h>
-#include <qpainter.h>
-#include <qspinbox.h>
-#include <qtextcodec.h>
-#include <qvgroupbox.h>
+#include <Qt3Support/Q3DragObject>
+#include <Qt3Support/Q3PopupMenu>
+#include <Qt3Support/Q3VGroupBox>
+#include <QtCore/QEvent>
+#include <QtCore/QList>
+#include <QtCore/QTextCodec>
+#include <QtGui/QApplication>
+#include <QtGui/QCheckBox>
+#include <QtGui/QCursor>
+#include <QtGui/QComboBox>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QPainter>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPixmap>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QSpinBox>
+#include <QtGui/QWheelEvent>
 
 #include "action.h"
 #include "config_file.h"
 #include "debug.h"
+#include "gadu.h"
 #include "html_document.h"
 #include "icons_manager.h"
 #include "ignore.h"
@@ -135,7 +144,7 @@ void KaduListBoxPixmap::setFont(const QFont &f)
 }
 
 KaduListBoxPixmap::KaduListBoxPixmap(UserListElement user)
-	: QListBoxItem(), pm(pixmapForUser(user)), buf_text(), buf_width(-1), buf_out(), buf_height(-1), User(user)
+	: Q3ListBoxItem(), pm(pixmapForUser(user)), buf_text(), buf_width(-1), buf_out(), buf_height(-1), User(user)
 {
 	setText(user.altNick());
 }
@@ -195,7 +204,7 @@ void KaduListBoxPixmap::paint(QPainter *painter)
 			painter->setPen(QColor(255, 0, 0));
 		else if (IgnoredManager::isIgnored(users))
 			painter->setPen(QColor(192, 192, 0));
-		else if (User.protocolData("Gadu", "OfflineTo").toBool())
+		else if (config_file.readBoolEntry("General", "PrivateStatus") && User.protocolData("Gadu", "OfflineTo").toBool())
 			painter->setPen(QColor(128, 128, 128));
 		if (User.data("HideDescription").toString() != "true")
 			description = User.status("Gadu").description();
@@ -253,9 +262,9 @@ void KaduListBoxPixmap::paint(QPainter *painter)
 				painter->setPen(descColor);
 			else
 				painter->setPen(origColor);
-			CONST_FOREACH(text, out)
+			foreach(const QString &text, out)
 			{
-				painter->drawText(pm.width() + 5, yPos, *text);
+				painter->drawText(pm.width() + 5, yPos, text);
 				yPos += descriptionFontMetrics->lineSpacing();
 			}
 
@@ -265,7 +274,7 @@ void KaduListBoxPixmap::paint(QPainter *painter)
 //	kdebugf2();
 }
 
-int KaduListBoxPixmap::height(const QListBox* lb) const
+int KaduListBoxPixmap::height(const Q3ListBox* lb) const
 {
 //	kdebugf();
 	QString description;
@@ -287,14 +296,14 @@ int KaduListBoxPixmap::height(const QListBox* lb) const
 	return QMAX(pm.height(), height);
 }
 
-int KaduListBoxPixmap::lineHeight(const QListBox* lb) const
+int KaduListBoxPixmap::lineHeight(const Q3ListBox* lb) const
 {
 	int height=lb->fontMetrics().lineSpacing()+3;
 	return QMAX(pm.height(), height);
 }
 
 
-int KaduListBoxPixmap::width(const QListBox* lb) const
+int KaduListBoxPixmap::width(const Q3ListBox* lb) const
 {
 	if (ColumnCount == 0)
 		return QMAX(pm.width(), (lb->visibleWidth()));
@@ -395,9 +404,9 @@ void KaduListBoxPixmap::calculateSize(const QString &text, int width, QStringLis
 	buf_width=width;
 	buf_out=out;
 	buf_height=height;
-//	kdebugm(KDEBUG_DUMP, "h:%d txt:%s\n", height, text.local8Bit().data());
+//	kdebugm(KDEBUG_DUMP, "h:%d txt:%s\n", height, qPrintable(text));
 //	for(QStringList::Iterator it = out.begin(); it != out.end(); ++it )
-//		kdebugm(KDEBUG_DUMP, ">>%s\n", (*it).local8Bit().data());
+//		kdebugm(KDEBUG_DUMP, ">>%s\n", qPrintable(*it));
 }
 
 void KaduListBoxPixmap::changeText(const QString &text)
@@ -408,25 +417,25 @@ void KaduListBoxPixmap::changeText(const QString &text)
 QPixmap KaduListBoxPixmap::pixmapForUser(const UserListElement &user)
 {
 	bool has_mobile = !user.mobile().isEmpty();
-	bool usesGadu = user.usesProtocol("Gadu");
-	if (!usesGadu)
+
+	if (!user.usesProtocol("Gadu"))
 	{
 		if (has_mobile)
-			return icons_manager->loadIcon("Mobile");
+			return icons_manager->loadPixmap("Mobile");
 		else if (!user.email().isEmpty())
-			return icons_manager->loadIcon("WriteEmail");
+			return icons_manager->loadPixmap("WriteEmail");
 		else
 			return QPixmap();
 	}
 	else if (pending.pendingMsgs(user))
-		return icons_manager->loadIcon("Message");
+		return icons_manager->loadPixmap("Message");
 	else
 	{
 		const QPixmap &pix = user.status("Gadu").pixmap(has_mobile);
 		if (!pix.isNull())
 			return pix;
 		else
-			return icons_manager->loadIcon("Online");
+			return icons_manager->loadPixmap("Online");
 	}
 }
 
@@ -440,46 +449,89 @@ class ULEComparer
 {
 	public:
 		inline bool operator()(const UserListElement &e1, const UserListElement &e2) const;
-		QValueList<UserBox::CmpFuncDesc> CmpFunctions;
+		QList<UserBox::CmpFuncDesc> CmpFunctions;
 		ULEComparer() : CmpFunctions() {}
 };
 
 inline bool ULEComparer::operator()(const UserListElement &e1, const UserListElement &e2) const
 {
 	int ret = 0;
-	CONST_FOREACH(f, CmpFunctions)
+	foreach(const UserBox::CmpFuncDesc &f, CmpFunctions)
 	{
-		ret = (*f).func(e1, e2);
-//		kdebugm(KDEBUG_WARNING, "%s %s %d\n", e1.altNick().local8Bit().data(), e2.altNick().local8Bit().data(), ret);
+		ret = f.func(e1, e2);
+//		kdebugm(KDEBUG_WARNING, "%s %s %d\n", qPrintable(e1.altNick()), qPrintable(e2.altNick()), ret);
 		if (ret)
 			break;
 	}
 	return ret < 0;
 }
 
-UserBoxMenu *UserBox::userboxmenu = NULL;
-UserBoxMenu *UserBox::management = NULL;
+//TODO 0.6.6: workaround for: http://www.kadu.net/mantis/view.php?id=1108
+class ScrollBarWatcher : public QObject
+{
+public:
+	ScrollBarWatcher()
+	{
+	}
+
+	virtual bool eventFilter(QObject *o, QEvent *e)
+	{
+		if (Kadu::closing())
+			return false;
+		QScrollBar *scrollbar = dynamic_cast<QScrollBar *>(o);
+		if (!scrollbar)
+			return false;
+		UserBox *userbox = dynamic_cast<UserBox *>(scrollbar->parent());
+		if (!userbox)
+			return false;
+
+		switch (e->type())
+		{
+			case QEvent::Show:
+			case QEvent::Hide:
+				userbox->refresh();
+			default:
+				return false;
+		}
+	}
+};
+ScrollBarWatcher *scrollBarWatcher = 0;
+//
+
 CreateNotifier UserBox::createNotifier;
 
-UserBox::UserBox(bool fancy, UserGroup *group, QWidget* parent, const char* name, WFlags f)
-	: QListBox(parent, name, f), fancy(fancy), VisibleUsers(new UserGroup(userlist->count() * 2, "visible_users")),
+QList<ActionDescription *> UserBox::UserBoxActions;
+QList<ActionDescription *> UserBox::ManagementActions;
+
+UserBox::UserBox(KaduMainWindow *mainWindow, bool fancy, UserGroup *group, QWidget* parent, const char* name, Qt::WFlags f)
+	: Q3ListBox(parent, name, f), MainWindow(mainWindow), fancy(fancy), VisibleUsers(new UserGroup()),
 	Filters(), NegativeFilters(), sortHelper(), toRemove(), AppendProxy(), RemoveProxy(), comparer(new ULEComparer()),
-	refreshTimer(), lastMouseStopUser(nullElement), lastMouseStop(), tipTimer(),
+	refreshTimer(), lastMouseStopUser(nullElement), tipTimer(),
 	verticalPositionTimer(), lastVerticalPosition(0)
 {
 	kdebugf();
 	Filters.append(group);
 
-	setHScrollBarMode(QScrollView::AlwaysOff);
+	setHScrollBarMode(Q3ScrollView::AlwaysOff);
+
+	//TODO 0.6.6: workaround for: http://www.kadu.net/mantis/view.php?id=1108
+	if (!scrollBarWatcher)
+		scrollBarWatcher = new ScrollBarWatcher();
+	verticalScrollBar()->installEventFilter(scrollBarWatcher);
+	//
+
+	showDescriptionAction = new ActionDescription(
+		ActionDescription::TypeUserList, "descriptionsAction",
+		this, SLOT(showDescriptionsActionActivated(QAction *, bool)),
+		"ShowDescription", tr("Hide descriptions"),
+		true, tr("Show descriptions")
+	);
+	connect(showDescriptionAction, SIGNAL(actionCreated(KaduAction *)), this, SLOT(setDescriptionsActionState()));
 
-	desc_action = new Action("ShowDescription", tr("Hide descriptions"), "descriptionsAction", Action::TypeUserList);
-	desc_action->setOnShape("HideDescription", tr("Show descriptions"));
-	desc_action->setToggleAction(true);
-	connect(desc_action, SIGNAL(activated(const UserGroup*, const QWidget*, bool)),
-		this, SLOT(descriptionsActionActivated(const UserGroup*, const QWidget*, bool)));
-	connect(desc_action, SIGNAL(iconsRefreshed()), this, SLOT(setDescriptionsActionState()));
 	setDescriptionsActionState();
 
+	connect(this, SIGNAL(selectionChanged()), this, SLOT(selectionChangedSlot()));
+
 	connect(group, SIGNAL(userAdded(UserListElement, bool, bool)),
 			this, SLOT(userAddedToGroup(UserListElement, bool, bool)));
 	connect(group, SIGNAL(userRemoved(UserListElement, bool, bool)),
@@ -505,18 +557,14 @@ UserBox::UserBox(bool fancy, UserGroup *group, QWidget* parent, const char* name
 	else
 		addCompareFunction("AltNick", tr("Nicks"), compareAltNick);
 
-	if (!userboxmenu)
-		userboxmenu = new UserBoxMenu(this);
-	if (!management)
-		management = new UserBoxMenu(userboxmenu);
 	UserBoxes.append(this);
 
 	setMinimumWidth(20);
-	setSelectionMode(QListBox::Extended);
+	setSelectionMode(Q3ListBox::Extended);
 
-	connect(this, SIGNAL(doubleClicked(QListBoxItem *)), this, SLOT(doubleClickedSlot(QListBoxItem *)));
-	connect(this, SIGNAL(returnPressed(QListBoxItem *)), this, SLOT(returnPressedSlot(QListBoxItem *)));
-	connect(this, SIGNAL(currentChanged(QListBoxItem *)), this, SLOT(currentChangedSlot(QListBoxItem *)));
+	connect(this, SIGNAL(doubleClicked(Q3ListBoxItem *)), this, SLOT(doubleClickedSlot(Q3ListBoxItem *)));
+	connect(this, SIGNAL(returnPressed(Q3ListBoxItem *)), this, SLOT(returnPressedSlot(Q3ListBoxItem *)));
+	connect(this, SIGNAL(currentChanged(Q3ListBoxItem *)), this, SLOT(currentChangedSlot(Q3ListBoxItem *)));
 	connect(&refreshTimer, SIGNAL(timeout()), this, SLOT(refresh()));
 
 	connect(&pending, SIGNAL(messageFromUserAdded(UserListElement)), this, SLOT(messageFromUserAdded(UserListElement)));
@@ -536,13 +584,17 @@ UserBox::UserBox(bool fancy, UserGroup *group, QWidget* parent, const char* name
 UserBox::~UserBox()
 {
 	kdebugf();
+
+	disconnect(VisibleUsers, SIGNAL(userRemoved(UserListElement, bool, bool)),
+			this, SLOT(userRemovedFromVisible(UserListElement, bool, bool)));
+
 	UserBoxes.remove(this);
+	
 	delete VisibleUsers;
 	VisibleUsers = 0;
 	delete comparer;
 	comparer = 0;
-	delete desc_action;
-	desc_action = 0;
+
 	kdebugf2();
 }
 
@@ -552,7 +604,7 @@ void UserBox::tipTimeout()
 {
 	if (lastMouseStopUser != nullElement)
 	{
-		tool_tip_class_manager->showToolTip(lastMouseStop, lastMouseStopUser);
+		tool_tip_class_manager->showToolTip(QCursor().pos(), lastMouseStopUser);
 		tipTimer.stop();
 	}
 }
@@ -572,7 +624,6 @@ void UserBox::restartTip(const QPoint &p)
 		hideTip();
 		lastMouseStopUser = nullElement;
 	}
-	lastMouseStop = p;
 	tipTimer.start(TIP_TM);
 //	kdebugf2();
 }
@@ -587,24 +638,25 @@ void UserBox::hideTip(bool waitForAnother)
 		tipTimer.stop();
 }
 
-void UserBox::descriptionsActionActivated(const UserGroup* /*users*/, const QWidget* /*widget*/, bool toggle)
+void UserBox::showDescriptionsActionActivated(QAction *sender, bool toggle)
 {
-	desc_action->setAllOn(toggle);
 	config_file.writeEntry("Look", "ShowDesc", !toggle);
-//	dynamic_cast<QCheckBox *>(MainConfigurationWindow::instance()->widgetById("showDescription"))->setChecked(toggle);
 	KaduListBoxPixmap::setShowDesc(!toggle);
 	UserBox::refreshAllLater();
+ 	foreach (KaduAction *action, showDescriptionAction->actions())
+		action->setChecked(!KaduListBoxPixmap::ShowDesc);
 }
 
 void UserBox::setDescriptionsActionState()
 {
-	desc_action->setAllOn(!KaduListBoxPixmap::ShowDesc);
+ 	foreach (KaduAction *action, showDescriptionAction->actions())
+		action->setChecked(!KaduListBoxPixmap::ShowDesc);
 }
 
 void UserBox::wheelEvent(QWheelEvent *e)
 {
 //	kdebugf();
-	QListBox::wheelEvent(e);
+	Q3ListBox::wheelEvent(e);
 
 	// if event source (e->globalPos()) is inside this widget (QRect(...))
 	if (QRect(mapToGlobal(QPoint(0,0)), size()).contains(e->globalPos()))
@@ -616,25 +668,28 @@ void UserBox::wheelEvent(QWheelEvent *e)
 void UserBox::enterEvent(QEvent *e)
 {
 //	kdebugf();
-	QListBox::enterEvent(e);
+	Q3ListBox::enterEvent(e);
 }
 
 void UserBox::leaveEvent(QEvent *e)
 {
 //	kdebugf();
 	hideTip(false);
-	QListBox::leaveEvent(e);
+	Q3ListBox::leaveEvent(e);
 }
 
 void UserBox::mousePressEvent(QMouseEvent *e)
 {
 	kdebugf();
 	hideTip(false);
-	if (e->button() != RightButton)
-		QListBox::mousePressEvent(e);
+	if (e->button() != Qt::RightButton)
+	{
+		MouseStart = e->pos();
+		Q3ListBox::mousePressEvent(e);
+	}
 	else
 	{
-		QListBoxItem *item = itemAt(e->pos());
+		Q3ListBoxItem *item = itemAt(e->pos());
 		if (item)
 		{
 			if (!item->isSelected())
@@ -651,26 +706,26 @@ void UserBox::mousePressEvent(QMouseEvent *e)
 
 void UserBox::mouseReleaseEvent(QMouseEvent *e)
 {
-	QListBox::mouseReleaseEvent(e);
+	Q3ListBox::mouseReleaseEvent(e);
 	restartTip(e->pos());
 }
 
 void UserBox::mouseMoveEvent(QMouseEvent* e)
 {
 //	kdebugf();
-	if ((e->state() & LeftButton) && itemAt(e->pos()))
+	if ((e->buttons() & Qt::LeftButton) && itemAt(MouseStart) && (e->pos() - MouseStart).manhattanLength() > QApplication::startDragDistance())
 	{
 		QStringList ules;
-		for(unsigned int i = 0, count1 = count(); i < count1; ++i)
+		for(int i = 0, count1 = count(); i < count1; ++i)
 			if (isSelected(i))
 				ules.append(item(i)->text());
 
-		QDragObject* d = new UlesDrag(ules, this);
-		d->dragCopy();
+		QDrag* drag = new UlesDrag(ules, this);
+		drag->exec(Qt::CopyAction);
 	}
 	else
 	{
-		QListBox::mouseMoveEvent(e);
+		Q3ListBox::mouseMoveEvent(e);
 		restartTip(e->pos());
 	}
 //	kdebugf2();
@@ -680,9 +735,9 @@ void UserBox::keyPressEvent(QKeyEvent *e)
 {
 //	kdebugf();
 	hideTip(false);
-	QListBox::keyPressEvent(e);
+	Q3ListBox::keyPressEvent(e);
 //	QWidget::keyPressEvent(e);
-	QListBoxItem *i = item(currentItem());
+	Q3ListBoxItem *i = item(currentItem());
 	currentChangedSlot(i);
 //	kdebugf2();
 }
@@ -743,7 +798,7 @@ void UserBox::refresh()
 	int vScrollValue = verticalScrollBar()->value();
 
 	// clearing list
-	QListBox::clear();
+	Q3ListBox::clear();
 	// clear clears columns too...
 	if (fancy)
 		setColumnMode(config_file.readNumEntry("Look", "UserBoxColumnCount", 1));
@@ -753,8 +808,8 @@ void UserBox::refresh()
 		insertItem(new KaduListBoxPixmap(*user));
 
 	// restore selected users
-	CONST_FOREACH(username, s_users)
-		setSelected(findItem(*username), true);
+	foreach(const QString &username, s_users)
+		setSelected(findItem(username), true);
 	setCurrentItem(findItem(s_user));
 
 	// restore vertical scrollbar position
@@ -763,9 +818,9 @@ void UserBox::refresh()
 	// because settingCurrentItem changes vertical scrollbar position and line
 	// above doesn't prevents this, we must set position as soon as possible
 	lastVerticalPosition = vScrollValue;
+
 	verticalPositionTimer.start(0, true);
 
-	updateScrollBars();
 //	QListBox::refresh();
 
 //	}
@@ -778,10 +833,10 @@ void UserBox::refresh()
 void UserBox::resetVerticalPosition()
 {
 	kdebugf();
+
 	verticalScrollBar()->setValue(lastVerticalPosition);
 
 	updateScrollBars();
-// 	refresh();
 }
 
 void UserBox::rememberVerticalPosition()
@@ -800,25 +855,10 @@ UserListElements UserBox::selectedUsers() const
 	return users;
 }
 
-UserBox* UserBox::activeUserBox()
-{
-	kdebugf();
-
-	CONST_FOREACH(box, UserBoxes)
-	{
-		QWidget *widget = *box;
-		if (!widget->isShown())
-			continue;
-
-		while (widget->parent())
-			widget = dynamic_cast<QWidget *>(widget->parent());
-
-		if (widget->isActiveWindow())
-			return *box;
-	}
-	kdebugmf(KDEBUG_WARNING, "return NULL!\n");
-//	printBacktrace("activeUserBox NULL");
-	return kadu->userbox();
+void UserBox::selectionChangedSlot()
+{	
+	if (!Kadu::closing())
+		emit userListChanged();
 }
 
 void UserBox::refreshLater()
@@ -829,16 +869,16 @@ void UserBox::refreshLater()
 void UserBox::refreshAll()
 {
 	kdebugf();
-	FOREACH(box, UserBoxes)
-		(*box)->refresh();
+	foreach(UserBox *box, UserBoxes)
+		box->refresh();
 	kdebugf2();
 }
 
 void UserBox::refreshAllLater()
 {
 	kdebugf();
-	FOREACH(box, UserBoxes)
-		(*box)->refreshLater();
+	foreach(UserBox *box, UserBoxes)
+		box->refreshLater();
 	kdebugf2();
 }
 
@@ -889,17 +929,22 @@ void UserBox::initModule()
 void UserBox::resizeEvent(QResizeEvent *r)
 {
 //	kdebugf();
-	QListBox::resizeEvent(r);
+	Q3ListBox::resizeEvent(r);
 	refreshBackground();
 	triggerUpdate(true);
 }
 
 void UserBox::refreshBackground()
 {
-	setPaletteBackgroundColor(config_file.readColorEntry("Look","UserboxBgColor"));
-	setPaletteForegroundColor(config_file.readColorEntry("Look","UserboxFgColor"));
+	//hack:
+	viewport()->setStyleSheet(QString("QWidget {background-color:%1}").arg(config_file.readColorEntry("Look","UserboxBgColor").name()));
+	setStyleSheet(QString("QFrame {color:%1}").arg(config_file.readColorEntry("Look","UserboxFgColor").name()));
+	
+	/*	
+	TODO 0.6.6: dead code. Re-Enable in 0.6.6
+	
 	setStaticBackground(backgroundImage);
-
+	
 	if (!backgroundImage || !fancy)
 		return;
 
@@ -936,97 +981,73 @@ void UserBox::refreshBackground()
 	else // TILED
 		image = *backgroundImage;
 
-	setPaletteBackgroundPixmap(image);
+ 	viewport()->setPaletteBackgroundPixmap(QPixmap::fromImage(image));
+	*/
 }
 
-void UserBox::doubleClickedSlot(QListBoxItem *item)
+void UserBox::doubleClickedSlot(Q3ListBoxItem *item)
 {
 	emit doubleClicked(static_cast<KaduListBoxPixmap *>(item)->User);
 }
 
-void UserBox::returnPressedSlot(QListBoxItem *item)
+void UserBox::returnPressedSlot(Q3ListBoxItem *item)
 {
 	emit returnPressed(static_cast<KaduListBoxPixmap *>(item)->User);
 }
 
-void UserBox::currentChangedSlot(QListBoxItem *item)
+void UserBox::currentChangedSlot(Q3ListBoxItem *item)
 {
+	/*
+	TODO 0.6.6: obejście dziwnego problemu z Q3ListBox.
+	Pomimo kilknięcia, currentItem() wskazuje na poprzednio aktywny element.
+	Blokujemy sygnał, aby ponownie nie wykonywać tej samem metody 
+	*/
+	blockSignals(true);
+	setCurrentItem(item);
+	blockSignals(false);
+	//
 	if (item)
 		emit currentChanged(static_cast<KaduListBoxPixmap *>(item)->User);
 }
 
-UserBoxMenu::UserBoxMenu(QWidget *parent, const char *name) : QPopupMenu(parent, name), iconNames()
+void UserBox::addActionDescription(ActionDescription *actionDescription)
 {
-	connect(this, SIGNAL(aboutToHide()), this, SLOT(restoreLook()));
+	UserBoxActions.append(actionDescription);
 }
 
-int UserBoxMenu::addItem(const QString &text, const QObject* receiver, const char* member, const QKeySequence accel, int id)
+void UserBox::insertActionDescription(int pos, ActionDescription *actionDescription)
 {
-	return insertItem(text, receiver, member, accel, id);
+	UserBoxActions.insert(pos, actionDescription);
 }
 
-int UserBoxMenu::addItem(const QString &iconname, const QString &text, const QObject* receiver, const char* member, const QKeySequence accel, int id)
+void UserBox::removeActionDescription(ActionDescription *actionDescription)
 {
-	iconNames.append(qMakePair(text,iconname));
-	return insertItem( QIconSet(icons_manager->loadIcon(iconname)) , text, receiver, member, accel, id);
+	UserBoxActions.removeAll(actionDescription);
 }
 
-int UserBoxMenu::addItemAtPos(int index, const QString &text, const QObject* receiver, const char* member, const QKeySequence accel, int id)
+void UserBox::addSeparator()
 {
-	return insertItem(text, receiver, member, accel, id, index);
+	UserBoxActions.append(0);
 }
 
-int UserBoxMenu::addItemAtPos(int index,const QString &iconname, const QString &text, const QObject* receiver, const char* member, const QKeySequence accel, int id)
+void UserBox::addManagementActionDescription(ActionDescription *actionDescription)
 {
-	iconNames.append(qMakePair(text,iconname));
-	return insertItem( QIconSet(icons_manager->loadIcon(iconname)) , text, receiver, member, accel, id, index);
+	ManagementActions.append(actionDescription);
 }
 
-int UserBoxMenu::getItem(const QString &caption) const
+void UserBox::insertManagementActionDescription(int pos, ActionDescription *actionDescription)
 {
-	for (unsigned int i = 0, count2 = count(); i < count2; ++i)
-		if (!QString::localeAwareCompare(caption, text(idAt(i)).left(caption.length())))
-			return idAt(i);
-	return -1;
+	ManagementActions.insert(pos, actionDescription);
 }
 
-void UserBoxMenu::restoreLook()
+void UserBox::removeManagementActionDescription(ActionDescription *actionDescription)
 {
-	for (unsigned int i = 0, count2 = count(); i < count2; ++i)
-	{
-		setItemVisible(idAt(i), true);
-		setItemChecked(idAt(i), false);
-	}
+	ManagementActions.removeAll(actionDescription);
 }
 
-void UserBoxMenu::show(QListBoxItem *item)
+void UserBox::addManagementSeparator()
 {
-	if (item == NULL)
-		return;
-
-	emit popup();
-	showPopupMenu(this);
-}
-
-void UserBoxMenu::refreshIcons()
-{
-	kdebugf();
-	for (unsigned int i = 0, count2 = count(); i < count2; ++i)
-	{
-		int id = idAt(i);
-		QString t = text(id);
-
-		CONST_FOREACH(it, iconNames)
-			if (t.startsWith((*it).first))
-			{
-				bool visible = isItemVisible(id);
-				bool checked = isItemChecked(id);
-				changeItem(id, icons_manager->loadIcon((*it).second), t);
-				setItemVisible(id, visible);
-				setItemChecked(id, checked);
-			}
-	}
-	kdebugf2();
+	ManagementActions.append(0);
 }
 
 void UserBox::configurationUpdated()
@@ -1036,7 +1057,7 @@ void UserBox::configurationUpdated()
 	int columnCount = config_file.readNumEntry("Look", "UserBoxColumnCount", 1);
 	setColumnMode(columnCount);
 
-	QListBox::setFont(config_file.readFontEntry("Look", "UserboxFont"));
+	Q3ListBox::setFont(config_file.readFontEntry("Look", "UserboxFont"));
 
 	KaduListBoxPixmap::setFont(config_file.readFontEntry("Look", "UserboxFont"));
 	KaduListBoxPixmap::setShowDesc(config_file.readBoolEntry("Look", "ShowDesc"));
@@ -1057,8 +1078,11 @@ void UserBox::configurationUpdated()
 	kdebugf2();
 }
 
+
 void UserBox::setColorsOrBackgrounds()
 {
+	/*
+	TODO: 0.6.6:	
 	QImage *newImage = 0;
 
 	if (config_file.readBoolEntry("Look", "UseUserboxBackground", true))
@@ -1069,46 +1093,48 @@ void UserBox::setColorsOrBackgrounds()
 	}
 
 	if (newImage)
-		backgroundImage = newImage;
-	else
+	{
 		if (backgroundImage)
-		{
 			delete backgroundImage;
-			backgroundImage = 0;
-		}
 
-	FOREACH(userbox, UserBoxes)
-		(*userbox)->refreshBackground();
+		backgroundImage = newImage;
+	}
+	*/
+	foreach(UserBox *userbox, UserBoxes)
+		userbox->refreshBackground();
 }
 
-QValueList<UserBox *> UserBox::UserBoxes;
+QList<UserBox *> UserBox::UserBoxes;
 
-QValueList<UserBox::CmpFuncDesc> UserBox::compareFunctions() const
+QList<UserBox::CmpFuncDesc> UserBox::compareFunctions() const
 {
 	return comparer->CmpFunctions;
 }
 
-void UserBox::applyFilter(UserGroup *g)
+void UserBox::applyFilter(UserGroup *g, bool forceRefresh)
 {
 	kdebugf();
 	if (Filters.contains(g))
 		return;
 	Filters.append(g);
 	UserListElements users;
-	CONST_FOREACH(user, *VisibleUsers)
-		if (!g->contains(*user))
-			users.append(*user);
+	foreach(const UserListElement &user, *VisibleUsers)
+		if (!g->contains(user))
+			users.append(user);
 	VisibleUsers->removeUsers(users);
 	connect(g, SIGNAL(userAdded(UserListElement, bool, bool)),
 			this, SLOT(userAddedToGroup(UserListElement, bool, bool)));
 	connect(g, SIGNAL(userRemoved(UserListElement, bool, bool)),
 			this, SLOT(userRemovedFromGroup(UserListElement, bool, bool)));
-	refresh();
-	emit selectionChanged();
+	if (forceRefresh)
+	{
+		refresh();
+		emit selectionChanged();
+	}
 	kdebugf2();
 }
 
-void UserBox::removeFilter(UserGroup *g)
+void UserBox::removeFilter(UserGroup *g, bool forceRefresh)
 {
 	kdebugf();
 	if (!Filters.contains(g))
@@ -1124,14 +1150,14 @@ void UserBox::removeFilter(UserGroup *g)
 	Filters.pop_back(); //temporarily removing
 
 	UserListElements users;
-	CONST_FOREACH(user, *last)
+	foreach(const UserListElement &user, *last)
 	{
-		if (VisibleUsers->contains(*user)) // we are not looking for contacts which are certain
+		if (VisibleUsers->contains(user)) // we are not looking for contacts which are certain
 			continue;
 		bool omit = false;
 
-		CONST_FOREACH(ngroup, NegativeFilters)
-			if ((*ngroup)->contains(*user))
+		foreach(UserGroup *ngroup, NegativeFilters)
+			if (ngroup->contains(user))
 			{
 				omit = true;
 				break;
@@ -1139,8 +1165,8 @@ void UserBox::removeFilter(UserGroup *g)
 		if (omit)
 			continue;
 
-		CONST_FOREACH(group, Filters)
-			if (!(*group)->contains(*user))
+		foreach(UserGroup *group, Filters)
+			if (!group->contains(user))
 			{
 				omit = true;
 				break; // if belongs to any group, there is no point in checking further
@@ -1148,36 +1174,42 @@ void UserBox::removeFilter(UserGroup *g)
 		if (omit)
 			continue;
 
-		users.append(*user);
+		users.append(user);
 	}
 	Filters.append(last); // restoring
 	VisibleUsers->addUsers(users);
-	refresh();
-	emit selectionChanged();
+	if (forceRefresh)
+	{
+		refresh();
+		emit selectionChanged();
+	}
 	kdebugf2();
 }
 
-void UserBox::applyNegativeFilter(UserGroup *g)
+void UserBox::applyNegativeFilter(UserGroup *g, bool forceRefresh)
 {
 	kdebugf();
 	if (NegativeFilters.contains(g))
 		return;
 	NegativeFilters.append(g);
 	UserListElements users;
-	CONST_FOREACH(user, *VisibleUsers)
-		if (g->contains(*user))
-			users.append(*user);
+	foreach(const UserListElement &user, *VisibleUsers)
+		if (g->contains(user))
+			users.append(user);
 	VisibleUsers->removeUsers(users);
 	connect(g, SIGNAL(userAdded(UserListElement, bool, bool)),
 			this, SLOT(userRemovedFromGroup(UserListElement, bool, bool)));
 	connect(g, SIGNAL(userRemoved(UserListElement, bool, bool)),
 			this, SLOT(userAddedToGroup(UserListElement, bool, bool)));
-	refresh();
-	emit selectionChanged();
+	if (forceRefresh)
+	{
+		refresh();
+		emit selectionChanged();
+	}
 	kdebugf2();
 }
 
-void UserBox::removeNegativeFilter(UserGroup *g)
+void UserBox::removeNegativeFilter(UserGroup *g, bool forceRefresh)
 {
 	kdebugf();
 	if (!NegativeFilters.contains(g))
@@ -1189,11 +1221,11 @@ void UserBox::removeNegativeFilter(UserGroup *g)
 			this, SLOT(userAddedToGroup(UserListElement, bool, bool)));
 
 	UserListElements users;
-	CONST_FOREACH(user, *g)
+	foreach(const UserListElement &user, *g)
 	{
 		bool omit = false;
-		CONST_FOREACH(ngroup, NegativeFilters)
-			if ((*ngroup)->contains(*user))
+		foreach(UserGroup *ngroup, NegativeFilters)
+			if (ngroup->contains(user))
 			{
 				omit = true;
 				break;
@@ -1201,8 +1233,8 @@ void UserBox::removeNegativeFilter(UserGroup *g)
 		if (omit)
 			continue;
 
-		CONST_FOREACH(group, Filters)
-			if (!(*group)->contains(*user))
+		foreach(UserGroup *group, Filters)
+			if (!group->contains(user))
 			{
 				omit = true;
 				break;
@@ -1210,11 +1242,14 @@ void UserBox::removeNegativeFilter(UserGroup *g)
 		if (omit)
 			continue;
 
-		users.append(*user);
+		users.append(user);
 	}
 	VisibleUsers->addUsers(users);
-	refresh();
-	emit selectionChanged();
+	if (forceRefresh)
+	{
+		refresh();
+		emit selectionChanged();
+	}
 	kdebugf2();
 }
 
@@ -1227,8 +1262,8 @@ void UserBox::addCompareFunction(const QString &id, const QString &trDescription
 
 void UserBox::removeCompareFunction(const QString &id)
 {
-	FOREACH(c, comparer->CmpFunctions)
-		if ((*c).id == id)
+	foreach(const CmpFuncDesc &c, comparer->CmpFunctions)
+		if (c.id == id)
 		{
 			comparer->CmpFunctions.remove(c);
 			refreshLater();
@@ -1242,22 +1277,23 @@ bool UserBox::moveUpCompareFunction(const QString &id)
 	CmpFuncDesc d;
 	int pos = 0;
 	bool found = false;
-	FOREACH(c, comparer->CmpFunctions)
+	QList<CmpFuncDesc>::iterator c;
+	for (c = comparer->CmpFunctions.begin(); c != comparer->CmpFunctions.end(); ++c)
 	{
-		if ((*c).id == id)
-		{
-			found = true;
-			if (pos == 0)
-				break;
-			d = *c;
-			--c;
-			c = comparer->CmpFunctions.insert(c, d);
-			c += 2;
-			comparer->CmpFunctions.remove(c);
-			refreshLater();
-			break;
-		}
-		++pos;
+ 		if ((*c).id == id)
+ 		{
+ 			found = true;
+ 			if (pos == 0)
+ 				break;
+ 			d = *c;
+ 			--c;
+ 			c = comparer->CmpFunctions.insert(c, d);
+ 			c += 2;
+ 			comparer->CmpFunctions.remove(c);
+ 			refreshLater();
+ 			break;
+ 		}
+ 		++pos;
 	}
 	kdebugf2();
 	return found;
@@ -1270,22 +1306,23 @@ bool UserBox::moveDownCompareFunction(const QString &id)
 	int pos = 0;
 	int cnt = comparer->CmpFunctions.count();
 	bool found = false;
-	FOREACH(c, comparer->CmpFunctions)
+	QList<CmpFuncDesc>::iterator c;
+	for (c = comparer->CmpFunctions.begin(); c != comparer->CmpFunctions.end(); ++c)
 	{
-		if ((*c).id == id)
-		{
-			found = true;
-			if (pos == cnt - 1)
-				break;
-			d = *c;
-			++c;
-			c = comparer->CmpFunctions.insert(c, d);
-			c -= 2;
-			comparer->CmpFunctions.remove(c);
-			refreshLater();
-			break;
-		}
-		++pos;
+ 		if ((*c).id == id)
+ 		{
+ 			found = true;
+ 			if (pos == cnt - 1)
+ 				break;
+ 			d = *c;
+ 			++c;
+ 			c = comparer->CmpFunctions.insert(c, d);
+ 			c -= 2;
+ 			comparer->CmpFunctions.remove(c);
+ 			refreshLater();
+ 			break;
+ 		}
+ 		++pos;
 	}
 	kdebugf2();
 	return found;
@@ -1294,10 +1331,10 @@ bool UserBox::moveDownCompareFunction(const QString &id)
 void UserBox::sort()
 {
 //	FOREACH(u, sortHelper)
-//		kdebugm(KDEBUG_WARNING, ">>%s\n", (*u).altNick().local8Bit().data());
+//		kdebugm(KDEBUG_WARNING, ">>%s\n", qPrintable((*u).altNick()));
 	std::sort(sortHelper.begin(), sortHelper.end(), *comparer);
 //	FOREACH(u, sortHelper)
-//		kdebugm(KDEBUG_ERROR, ">>%s\n", (*u).altNick().local8Bit().data());
+//		kdebugm(KDEBUG_ERROR, ">>%s\n", qPrintable((*u).altNick()));
 }
 
 void UserBox::removingProtocol(UserListElement /*elem*/, QString /*protocolName*/, bool /*massively*/, bool /*last*/)
@@ -1309,7 +1346,7 @@ void UserBox::removingProtocol(UserListElement /*elem*/, QString /*protocolName*
 void UserBox::userDataChanged(UserListElement /*elem*/, QString name, QVariant /*oldValue*/,
 					QVariant /*currentValue*/, bool /*massively*/, bool /*last*/)
 {
-	if (name != "AltNick" && name != "Mobile" && name != "HideDescription") // we are not interested in other names
+	if (name != "AltNick" && name != "Mobile" && name != "Email" && name != "HideDescription") // we are not interested in other names
 		return;
 	refreshLater();
 }
@@ -1390,16 +1427,16 @@ void UserBox::userAddedToGroup(UserListElement elem, bool massively, bool last)
 	const UserGroup *s = static_cast<const UserGroup *>(sender());
 //	kdebugm(KDEBUG_INFO, "sender name: '%s'\n", s->name());
 	bool append = true;
-	CONST_FOREACH(group, NegativeFilters)
-		if ((*group)->contains(elem))
+	foreach(UserGroup *group, NegativeFilters)
+		if (group->contains(elem))
 		{
 			append = false;
 			break;
 		}
 //	kdebugm(KDEBUG_WARNING, "%d %d %d\n", append, massively, last);
 	if (append)
-		CONST_FOREACH(group, Filters)
-			if (!(*group)->contains(elem))
+		foreach(UserGroup *group, Filters)
+			if (!group->contains(elem))
 			{
 				append = false;
 				break;
@@ -1443,17 +1480,51 @@ void UserBox::userRemovedFromGroup(UserListElement elem, bool massively, bool la
 //	kdebugf2();
 }
 
+void UserBox::contextMenuEvent(QContextMenuEvent *event)
+{
+	if (!itemAt(event->pos()))
+		return;
+
+	QMenu *menu = new QMenu(this);
+
+	foreach (ActionDescription *actionDescription, UserBox::UserBoxActions)
+	{
+		if (actionDescription)
+		{
+			KaduAction *action = actionDescription->createAction(MainWindow);
+			menu->addAction(action);
+			action->checkState();
+		}
+		else
+			menu->addSeparator();
+	}
+
+	QMenu *management = menu->addMenu(tr("User management"));
+
+	foreach (ActionDescription *actionDescription, UserBox::ManagementActions)
+		if (actionDescription)
+		{
+			KaduAction *action = actionDescription->createAction(MainWindow);
+			management->addAction(action);
+			action->checkState();
+		}
+		else
+			management->addSeparator();
+
+	menu->exec(event->globalPos());
+}
+
 const UserGroup *UserBox::visibleUsers() const
 {
 	return VisibleUsers;
 }
 
-QValueList<UserGroup *> UserBox::filters() const
+QList<UserGroup *> UserBox::filters() const
 {
 	return Filters;
 }
 
-QValueList<UserGroup *> UserBox::negativeFilters() const
+QList<UserGroup *> UserBox::negativeFilters() const
 {
 	return NegativeFilters;
 }
@@ -1465,7 +1536,7 @@ bool UserBox::currentUserExists() const
 
 UserListElement UserBox::currentUser() const
 {
-	QListBoxItem *i = item(currentItem());
+	Q3ListBoxItem *i = item(currentItem());
 	if (i)
 		return static_cast<KaduListBoxPixmap *>(i)->User;
 	else
@@ -1476,27 +1547,44 @@ UserListElement UserBox::currentUser() const
 	}
 }
 
-UlesDrag::UlesDrag(const QStringList &ules, QWidget* dragSource, const char* name)
-	: DragSimple("application/x-kadu-ules", ules.join("\n"), dragSource, name)
+UlesDrag::UlesDrag(const QStringList &ules, QWidget* dragSource)
+	: QDrag(dragSource)
 {
 	kdebugf();
+
+	QByteArray data;
+	QMimeData *mimeData = new QMimeData;
+	QString allUles = ules.join("\n");
+
+	data = allUles.toUtf8(); 
+
+     	mimeData->setData("application/x-kadu-ules", data);
+
+	setMimeData(mimeData);
+
 	kdebugf2();
 }
 
-bool UlesDrag::decode(const QMimeSource *source, QStringList &ules)
+bool UlesDrag::decode(QDropEvent *event, QStringList &ules)
 {
-	QTextStream stream(source->encodedData("application/x-kadu-ules"), IO_ReadOnly);
-	stream.setCodec(QTextCodec::codecForLocale());
+	const QMimeData *mimeData = event->mimeData();
+
+	if (!mimeData->hasFormat("application/x-kadu-ules"))
+		return false;
+
+	QTextStream stream(mimeData->data("application/x-kadu-ules"), QIODevice::ReadOnly);
+	stream.setCodec("UTF-8");
+
+	QString allUles = stream.readAll();
 
-	QString allUles = stream.read();
 	ules = QStringList::split("\n", allUles);
 
 	return ules.count() > 0;
 }
 
-bool UlesDrag::canDecode(const QMimeSource *source)
+bool UlesDrag::canDecode(QDragEnterEvent *event)
 {
-	return source->provides("application/x-kadu-ules");
+	return event->mimeData()->hasFormat("application/x-kadu-ules");
 }
 
 inline int compareAltNick(const UserListElement &u1, const UserListElement &u2)
