@@ -7,11 +7,12 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qvbox.h>
-#include <qvgroupbox.h>
+#include <QtGui/QGroupBox>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <QtGui/QPushButton>
 
 #include "config_file.h"
 #include "debug.h"
@@ -25,60 +26,76 @@
  * @ingroup account_management
  * @{
  */
-RemindPassword::RemindPassword(QDialog *parent, const char *name) : QHBox(parent, name, WDestructiveClose),
-	emailedit(0), layoutHelper(new LayoutHelper())
+RemindPassword::RemindPassword(QDialog *parent) : QWidget(parent, Qt::Window),
+	emailedit(0)
 {
 	kdebugf();
 
-	setCaption(tr("Remind password"));
-	layout()->setResizeMode(QLayout::Minimum);
+	setWindowTitle(tr("Remind password"));
+	setAttribute(Qt::WA_DeleteOnClose);
 
 	// create main QLabel widgets (icon and app info)
-	QVBox *left = new QVBox(this);
-	left->setMargin(10);
-	left->setSpacing(10);
+	QWidget *left = new QWidget();
 
-	QLabel *l_icon = new QLabel(left);
-	QWidget *blank = new QWidget(left);
+	QLabel *l_icon = new QLabel;
+	l_icon->setPixmap(icons_manager->loadPixmap("RemindPasswordWindowIcon"));
+
+	QWidget *blank = new QWidget;
 	blank->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Expanding));
 
-	QVBox *center = new QVBox(this);
-	center->setMargin(10);
-	center->setSpacing(10);
+	QVBoxLayout *left_layout = new QVBoxLayout(left);
+	left_layout->addWidget(l_icon);
+	left_layout->addWidget(blank);
+
+	QWidget *center = new QWidget;
+
+	QLabel *l_info = new QLabel();
 
-	QLabel *l_info = new QLabel(center);
-	l_icon->setPixmap(icons_manager->loadIcon("RemindPasswordWindowIcon"));
 	l_info->setText(tr("This dialog box allows you to ask server to remind your current password."));
-	l_info->setAlignment(Qt::WordBreak);
+	l_info->setWordWrap(true);
+	l_info->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+
 	// end create main QLabel widgets (icon and app info)
 
 	//our QVGroupBox
-	QVGroupBox *vgb_email = new QVGroupBox(center);
-	vgb_email->setTitle(tr("Email"));
+	QGroupBox *vgb_email = new QGroupBox(tr("Email"));
+	QVBoxLayout *email_layout = new QVBoxLayout(vgb_email);
 	//end our QGroupBox
 
 	// create needed fields
-
-	new QLabel(tr("Email (as during registration):"), vgb_email);
-	emailedit = new QLineEdit(vgb_email);
-
+	emailedit = new QLineEdit();
+	email_layout->addWidget(new QLabel(tr("Email (as during registration):")));
+	email_layout->addWidget(emailedit);
 	// end create needed fields
 
 	// buttons
-	QHBox *bottom = new QHBox(center);
-	QWidget *blank2 = new QWidget(bottom);
-	bottom->setSpacing(5);
-	blank2->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
-	QPushButton *pb_ok = new QPushButton(icons_manager->loadIcon("RemindPasswordButton"), tr("OK"), bottom, "ok");
-	QPushButton *pb_close = new QPushButton(icons_manager->loadIcon("CloseWindow"), tr("&Close"), bottom, "close");
-	// end buttons
+	QWidget *bottom = new QWidget;
 
-	connect(pb_close, SIGNAL(clicked()), this, SLOT(close()));
+	QWidget *blank2 = new QWidget;
+	blank2->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
+
+	QPushButton *pb_ok = new QPushButton(icons_manager->loadIcon("RemindPasswordButton"), tr("OK"), bottom, "ok");
 	connect(pb_ok, SIGNAL(clicked()), this, SLOT(start()));
 
-	layoutHelper->addLabel(l_info);
+	QPushButton *pb_close = new QPushButton(icons_manager->loadIcon("CloseWindow"), tr("&Close"), bottom, "close");
+	connect(pb_close, SIGNAL(clicked()), this, SLOT(close()));
 
-	loadGeometry(this, "General", "RemindPasswordDialogGeometry", 0, 30, 355, 200);
+	QHBoxLayout *bottom_layout = new QHBoxLayout(bottom);
+	bottom_layout->addWidget(blank2);
+	bottom_layout->addWidget(pb_ok);
+	bottom_layout->addWidget(pb_close);
+	// end buttons
+
+	QVBoxLayout *center_layout = new QVBoxLayout(center);
+	center_layout->addWidget(l_info);
+	center_layout->addWidget(vgb_email);
+	center_layout->addWidget(bottom);
+
+	QHBoxLayout *layout = new QHBoxLayout(this);
+	layout->addWidget(left);
+	layout->addWidget(center);
+
+	loadWindowGeometry(this, "General", "RemindPasswordDialogGeometry", 0, 50, 355, 200);
 	connect(gadu, SIGNAL(reminded(bool)), this, SLOT(reminded(bool)));
 
 	kdebugf2();
@@ -88,17 +105,11 @@ RemindPassword::~RemindPassword()
 {
 	kdebugf();
 
-	saveGeometry(this, "General", "RemindPasswordDialogGeometry");
-	delete layoutHelper;
+	saveWindowGeometry(this, "General", "RemindPasswordDialogGeometry");
 
 	kdebugf2();
 }
 
-void RemindPassword::resizeEvent(QResizeEvent * /*e*/)
-{
-	layoutHelper->resizeLabels();
-}
-
 void RemindPassword::keyPressEvent(QKeyEvent* ke_event)
 {
 	if (ke_event->key() == Qt::Key_Escape)
