@@ -7,16 +7,13 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qapplication.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qcursor.h>
-#include <qfile.h>
-#include <qhgroupbox.h>
-#include <qspinbox.h>
-#include <qtextstream.h>
+#include <QtGui/QApplication>
+#include <QtGui/QCheckBox>
+#include <QtGui/QSpinBox>
 
-#include <string.h>
+#ifdef Q_OS_WIN
+#include <windows.h>
+#endif
 
 #include "autoaway.h"
 #include "config_file.h"
@@ -31,7 +28,7 @@
  */
 AutoAway *autoAway = 0;
 
-extern "C" int autoaway_init()
+extern "C" KADU_EXPORT int autoaway_init(bool firstLoad)
 {
 	kdebugf();
 
@@ -43,7 +40,7 @@ extern "C" int autoaway_init()
 	return 0;
 }
 
-extern "C" void autoaway_close()
+extern "C" KADU_EXPORT void autoaway_close()
 {
 	kdebugf();
 
@@ -128,9 +125,12 @@ void AutoAwayStatusChanger::setChangeDescriptionTo(ChangeDescriptionTo newChange
 	descriptionAddon = newDescriptionAddon;
 }
 
-AutoAway::AutoAway(QObject* parent, const char *name)
-	: autoAwayStatusChanger(0), timer(0)
+AutoAway::AutoAway()
+	: autoAwayStatusChanger(0), timer(0), updateDescripion(true)
 {
+	connect(gadu, SIGNAL(connected()), this, SLOT(on()));
+	connect(gadu, SIGNAL(disconnected()), this, SLOT(off()));
+
 	createDefaultConfiguration();
 	configurationUpdated();
 }
@@ -150,6 +150,9 @@ AutoAway::~AutoAway()
 		autoAwayStatusChanger = 0;
 	}
 
+	disconnect(gadu, SIGNAL(connected()), this, SLOT(on()));
+	disconnect(gadu, SIGNAL(disconnected()), this, SLOT(off()));
+
 	qApp->removeEventFilter(this);
 }
 
@@ -212,6 +215,13 @@ void AutoAway::checkIdleTime()
 		idleTime = 0;
 	}
 
+#ifdef Q_OS_WIN
+	LASTINPUTINFO lpi;
+	lpi.cbSize=sizeof(LASTINPUTINFO);
+	GetLastInputInfo(&lpi);
+	idleTime=(GetTickCount() - lpi.dwTime)/1000;
+#else
+
 //	sprawdzenie czy wzrosla liczba obsluzonych przerwan klawiatury lub myszki
 	QFile f("/proc/interrupts");
 	if (f.open(IO_ReadOnly))
@@ -244,6 +254,7 @@ void AutoAway::checkIdleTime()
 			memcpy(interrupts, currentInterrupts, INTCOUNT*sizeof(interrupts[0]));
 		}
 	}
+#endif
 
 	idleTime += checkInterval;
 
@@ -252,6 +263,11 @@ void AutoAway::checkIdleTime()
 		autoAwayStatusChanger->setChangeDescriptionTo(changeTo, parseDescription(autoStatusText));
 		refreshStatusTime = idleTime + refreshStatusInterval;
 	}
+ 	else if (updateDescripion)
+        {
+		autoAwayStatusChanger->setChangeDescriptionTo(changeTo, parseDescription(autoStatusText));
+		updateDescripion = false;
+	}
 
 	if (idleTime >= autoDisconnectTime && autoDisconnectEnabled)
 		autoAwayStatusChanger->setChangeStatusTo(AutoAwayStatusChanger::ChangeStatusToOffline);
@@ -260,7 +276,10 @@ void AutoAway::checkIdleTime()
 	else if (idleTime >= autoAwayTime && autoAwayEnabled)
 		autoAwayStatusChanger->setChangeStatusTo(AutoAwayStatusChanger::ChangeStatusToBusy);
 	else
+	{
 		autoAwayStatusChanger->setChangeStatusTo(AutoAwayStatusChanger::NoChangeStatus);
+		updateDescripion = true;
+	}
 
 	if (idleTime < refreshStatusTime)
 		refreshStatusTime = refreshStatusInterval;
@@ -315,7 +334,7 @@ void AutoAway::configurationUpdated()
 
 	changeTo = (AutoAwayStatusChanger::ChangeDescriptionTo)config_file.readNumEntry("General", "AutoChangeDescription");
 
-	if (autoAwayEnabled || autoInvisibleEnabled || autoDisconnectEnabled)
+	if ((autoAwayEnabled || autoInvisibleEnabled || autoDisconnectEnabled) && !gadu->currentStatus().isOffline())
 		on();
 	else
 		off();
