@@ -1,89 +1,71 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="3"/>
         <source>Status</source>
         <translation>Status</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="9"/>
         <source>Autoaway</source>
         <translation>Autoaway</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="12"/>
         <source>Check idle every</source>
         <translation>Controlla  Iddle ogni</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="15"/>
         <source>Enable autoaway</source>
         <translation>Occupato automatico</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="18"/>
         <source>Set status to away after</source>
         <translation>Metti status Occupato dopo</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="21"/>
         <source>Enable autoinvisible</source>
         <translation>Attiva autoinvisibile</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="24"/>
         <source>Set status to invisible after</source>
         <translation>Metti status invisibile dopo</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="27"/>
         <source>Enable autodisconnect</source>
         <translation>Attiva autosconessione</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="30"/>
         <source>Disconnect after</source>
         <translation>Sconnetti dopo</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="38"/>
         <source>Description</source>
         <translation>Descrizione</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="41"/>
         <source>Don&apos;t change</source>
         <translation>Non cambiare descrizione</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="44"/>
         <source>Replace</source>
         <translation>Cambia</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="47"/>
         <source>Add in front</source>
         <translation>Aggiungi all&apos;inizio</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="50"/>
         <source>Add at the back</source>
         <translation>Agiungi alla fine</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="54"/>
         <source>New description</source>
         <translation>Nuovo descrizione</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="57"/>
         <source>Autorefresh status</source>
         <translation>Rinfrescare automatico</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="61"/>
         <source>Parse AutoStatus</source>
         <translation>Parse status automatico</translation>
     </message>
