@@ -7,17 +7,17 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qcheckbox.h>
-#include <qobject.h>
-#include <qpopupmenu.h>
-#include <qtimer.h>
-#include <qwindowdefs.h>
+#include <QtCore/QObject>
+#include <QtCore/QTimer>
+#include <QtGui/QApplication>
+#include <QtGui/QCursor>
+#include <QtGui/QMenu>
+#include <QtGui/QMouseEvent>
 
-#include "config_file.h"
+#include "kadu-core/config_file.h"
 #include "docking.h"
 #include "debug.h"
+#include "gadu.h"
 #include "icons_manager.h"
 #include "kadu.h"
 #include "pending_msgs.h"
@@ -30,17 +30,15 @@
  * @ingroup docking
  * @{
  */
-extern "C" int docking_init()
+extern "C" KADU_EXPORT int docking_init(bool firstLoad)
 {
-	create_netwm_atoms(qt_xdisplay());
-
 	docking_manager = new DockingManager();
 	MainConfigurationWindow::registerUiFile(dataPath("kadu/modules/configuration/docking.ui"), docking_manager);
 
 	return 0;
 }
 
-extern "C" void docking_close()
+extern "C" KADU_EXPORT void docking_close()
 {
 	kdebugf();
 
@@ -50,7 +48,7 @@ extern "C" void docking_close()
 }
 
 DockingManager::DockingManager()
-	: icon_timer(new QTimer(this, "icon_timer")), blink(false), newMessageIcon(StaticEnvelope)
+	: newMessageIcon(StaticEnvelope), icon_timer(new QTimer(this, "icon_timer")), blink(false)
 {
 	kdebugf();
 
@@ -58,8 +56,8 @@ DockingManager::DockingManager()
 
 	connect(icon_timer, SIGNAL(timeout()), this, SLOT(changeIcon()));
 
-	connect(kadu, SIGNAL(statusPixmapChanged(const QPixmap &, const QString &)),
-		this, SLOT(statusPixmapChanged(const QPixmap &, const QString &)));
+	connect(kadu, SIGNAL(statusPixmapChanged(const QIcon &, const QString &)),
+		this, SLOT(statusPixmapChanged(const QIcon &, const QString &)));
 	connect(&pending, SIGNAL(messageFromUserAdded(UserListElement)), this, SLOT(pendingMessageAdded()));
 	connect(&pending, SIGNAL(messageFromUserDeleted(UserListElement)), this, SLOT(pendingMessageDeleted()));
 
@@ -96,8 +94,8 @@ DockingManager::~DockingManager()
 {
 	kdebugf();
 
-	disconnect(kadu, SIGNAL(statusPixmapChanged(const QPixmap &, const QString &)),
-		this, SLOT(statusPixmapChanged(const QPixmap &, const QString &)));
+	disconnect(kadu, SIGNAL(statusPixmapChanged(const QIcon &, const QString &)),
+		this, SLOT(statusPixmapChanged(const QIcon &, const QString &)));
 	disconnect(&pending, SIGNAL(messageFromUserAdded(UserListElement)), this, SLOT(pendingMessageAdded()));
 	disconnect(&pending, SIGNAL(messageFromUserDeleted(UserListElement)), this, SLOT(pendingMessageDeleted()));
 
@@ -119,7 +117,7 @@ void DockingManager::changeIcon()
 		switch (newMessageIcon)
 		{
 			case AnimatedEnvelope:
-				emit trayMovieChanged(icons_manager->loadAnimatedIcon("MessageAnim"));
+				emit trayMovieChanged(icons_manager->iconPath("MessageAnim"));
 				break;
 			case StaticEnvelope:
 				emit trayPixmapChanged(icons_manager->loadIcon("Message"), "Message");
@@ -134,11 +132,13 @@ void DockingManager::changeIcon()
 				else
 				{
 					const UserStatus &stat = gadu->currentStatus();
-					emit trayPixmapChanged(stat.pixmap(), stat.toString());
+					emit trayPixmapChanged(QIcon(stat.pixmap()), stat.toString());
 					icon_timer->start(500,TRUE);
 					blink = false;
 				}
 				break;
+			case NoChange:
+				break;
 		}
 	}
 	else
@@ -164,7 +164,7 @@ void DockingManager::pendingMessageDeleted()
 	if (!pending.pendingMsgs())
 	{
 		const UserStatus &stat = gadu->currentStatus();
-		emit trayPixmapChanged(stat.pixmap(), stat.toString());
+		emit trayPixmapChanged(QIcon(stat.pixmap()), stat.toString());
 	}
 }
 
@@ -172,8 +172,8 @@ void DockingManager::defaultToolTip()
 {
 	if (config_file.readBoolEntry("General", "ShowTooltipInTray"))
 	{
-		QString tiptext = tr("Left click - hide / show window\nMiddle click or Left click - open message");
-		tiptext.append(tr("\n\nCurrent status:\n%1")
+		QString tiptext;
+		tiptext.append(tr("Current status:\n%1")
 			.arg(qApp->translate("@default", UserStatus::name(gadu->currentStatus().index()).ascii())));
 
 		if (gadu->currentStatus().hasDescription())
@@ -186,46 +186,51 @@ void DockingManager::defaultToolTip()
 void DockingManager::trayMousePressEvent(QMouseEvent * e)
 {
 	kdebugf();
-	if (e->button() == MidButton)
+	if (e->button() == Qt::MidButton)
 	{
 		emit mousePressMidButton();
 		return;
 	}
 
-	if (e->button() == LeftButton)
+	if (e->button() == Qt::LeftButton)
 	{
 		emit mousePressLeftButton();
 		kdebugm(KDEBUG_INFO, "minimized: %d, visible: %d\n", kadu->isMinimized(), kadu->isVisible());
 
-		if (pending.pendingMsgs() && e->state() != ControlButton)
+		if (pending.pendingMsgs() && (e->modifiers() != Qt::ControlModifier))
 		{
 			pending.openMessages();
 			return;
 		}
 
-		if (kadu->isMinimized() || !kadu->isVisible() || !kadu->isActiveWindow())
+		if(kadu->isMinimized())
+		{
+			kadu->showNormal();
+			activateWindow(kadu->winId());
+			return;
+		}
+		else if(kadu->isVisible())
+			kadu->hide();
+		else
 		{
 			kadu->show();
 			kadu->raise();
 
 			activateWindow(kadu->winId());
 		}
-		else
-			kadu->hide();
-
 		return;
 	}
 
-	if (e->button() == RightButton)
+	if (e->button() == Qt::RightButton)
 	{
 		emit mousePressRightButton();
-		showPopupMenu(dockMenu);
+		//showPopupMenu(dockMenu);
 		return;
 	}
 	kdebugf2();
 }
 
-void DockingManager::statusPixmapChanged(const QPixmap &icon, const QString &iconName)
+void DockingManager::statusPixmapChanged(const QIcon &icon, const QString &iconName)
 {
  	kdebugf();
 	emit trayPixmapChanged(icon, iconName);
@@ -233,9 +238,9 @@ void DockingManager::statusPixmapChanged(const QPixmap &icon, const QString &ico
 	changeIcon();
 }
 
-QPixmap DockingManager::defaultPixmap()
+QIcon DockingManager::defaultPixmap()
 {
-	return gadu->currentStatus().pixmap();
+	return QIcon(gadu->currentStatus().pixmap());
 }
 
 void DockingManager::setDocked(bool docked, bool butDontHideOnClose)
@@ -262,7 +267,11 @@ void DockingManager::createDefaultConfiguration()
 {
 	config_file.addVariable("General", "RunDocked", false);
 	config_file.addVariable("General", "ShowTooltipInTray", true);
+#ifdef Q_OS_MAC
+	config_file.addVariable("Look", "NewMessageIcon", 3);
+#else
 	config_file.addVariable("Look", "NewMessageIcon", 0);
+#endif
 }
 
 DockingManager* docking_manager = NULL;
