@@ -7,18 +7,15 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qcheckbox.h>
-#include <qfile.h>
-#include <qhgroupbox.h>
-#include <qpushbutton.h>
-#include <qtooltip.h>
-#include <stdlib.h>
+#include <QtGui/QGridLayout>
+#include <QtGui/QLabel>
 
 #include "action.h"
 #include "chat_widget.h"
 #include "chat_manager.h"
+#include "chat_edit_box.h"
+#include "config_file.h"
 #include "debug.h"
-#include "encryption.h"
 #include "keys_manager.h"
 #include "gadu.h"
 #include "icons_manager.h"
@@ -27,6 +24,8 @@
 #include "toolbar.h"
 #include "userbox.h"
 
+#include "encryption.h"
+
 extern "C"
 {
 #include "simlite.h"
@@ -42,15 +41,15 @@ extern "C"
 
 EncryptionManager* encryption_manager;
 
-extern "C" int encryption_init()
+extern "C" KADU_EXPORT int encryption_init(bool firstLoad)
 {
-	encryption_manager = new EncryptionManager();
+	encryption_manager = new EncryptionManager(firstLoad);
 	MainConfigurationWindow::registerUiFile(dataPath("kadu/modules/configuration/encryption.ui"), encryption_manager);
 
 	return 0;
 }
 
-extern "C" void encryption_close()
+extern "C" KADU_EXPORT void encryption_close()
 {
 	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/encryption.ui"), encryption_manager);
 
@@ -58,7 +57,45 @@ extern "C" void encryption_close()
 	encryption_manager = 0;
 }
 
-EncryptionManager::EncryptionManager()
+void disableSendKey(KaduAction *action)
+{
+	kdebugf();
+
+	UserListElements ules=action->userListElements();
+
+	if (!ules.count())
+	{
+		action->setEnabled(false);
+		return;
+	}
+
+	QString keyfile_path;
+	keyfile_path.append(ggPath("keys/"));
+	keyfile_path.append(QString::number(config_file.readNumEntry("General", "UIN")));
+	keyfile_path.append(".pem");
+	QFileInfo keyfile(keyfile_path);
+
+	if (!keyfile.permission(QFileInfo::ReadUser))
+	{
+		action->setEnabled(false);
+		return;
+	}
+
+	unsigned int myUin = config_file.readUnsignedNumEntry("General", "UIN");
+
+	foreach(const UserListElement &user, ules)
+	{
+		if (!user.usesProtocol("Gadu") || user.ID("Gadu").toUInt() == myUin)
+		{
+			action->setEnabled(false);
+			return;
+		}
+	}
+
+	action->setEnabled(true);
+}
+
+EncryptionManager::EncryptionManager(bool firstLoad)
 	: MenuId(0), EncryptionEnabled(), EncryptionPossible(), KeysManagerDialog(0)
 {
 	kdebugf();
@@ -67,30 +104,46 @@ EncryptionManager::EncryptionManager()
 
 	userlist->addPerContactNonProtocolConfigEntry("encryption_enabled", "EncryptionEnabled");
 
-	connect(gadu, SIGNAL(rawGaduReceivedMessageFilter(Protocol *, UserListElements, QCString&, QByteArray&, bool&)),
-			this, SLOT(decryptMessage(Protocol *, UserListElements, QCString&, QByteArray&, bool&)));
-	connect(gadu, SIGNAL(sendMessageFiltering(const UserListElements, QString &, bool &)),
-			this, SLOT(sendMessageFilter(const UserListElements, QString &, bool &)));
-	connect(UserBox::userboxmenu, SIGNAL(popup()), this, SLOT(userBoxMenuPopup()));
+	connect(gadu, SIGNAL(rawGaduReceivedMessageFilter(Protocol *, UserListElements, QString&, QByteArray&, bool&)),
+			this, SLOT(decryptMessage(Protocol *, UserListElements, QString&, QByteArray&, bool&)));
+	connect(gadu, SIGNAL(sendMessageFiltering(const UserListElements, QByteArray &, bool &)),
+			this, SLOT(sendMessageFilter(const UserListElements, QByteArray &, bool &)));
 
-	action = new Action("EncryptedChat", tr("Enable encryption for this conversation"),
-		"encryptionAction", Action::TypeChat);
-	action->setToggleAction(true);
-	connect(action, SIGNAL(activated(const UserGroup*, const QWidget*, bool)),
-		this, SLOT(encryptionActionActivated(const UserGroup*)));
-	connect(action, SIGNAL(addedToToolbar(const UserGroup*, ToolButton*, ToolBar*)),
-		this, SLOT(setupEncrypt(const UserGroup*)));
-	ToolBar::addDefaultAction("Chat toolbar 1", "encryptionAction", 4);
+	encryptionActionDescription = new ActionDescription(
+                	ActionDescription::TypeChat, "encryptionAction",
+			this, SLOT(encryptionActionActivated(QAction *, bool)),
+			"DecryptedChat", tr("Enable encryption for this conversation"),
+			true, tr("Disable encryption for this conversation"),
+			disableSendKey
+	);
+	connect(encryptionActionDescription, SIGNAL(actionCreated(KaduAction *)), this, SLOT(setupEncrypt(KaduAction *)));
 
-	UserBox::userboxmenu->addItemAtPos(2,"SendPublicKey", tr("Send my public key"), this, SLOT(sendPublicKey()));
-	
-	MenuId = kadu->mainMenu()->insertItem(icons_manager->loadIcon("KeysManager"), tr("Manage keys"), this, SLOT(showKeysManagerDialog()), 0, -1, 12);
-	icons_manager->registerMenuItem(kadu->mainMenu(), tr("Manage keys"), "KeysManager");
+	if (firstLoad)
+		ChatEditBox::addAction("encryptionAction");
 
-	sim_key_path = strdup(ggPath("keys/").local8Bit());
+	sendPublicKeyActionDescription = new ActionDescription(
+		ActionDescription::TypeUser, "sendPublicKeyAction",
+		this, SLOT(sendPublicKeyActionActivated(QAction *, bool)),
+		"SendPublicKey", tr("Send my public key"), false, QString::null,
+		disableSendKey
+	);
+	UserBox::insertActionDescription(2, sendPublicKeyActionDescription);
+
+	keysManagerActionDescription = new ActionDescription(
+		ActionDescription::TypeGlobal, "keysManagerAction",
+		this, SLOT(showKeysManagerDialog(QAction *, bool)),
+		"KeysManager", tr("Manage keys")
+	);
+	kadu->insertMenuActionDescription(12, keysManagerActionDescription);
+
+	sim_key_path = strdup(qPrintable(QDir::toNativeSeparators(ggPath("keys/"))));
 
 	// use mkdir from sys/stat.h - there's no easy way to set permissions through Qt
-	mkdir(ggPath("keys").local8Bit().data(), 0700);
+#ifdef Q_OS_WIN
+	QDir().mkdir(ggPath("keys"));
+#else
+	mkdir(qPrintable(ggPath("keys")), 0700);
+#endif
 
 	kdebugf2();
 }
@@ -98,18 +151,19 @@ EncryptionManager::EncryptionManager()
 EncryptionManager::~EncryptionManager()
 {
 	kdebugf();
-	kadu->mainMenu()->removeItem(MenuId);
-	int sendkeyitem = UserBox::userboxmenu->getItem(tr("Send my public key"));
-	UserBox::userboxmenu->removeItem(sendkeyitem);
 
-	disconnect(gadu, SIGNAL(rawGaduReceivedMessageFilter(Protocol *, UserListElements, QCString&, QByteArray&, bool&)),
-			this, SLOT(decryptMessage(Protocol *, UserListElements, QCString&, QByteArray&, bool&)));
-	disconnect(gadu, SIGNAL(sendMessageFiltering(const UserListElements, QString &, bool &)),
-			this, SLOT(sendMessageFilter(const UserListElements, QString &, bool &)));
-	disconnect(UserBox::userboxmenu,SIGNAL(popup()),this,SLOT(userBoxMenuPopup()));
+	kadu->removeMenuActionDescription(keysManagerActionDescription);
+	delete keysManagerActionDescription;
+
+	disconnect(gadu, SIGNAL(rawGaduReceivedMessageFilter(Protocol *, UserListElements, QString&, QByteArray&, bool&)),
+			this, SLOT(decryptMessage(Protocol *, UserListElements, QString&, QByteArray&, bool&)));
+	disconnect(gadu, SIGNAL(sendMessageFiltering(const UserListElements, QByteArray &, bool &)),
+			this, SLOT(sendMessageFilter(const UserListElements, QByteArray &, bool &)));
+
+	delete encryptionActionDescription;
+	UserBox::removeActionDescription(sendPublicKeyActionDescription);
+	delete sendPublicKeyActionDescription;
 
-	delete action;
-	action = 0;
 	kdebugf2();
 }
 
@@ -143,9 +197,20 @@ void EncryptionManager::generateMyKeys()
 	kdebugf2();
 }
 
-void EncryptionManager::setupEncrypt(const UserGroup *group)
+void EncryptionManager::setupEncrypt(KaduAction *action)
 {
 	kdebugf();
+
+	ChatEditBox *chatEditBox = dynamic_cast<ChatEditBox *>(action->parent());
+	if (!chatEditBox)
+		return;
+
+	ChatWidget *chatWidget = chatEditBox->chatWidget();
+	if (!chatWidget)
+		return;
+
+	const UserGroup *group = chatWidget->users();
+
 	QString keyfile_path;
 	keyfile_path.append(ggPath("keys/"));
 	keyfile_path.append((*(*group).constBegin()).ID("Gadu"));
@@ -157,7 +222,7 @@ void EncryptionManager::setupEncrypt(const UserGroup *group)
 	bool encrypt = false;
 	if (encryption_possible)
 	{
-		QVariant v = chat_manager->getChatWidgetProperty(group, "EncryptionEnabled");
+		QVariant v = chat_manager->chatWidgetProperty(group, "EncryptionEnabled");
 		if (v.isValid())
 			encrypt = v.toBool();
 		else if ((*(group->constBegin())).data("EncryptionEnabled").isValid())
@@ -166,54 +231,56 @@ void EncryptionManager::setupEncrypt(const UserGroup *group)
 			encrypt = config_file.readBoolEntry("Chat", "Encryption");
 	}
 
-	ChatWidget *chat = chat_manager->findChatWidget(group);
-	setupEncryptButton(chat, encrypt);
+	setupEncryptButton(chatEditBox, encrypt);
 	setupEncryptionButtonForUsers(group->toUserListElements(), encryption_possible);
-	EncryptionPossible[chat] = encryption_possible;
+	EncryptionPossible[chatWidget] = encryption_possible;
 
 	kdebugf2();
 }
 
-void EncryptionManager::setupEncryptButton(ChatWidget* chat,bool enabled)
+void EncryptionManager::setupEncryptButton(ChatEditBox* chatEditBox, bool enabled)
 {
 	kdebugf();
-	EncryptionEnabled[chat] = enabled;
-	QValueList<ToolButton*> buttons =
-		KaduActions["encryptionAction"]->toolButtonsForUserListElements(
-			chat->users()->toUserListElements());
-	CONST_FOREACH(i, buttons)
+
+	ChatWidget *chatWidget = chatEditBox->chatWidget();
+	if (!chatWidget)
+		return;
+
+	EncryptionEnabled[chatWidget] = enabled;
+
+	QAction *action = encryptionActionDescription->action(chatEditBox);
+	if (action)
 	{
-		QToolTip::remove(*i);
 		if (enabled)
-		{
-			QToolTip::add(*i, tr("Disable encryption for this conversation"));
-			(*i)->setIconSet(icons_manager->loadIconSet("EncryptedChat"));
-			(*i)->setOn(true);
-		}
+			action->setChecked(true);
 		else
-		{
-			QToolTip::add(*i, tr("Enable encryption for this conversation"));
-			(*i)->setIconSet(icons_manager->loadIconSet("DecryptedChat"));
-			(*i)->setOn(false);
-		}
+			action->setChecked(false);
 	}
-	chat_manager->setChatWidgetProperty(chat->users(), "EncryptionEnabled", QVariant(enabled));
-	if (chat->users()->count() == 1)
-		(*(chat->users()->begin())).setData("EncryptionEnabled", enabled ? "true" : "false");
+
+	chat_manager->setChatWidgetProperty(chatWidget->users(), "EncryptionEnabled", QVariant(enabled));
+	if (chatWidget->users()->count() == 1)
+		(*(chatWidget->users()->begin())).setData("EncryptionEnabled", enabled ? "true" : "false");
 	kdebugf2();
 }
 
-void EncryptionManager::encryptionActionActivated(const UserGroup* users)
+void EncryptionManager::encryptionActionActivated(QAction *sender, bool toggled)
 {
 	kdebugf();
-	ChatWidget* chat= chat_manager->findChatWidget(users);
-	setupEncryptButton(chat,!EncryptionEnabled[chat]);
-	if (KeysManagerDialog!=NULL)
-		KeysManagerDialog->turnContactEncryptionText((*(*users).constBegin()).ID("Gadu"), EncryptionEnabled[chat]);
+
+	KaduMainWindow *kaduMainWindow = dynamic_cast<KaduMainWindow *>(sender->parent());
+	if (!kaduMainWindow)
+		return;
+
+	ChatWidget *chatWidget = chat_manager->findChatWidget(kaduMainWindow->userListElements());
+	if (!chatWidget)
+		return;
+	setupEncryptButton(chatWidget->getChatEditBox(), !EncryptionEnabled[chatWidget]);
+	if (KeysManagerDialog)
+		KeysManagerDialog->turnContactEncryptionText((*chatWidget->users()->constBegin()).ID("Gadu"), EncryptionEnabled[chatWidget]);
 	kdebugf2();
 }
 
-void EncryptionManager::decryptMessage(Protocol *protocol, UserListElements senders, QCString &msg, QByteArray &formats, bool &ignore)
+void EncryptionManager::decryptMessage(Protocol *protocol, UserListElements senders, QString &msg, QByteArray &formats, bool &ignore)
 {
 	kdebugf();
 	if (msg.length() < 30)
@@ -253,7 +320,7 @@ void EncryptionManager::decryptMessage(Protocol *protocol, UserListElements send
 		color.blue = new_color.blue();
 
 		QByteArray new_formats(
-			formats.size()+sizeof(format)+sizeof(color));
+			formats.size() + sizeof(format) + sizeof(color));
 		char* dst = new_formats.data();
 		memcpy(dst, &format, sizeof(format));
 		dst += sizeof(format);
@@ -277,11 +344,12 @@ void EncryptionManager::decryptMessage(Protocol *protocol, UserListElements send
 
 void EncryptionManager::setupEncryptionButtonForUsers(UserListElements users, bool enabled)
 {
-	kdebugf();
-	QValueList<ToolButton*> buttons =
-		KaduActions["encryptionAction"]->toolButtonsForUserListElements(users);
-	CONST_FOREACH(i, buttons)
-		(*i)->setEnabled(enabled);
+	kdebugf(); 
+	foreach (KaduAction *action, encryptionActionDescription->actions())
+	{
+		if (action->userListElements() == users)
+			action->setEnabled(enabled);
+	}
 	kdebugf2();
 }
 
@@ -289,17 +357,17 @@ void EncryptionManager::turnEncryption(UserGroup *group, bool on)
 {
 	ChatWidget *chat = chat_manager->findChatWidget(group->toUserListElements());
 	if (chat)
-		setupEncryptButton(chat, on);
+		setupEncryptButton(chat->getChatEditBox(), on);
 	else
 	{
 		chat_manager->setChatWidgetProperty(group, "EncryptionEnabled", QVariant(on));
 		(*(group->begin())).setData("EncryptionEnabled", (on ? "true" : "false"));
 	}
-	if (KeysManagerDialog!=NULL)
+	if (KeysManagerDialog)
 		KeysManagerDialog->turnContactEncryptionText((*(*group).constBegin()).ID("Gadu"), on);
 }
 
-void EncryptionManager::sendMessageFilter(const UserListElements users, QString &msg, bool &stop)
+void EncryptionManager::sendMessageFilter(const UserListElements users, QByteArray &msg, bool &stop)
 {
 
 	ChatWidget* chat = chat_manager->findChatWidget(users);
@@ -307,7 +375,7 @@ void EncryptionManager::sendMessageFilter(const UserListElements users, QString
 	if (users.count() == 1 && EncryptionEnabled[chat])
 	{
 		char *msg_c = sim_message_encrypt((const unsigned char *)msg.data(), (*users.constBegin()).ID("Gadu").toUInt());
-		if (msg_c == NULL)
+		if (!msg_c)
 		{
 			kdebugm(KDEBUG_ERROR, "sim_message_encrypt returned NULL! sim_errno=%d sim_strerror=%s\n", sim_errno, sim_strerror(sim_errno));
 			stop = true;
@@ -315,57 +383,28 @@ void EncryptionManager::sendMessageFilter(const UserListElements users, QString
 		}
 		else
 		{
-			msg = msg_c;
+			msg = QByteArray(msg_c);
+
 			free(msg_c);
 		}
 	}
 //	kdebugm(KDEBUG_INFO, "length: %d\n", msg.length());
 }
 
-void EncryptionManager::userBoxMenuPopup()
-{
-	kdebugf();
-	int sendkeyitem = UserBox::userboxmenu->getItem(tr("Send my public key"));
-
-	UserBox *activeUserBox = UserBox::activeUserBox();
-	if (activeUserBox == NULL)
-		return;
-
-	QString keyfile_path;
-	keyfile_path.append(ggPath("keys/"));
-	keyfile_path.append(QString::number(config_file.readNumEntry("General", "UIN")));
-	keyfile_path.append(".pem");
-	QFileInfo keyfile(keyfile_path);
-
-	bool sendKeyEnabled = true;
-	if (keyfile.permission(QFileInfo::ReadUser) && !gadu->currentStatus().isOffline())
-	{
-		unsigned int myUin = config_file.readUnsignedNumEntry("General", "UIN");
-		UserListElements users = activeUserBox->selectedUsers();
-
-		CONST_FOREACH(user, users)
-			if (!(*user).usesProtocol("Gadu") || (*user).ID("Gadu").toUInt() == myUin)
-			{
-				sendKeyEnabled = false;
-				break;
-			}
-	}
-	else
-		sendKeyEnabled = false;
-
-	UserBox::userboxmenu->setItemVisible(sendkeyitem, sendKeyEnabled);
-	kdebugf2();
-}
-
-void EncryptionManager::sendPublicKey()
+void EncryptionManager::sendPublicKeyActionActivated(QAction *sender, bool toggled)
 {
 	kdebugf();
 	QString keyfile_path;
 	QString mykey;
 	QFile keyfile;
 
-	UserBox *activeUserBox = UserBox::activeUserBox();
-	if (activeUserBox == NULL)
+	KaduMainWindow *kaduMainWindow = dynamic_cast<KaduMainWindow *>(sender->parent());
+	if (!kaduMainWindow)
+		return;
+
+	UserListElements users = kaduMainWindow->userListElements();
+
+	if (!users.count())
 		return;
 
 	keyfile_path.append(ggPath("keys/"));
@@ -374,14 +413,13 @@ void EncryptionManager::sendPublicKey()
 
 	keyfile.setName(keyfile_path);
 
-	if (keyfile.open(IO_ReadOnly))
+	if (keyfile.open(QIODevice::ReadOnly))
 	{
 		QTextStream t(&keyfile);
 		mykey = t.read();
 		keyfile.close();
-		UserListElements users = activeUserBox->selectedUsers();
-		CONST_FOREACH(user, users)
-			gadu->sendMessage(*user, mykey);
+		foreach(const UserListElement &user, users)
+			(dynamic_cast<Protocol *>(gadu))->sendMessage(user, mykey);
 
 		MessageBox::msg(tr("Your public key has been sent"), false, "Information", kadu);
 	}
@@ -395,15 +433,15 @@ void EncryptionManager::createDefaultConfiguration()
 	config_file.addVariable("Look", "EncryptionColor", QColor(0, 127, 0));
 }
 
-void EncryptionManager::showKeysManagerDialog()
+void EncryptionManager::showKeysManagerDialog(QAction *sender, bool toggled)
 {
 	kdebugf();
-	if (KeysManagerDialog==NULL)
+	if (!KeysManagerDialog)
 	{
-		KeysManagerDialog=new KeysManager();
-		connect(KeysManagerDialog,SIGNAL(destroyed()),this,SLOT(keysManagerDialogDestroyed()));
-		connect(KeysManagerDialog,SIGNAL(keyRemoved(UserListElement)),this,SLOT(keyRemoved(UserListElement)));
-		connect(KeysManagerDialog,SIGNAL(turnEncryption(UserGroup*, bool)),this,SLOT(turnEncryption(UserGroup*, bool)));
+		KeysManagerDialog = new KeysManager();
+		connect(KeysManagerDialog, SIGNAL(destroyed()), this, SLOT(keysManagerDialogDestroyed()));
+		connect(KeysManagerDialog, SIGNAL(keyRemoved(UserListElement)), this, SLOT(keyRemoved(UserListElement)));
+		connect(KeysManagerDialog, SIGNAL(turnEncryption(UserGroup*, bool)), this, SLOT(turnEncryption(UserGroup*, bool)));
 		KeysManagerDialog->show();
 	}
 	else
@@ -417,7 +455,7 @@ void EncryptionManager::showKeysManagerDialog()
 void EncryptionManager::keysManagerDialogDestroyed()
 {
 	kdebugf();
-	KeysManagerDialog=NULL;
+	KeysManagerDialog = 0;
 	kdebugf2();
 }
 
@@ -428,7 +466,7 @@ void EncryptionManager::keyRemoved(UserListElement ule)
 	if (chat)
 	{
 		EncryptionPossible[chat] = false;
-		setupEncryptButton(chat, false);
+		setupEncryptButton(chat->getChatEditBox(), false);
 		setupEncryptionButtonForUsers(ules, false);
 	}
 }
@@ -442,26 +480,28 @@ void EncryptionManager::keyAdded(UserListElement ule)
 		KeysManagerDialog->refreshKeysList();
 }
 
-SavePublicKey::SavePublicKey(UserListElement user, QString keyData, QWidget *parent, const char *name) :
-	QDialog(parent, name, Qt::WDestructiveClose), user(user), keyData(keyData)
+SavePublicKey::SavePublicKey(UserListElement user, QString keyData, QWidget *parent)
+	 : QDialog(parent), 
+	user(user), keyData(keyData)
 {
 	kdebugf();
 
-	setCaption(tr("Save public key"));
+	setWindowTitle(tr("Save public key"));
+	setAttribute(Qt::WA_DeleteOnClose);
+
 	resize(200, 80);
 
-	QLabel *l_info;
 	QString text = tr("User %1 is sending you his public key. Do you want to save it?").arg(user.altNick());
 
-	l_info = new QLabel(text, this);
+	QLabel *l_info = new QLabel(text, this);
 
 	QPushButton *yesbtn = new QPushButton(tr("Yes"), this);
 	QPushButton *nobtn = new QPushButton(tr("No"), this);
 
-	QObject::connect(yesbtn, SIGNAL(clicked()), this, SLOT(yesClicked()));
-	QObject::connect(nobtn, SIGNAL(clicked()), this, SLOT(reject()));
+	connect(yesbtn, SIGNAL(clicked()), this, SLOT(yesClicked()));
+	connect(nobtn, SIGNAL(clicked()), this, SLOT(reject()));
 
-	QGridLayout *grid = new QGridLayout(this, 2, 2, 3, 3);
+	QGridLayout *grid = new QGridLayout(this);
 	grid->addMultiCellWidget(l_info, 0, 0, 0, 1);
 	grid->addWidget(yesbtn, 1, 0);
 	grid->addWidget(nobtn, 1, 1);
@@ -481,10 +521,10 @@ void SavePublicKey::yesClicked()
 	keyfile_path.append(".pem");
 	keyfile.setName(keyfile_path);
 
-	if (!(keyfile.open(IO_WriteOnly)))
+	if (!(keyfile.open(QIODevice::WriteOnly)))
 	{
 		MessageBox::msg(tr("Error writting the key"), false, "Warning", this);
-		kdebugmf(KDEBUG_ERROR, "Error opening key file %s\n", (const char *)keyfile_path.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening key file %s\n", qPrintable(keyfile_path));
 		return;
 	}
 	else
