@@ -7,7 +7,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qpushbutton.h>
+#include <QtGui/QLabel>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPushButton>
 
 #include "config_file.h"
 #include "debug.h"
@@ -38,21 +40,21 @@ Hint::Hint(QWidget *parent, Notification *notification)
 	else
 		startSecs = secs = config_file.readNumEntry("Hints", "Event_" + notification->type() + "_timeout", 10);
 
-	createLabels(icons_manager->loadIcon(notification->icon()));
+	createLabels(icons_manager->loadPixmap(notification->icon()));
 	updateText();
 
-	callbacksBox = new QHBoxLayout();
-	vbox->addLayout(callbacksBox);
-
-	const QValueList<QPair<QString, const char *> > callbacks = notification->getCallbacks();
+	const QList<Notification::Callback> callbacks = notification->getCallbacks();
 	if (notification->getCallbacks().count())
 	{
+		QWidget *callbacksWidget = new QWidget(this);
+		callbacksBox = new QHBoxLayout(callbacksWidget);
 		callbacksBox->addStretch(10);
+		vbox->addWidget(callbacksWidget);
 
-		FOREACH(i, callbacks)
+		foreach(const Notification::Callback &i, callbacks)
 		{
-			QPushButton *button = new QPushButton((*i).first, this);
-			connect(button, SIGNAL(clicked()), notification, (*i).second);
+			QPushButton *button = new QPushButton(i.first, this);
+			connect(button, SIGNAL(clicked()), notification, i.second);
 			connect(button, SIGNAL(clicked()), notification, SLOT(clearDefaultCallback()));
 
 			callbacksBox->addWidget(button);
@@ -91,12 +93,11 @@ void Hint::configurationUpdated()
 	else
 		configurationDirective = "Event_" + notification->type();
 
-	QWidget w;
-
-	label->setFont(config_file.readFontEntry("Hints", configurationDirective + "_font"));
-	setPaletteForegroundColor(config_file.readColorEntry("Hints", configurationDirective + "_fgcolor", &paletteForegroundColor()));
 	bcolor = config_file.readColorEntry("Hints", configurationDirective + "_bgcolor", &paletteBackgroundColor());
-	setPaletteBackgroundColor(bcolor);
+	fcolor = config_file.readColorEntry("Hints", configurationDirective + "_fgcolor", &paletteForegroundColor());
+	label->setFont(config_file.readFontEntry("Hints", configurationDirective + "_font"));
+	QString style = narg("QWidget {color:%1; background-color:%2}", fcolor.name(), bcolor.name());
+	setStyleSheet(style);
 
 	setMinimumWidth(config_file.readNumEntry("Hints", "MinimumWidth", 100));
 	setMaximumWidth(config_file.readNumEntry("Hints", "MaximumWidth", 500));
@@ -108,21 +109,22 @@ void Hint::createLabels(const QPixmap &pixmap)
 	vbox->setSpacing(2);
 	vbox->setMargin(1);
 	vbox->setResizeMode(QLayout::FreeResize);
-
-	labels = new QHBoxLayout();
-	vbox->addLayout(labels);
-
+	QWidget *widget = new QWidget(this);
+	labels = new QHBoxLayout(widget);
+	labels->setContentsMargins(5, 5, 5, 5);
+	vbox->addWidget(widget);
 	if (!pixmap.isNull())
 	{
 		icon = new QLabel(this, "Icon");
 		icon->setPixmap(pixmap);
-		icon->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Ignored);
+		icon->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 		labels->addWidget(icon, 0, Qt::AlignTop);
 	}
 
 	label = new QLabel(this, "Label");
+	label->setTextInteractionFlags(Qt::NoTextInteraction);
 	label->setTextFormat(Qt::RichText);
-	label->setAlignment(AlignVCenter | Qt::AlignLeft);
+	label->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
 	labels->addWidget(label);
 }
 
@@ -151,7 +153,7 @@ void Hint::updateText()
 		{
 			int i = (count > 5) ? count - 5 : 0;
 
-			unsigned int citeSign = config_file.readUnsignedNumEntry("Hints","CiteSign");
+			int citeSign = config_file.readNumEntry("Hints","CiteSign");
 
 			QString itemSyntax = config_file.readEntry("Hints", "Event_" + notification->type() + "_detailSyntax", "\n&bull; <small>%1</small>");
 			for (; i < count; i++)
@@ -247,12 +249,14 @@ void Hint::mouseReleaseEvent(QMouseEvent *event)
 
 void Hint::enterEvent(QEvent *)
 {
-	setPaletteBackgroundColor(bcolor.light());
+	QString style = narg("QWidget {color:%1; background-color:%2}", fcolor.name(), bcolor.lighter().name());
+	setStyleSheet(style);
 }
 
 void Hint::leaveEvent(QEvent *)
 {
-	setPaletteBackgroundColor(bcolor);
+	QString style = narg("QWidget {color:%1; background-color:%2}", fcolor.name(), bcolor.name());
+	setStyleSheet(style);
 }
 
 void Hint::getData(QString &text, QPixmap &pixmap, unsigned int &timeout, QFont &font, QColor &fgcolor, QColor &bgcolor)
@@ -266,7 +270,7 @@ void Hint::getData(QString &text, QPixmap &pixmap, unsigned int &timeout, QFont
 
 	timeout = secs;
 	font = label->font();
-	fgcolor = label->paletteForegroundColor();
+	fgcolor = fcolor;
 	bgcolor = bcolor;
 }
 
