@@ -7,11 +7,12 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qapplication.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qspinbox.h>
-#include <qstylesheet.h>
+#include <QtGui/QApplication>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QDesktopWidget>
+#include <QtGui/QLabel>
+#include <QtGui/QSpinBox>
 
 #include "chat_widget.h"
 #include "chat_manager.h"
@@ -39,8 +40,11 @@ HintManager::HintManager(QWidget *parent, const char *name)	: Notifier(parent, n
 	hints(), tipFrame(0)
 {
 	kdebugf();
-	frame = new QFrame(parent, name, WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WX11BypassWM | WWinOwnDC);
-
+#ifdef Q_OS_MAC
+	frame = new QFrame(parent, name, Qt::FramelessWindowHint | Qt::SplashScreen | Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint |Qt::MSWindowsOwnDC);
+#else
+	frame = new QFrame(parent, name, Qt::FramelessWindowHint | Qt::Tool | Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint |Qt::MSWindowsOwnDC);
+#endif
 	frame->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 	frame->setFrameStyle(QFrame::Box | QFrame::Plain);
 	frame->setLineWidth(FRAME_WIDTH);
@@ -118,10 +122,9 @@ void HintManager::mainConfigurationWindowCreated(MainConfigurationWindow *mainCo
 	connect(maximumWidth, SIGNAL(valueChanged(int)), this, SLOT(maximumWidthChanged(int)));
 
 	overUserSyntax = mainConfigurationWindow->widgetById("hints/overUserSyntax");
-	QToolTip::add(overUserSyntax, qApp->translate("@default", Kadu::SyntaxText));
+	overUserSyntax->setToolTip(qApp->translate("@default", Kadu::SyntaxText));
 
-	toolTipClassesHighlighted((dynamic_cast<QComboBox *>(mainConfigurationWindow->widgetById("toolTipClasses")))->currentText());
-	connect(mainConfigurationWindow->widgetById("toolTipClasses"), SIGNAL(highlighted(const QString &)),
+	connect(mainConfigurationWindow->widgetById("toolTipClasses"), SIGNAL(currentIndexChanged(const QString &)),
 		this, SLOT(toolTipClassesHighlighted(const QString &)));
 }
 
@@ -174,7 +177,7 @@ void HintManager::setHint()
 
 	frame->adjustSize();
 	QSize preferredSize = frame->sizeHint();
-	QSize desktopSize = QApplication::desktop()->size();
+	QSize desktopSize = QApplication::desktop()->screenGeometry(frame).size();
 
 	emit searchingForTrayPosition(trayPosition);
 	if (config_file.readBoolEntry("Hints", "UseUserPosition") || trayPosition.isNull())
@@ -240,8 +243,8 @@ void HintManager::deleteHint(Hint *hint)
 {
 	kdebugf();
 
-	hints.remove(hint);
-	layout->remove(hint);
+	hints.removeAll(hint);
+	layout->removeWidget(static_cast<QWidget *>(hint));
 	hint->deleteLater();
 
 	kdebugf2();
@@ -258,7 +261,7 @@ void HintManager::oneSecond(void)
 	kdebugf();
 
 	bool removed = false;
-	for (unsigned int i = 0; i < hints.count(); ++i)
+	for (int i = 0; i < hints.count(); ++i)
 	{
 		hints.at(i)->nextSecond();
 
@@ -354,6 +357,12 @@ void HintManager::chatWidgetActivated(ChatWidget *chat)
 		linkedHints.remove(newMessage);
 	}
 
+	foreach(Hint *h, hints)
+	{
+		if (h->getUsers().equals(chat->users()) && !h->requireManualClosing())
+			deleteHint(h);
+	}
+
 	setHint();
 }
 
@@ -362,16 +371,10 @@ void HintManager::deleteAllHints()
 	kdebugf();
 	hint_timer->stop();
 
-	Hint *toDelete = hints.first();
-	while (toDelete)
+	foreach(Hint *h, hints)
 	{
-		if (!toDelete->requireManualClosing())
-		{
-			deleteHint(toDelete);
-			toDelete = hints.current();
-		}
-		else
-			toDelete = hints.next();
+		if(!h->requireManualClosing())
+			deleteHint(h);
 	}
 
 	if (hints.isEmpty())
@@ -390,7 +393,7 @@ Hint *HintManager::addHint(Notification *notification)
 	hints.append(hint);
 
 	setLayoutDirection();
-	layout->addWidget(hint);
+	layout->addWidget(static_cast<QWidget *>(hint));
 
 	connect(hint, SIGNAL(leftButtonClicked(Hint *)), this, SLOT(leftButtonSlot(Hint *)));
 	connect(hint, SIGNAL(rightButtonClicked(Hint *)), this, SLOT(rightButtonSlot(Hint *)));
@@ -413,20 +416,21 @@ void HintManager::setLayoutDirection()
 {
 	kdebugf();
 	QPoint trayPosition;
+	QSize desktopSize=QApplication::desktop()->screenGeometry(frame).size();
 	emit searchingForTrayPosition(trayPosition);
 	switch(config_file.readNumEntry("Hints", "NewHintUnder"))
 	{
 		case 0:
 			if (trayPosition.isNull() || config_file.readBoolEntry("Hints","UseUserPosition"))
 			{
-				if (config_file.readNumEntry("Hints","HintsPositionY") < QApplication::desktop()->size().height()/2)
+				if (config_file.readNumEntry("Hints","HintsPositionY") < desktopSize.height()/2)
 					layout->setDirection(QBoxLayout::Down);
 				else
 					layout->setDirection(QBoxLayout::Up);
 			}
 			else
 			{
-				if (trayPosition.y() < QApplication::desktop()->size().height()/2)
+				if (trayPosition.y() < desktopSize.height()/2)
 					layout->setDirection(QBoxLayout::Down);
 				else
 					layout->setDirection(QBoxLayout::Up);
@@ -456,7 +460,7 @@ void HintManager::showToolTip(const QPoint &point, const UserListElement &user)
 	if (tipFrame)
 		delete tipFrame;
 
-	tipFrame = new QFrame(0, "tip_frame", WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WX11BypassWM | WWinOwnDC);
+	tipFrame = new QFrame(0, "tip_frame", Qt::FramelessWindowHint | Qt::Tool | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint | Qt::MSWindowsOwnDC);
 	tipFrame->setFrameStyle(QFrame::Box | QFrame::Plain);
 	tipFrame->setLineWidth(FRAME_WIDTH);
 
@@ -465,16 +469,16 @@ void HintManager::showToolTip(const QPoint &point, const UserListElement &user)
 
 	QLabel *tipLabel = new QLabel(text, tipFrame);
 	tipLabel->setTextFormat(Qt::RichText);
-	tipLabel->setAlignment(AlignVCenter | AlignLeft);
+	tipLabel->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
 
 	lay->addWidget(tipLabel);
 
 	tipFrame->setFixedSize(tipLabel->sizeHint() + QSize(2 * FRAME_WIDTH, 2 * FRAME_WIDTH));
 
-	QPoint pos(kadu->userbox()->mapToGlobal(point) + QPoint(5, 5));
+	QPoint pos(point + QPoint(5, 5));
 
 	QSize preferredSize = tipFrame->sizeHint();
-	QSize desktopSize = QApplication::desktop()->size();
+	QSize desktopSize = QApplication::desktop()->screenGeometry(frame).size();
 	if (pos.x() + preferredSize.width() > desktopSize.width())
 		pos.setX(pos.x() - preferredSize.width() - 10);
 	if (pos.y() + preferredSize.height() > desktopSize.height())
@@ -613,7 +617,7 @@ void HintManager::createDefaultConfiguration()
 	// TODO: remove after removing import from 0.5
 	config_file.addVariable("Hints", "Event_NewChat_bgcolor", w.paletteBackgroundColor());
 	config_file.addVariable("Hints", "Event_NewChat_fgcolor", w.paletteForegroundColor());
-	config_file.addVariable("Hints", "Event_NewChat_font", defaultFont);
+	config_file.addVariable("Hints", "Event_NewChat_font", *defaultFont);
 	config_file.addVariable("Hints", "Event_NewChat_timeout", 10);
 	// end of TODO
 	config_file.addVariable("Hints", "HintsPositionX", 0);
@@ -628,7 +632,7 @@ void HintManager::createDefaultConfiguration()
 	config_file.addVariable("Hints", "SetAll", false); // TODO: fix
 	config_file.addVariable("Hints", "SetAll_bgcolor", w.paletteBackgroundColor());
 	config_file.addVariable("Hints", "SetAll_fgcolor", w.paletteForegroundColor());
-	config_file.addVariable("Hints", "SetAll_font", defaultFont);
+	config_file.addVariable("Hints", "SetAll_font", *defaultFont);
 	config_file.addVariable("Hints", "SetAll_timeout", 10);
 	config_file.addVariable("Hints", "ShowContentMessage", true);
 	config_file.addVariable("Hints", "UseUserPosition", false);
