@@ -7,32 +7,21 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qapplication.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qgrid.h>
-#include <qhbox.h>
-#include <qhgroupbox.h>
-#include <qmessagebox.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qregexp.h>
-#include <qsplitter.h>
-#include <qtimer.h>
-#include <qvbox.h>
-#include <qvbuttongroup.h>
+#include <QtCore/QDataStream>
+#include <QtCore/QTextStream>
+#include <QtCore/QTimer>
+#include <QtGui/QApplication>
+#include <QtGui/QMessageBox>
 
-// #include "config_dialog.h"
 #include "config_file.h"
 #include "debug.h"
-#include "emoticons.h"
 #include "gadu_images_manager.h"
-#include "history.h"
-#include "kadu.h"
-#include "kadu_text_browser.h"
 #include "html_document.h"
+#include "kadu.h"
 #include "misc.h"
 
+#include "history.h"
+
 enum {
 	HISTORYMANAGER_ORDINARY_LINE,
 	HISTORYMANAGER_HISTORY_OUR,
@@ -41,9 +30,10 @@ enum {
 	HISTORYMANAGER_SMS_WITHOUT_NICK
 };
 
-HistoryManager::HistoryManager(QObject *parent, const char *name) : QObject(parent, name), bufferedMessages(), imagesTimer(new QTimer(this, "imagesTimer"))
+HistoryManager::HistoryManager(QObject *parent) 
+	: QObject(parent), bufferedMessages(), imagesTimer(new QTimer(this))
 {
-	imagesTimer->start(1000*60);//60 sekund
+	imagesTimer->start(1000 * 60);//60 sekund
 	connect(imagesTimer, SIGNAL(timeout()), this, SLOT(checkImagesTimeouts()));
 	connect(userlist, SIGNAL(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)),
 		this, SLOT(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)));
@@ -70,9 +60,9 @@ QString HistoryManager::getFileNameByUinsList(UinsList uins)
 	{
 		uins.sort();
 		unsigned int i = 0, uinsCount = uins.count();
-		CONST_FOREACH(uin, uins)
+		foreach(const UinType &uin, uins)
 		{
-			fname.append(QString::number(*uin));
+			fname.append(QString::number(uin));
 			if (i++ < uinsCount - 1)
 				fname.append("_");
 		}
@@ -94,6 +84,7 @@ void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &ms
 
 	convHist2ekgForm(uins);
 	fname.append(getFileNameByUinsList(uins));
+	updateMessageDates(uins);
 
 	if (own)
 		if (chat)
@@ -118,15 +109,15 @@ void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &ms
 	line = linelist.join(",");
 
 	f.setName(fname);
-	if (!(f.open(IO_WriteOnly | IO_Append)))
+	if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", (const char *)fname.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(fname));
 		return;
 	}
 
 	buildIndexPrivate(fname);
 	fidx.setName(f.name() + ".idx");
-	if (fidx.open(IO_WriteOnly | IO_Append))
+	if (fidx.open(QIODevice::WriteOnly | QIODevice::Append))
 	{
 		offs = f.at();
 		fidx.writeBlock((const char *)&offs, sizeof(int));
@@ -143,7 +134,7 @@ void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &ms
 
 void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 {
-	kdebugmf(KDEBUG_FUNCTION_START, "appending sms to history (%s)\n", mobile.local8Bit().data());
+	kdebugmf(KDEBUG_FUNCTION_START, "appending sms to history (%s)\n", qPrintable(mobile));
 	QFile f, fidx;
 	QTextStream stream;
 	QStringList linelist;
@@ -161,11 +152,11 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 	linelist.append(QString::number(time(NULL)));
 	linelist.append(text2csv(html_msg));
 
-	CONST_FOREACH(i, *userlist)
-		if ((*i).mobile() == mobile)
+	foreach(const UserListElement &i, *userlist)
+		if (i.mobile() == mobile)
 		{
-			altnick = (*i).altNick();
-			uin = (*i).ID("Gadu").toUInt();;
+			altnick = i.altNick();
+			uin = i.ID("Gadu").toUInt();;
 			break;
 		}
 	if (uin)
@@ -179,7 +170,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 	line = linelist.join(",");
 
 	f.setName(ggPath("history/sms"));
-	if (!(f.open(IO_WriteOnly | IO_Append)))
+	if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening sms history file\n");
 		return;
@@ -187,7 +178,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 
 	buildIndexPrivate(f.name());
 	fidx.setName(f.name() + ".idx");
-	if (fidx.open(IO_WriteOnly | IO_Append))
+	if (fidx.open(QIODevice::WriteOnly | QIODevice::Append))
 	{
 		offs = f.at();
 		fidx.writeBlock((const char *)&offs, sizeof(int));
@@ -204,14 +195,14 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 		fname = ggPath("history/");
 		fname = fname + QString::number(uin);
 		f.setName(fname);
-		if (!(f.open(IO_WriteOnly | IO_Append)))
+		if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 		{
 			kdebugmf(KDEBUG_ERROR, "Error opening sms history\n");
 			return;
 		}
 
 		fidx.setName(f.name() + ".idx");
-		if (fidx.open(IO_WriteOnly | IO_Append))
+		if (fidx.open(QIODevice::WriteOnly | QIODevice::Append))
 		{
 			offs = f.at();
 			fidx.writeBlock((const char *)&offs, sizeof(int));
@@ -239,7 +230,7 @@ void HistoryManager::appendStatus(UinType uin, const UserStatus &status)
 	unsigned short port;
 //	struct in_addr in;
 
-	if (config_file.readBoolEntry("History", "DontSaveStatusChanges"))
+	if (!config_file.readBoolEntry("History", "SaveStatusChanges"))
 	{
 		kdebugm(KDEBUG_INFO|KDEBUG_FUNCTION_END, "not appending\n");
 		return;
@@ -294,15 +285,15 @@ void HistoryManager::appendStatus(UinType uin, const UserStatus &status)
 
 	fname = fname + QString::number(uin);
 	f.setName(fname);
-	if (!(f.open(IO_WriteOnly | IO_Append)))
+	if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", (const char *)fname.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(fname));
 		return;
 	}
 
 	buildIndexPrivate(fname);
 	fidx.setName(fname + ".idx");
-	if (fidx.open(IO_WriteOnly | IO_Append))
+	if (fidx.open(QIODevice::WriteOnly | QIODevice::Append))
 	{
 		offs = f.at();
 		fidx.writeBlock((const char *)&offs, sizeof(int));
@@ -328,7 +319,7 @@ void HistoryManager::removeHistory(const UinsList &uins)
 		case 0:
 			fname = ggPath("history/");
 			fname.append(getFileNameByUinsList(uins));
-			kdebugmf(KDEBUG_INFO, "deleting %s\n", (const char *)fname.local8Bit());
+			kdebugmf(KDEBUG_INFO, "deleting %s\n", qPrintable(fname));
 			QFile::remove(fname);
 			QFile::remove(fname + ".idx");
 			break;
@@ -352,17 +343,17 @@ void HistoryManager::convHist2ekgForm(UinsList uins)
 	fname = getFileNameByUinsList(uins);
 
 	f.setName(path + fname);
-	if (!(f.open(IO_ReadWrite)))
+	if (!(f.open(QIODevice::ReadWrite)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", (const char *)fname.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(fname));
 		return;
 	}
 
 	fnameout = fname + ".new";
 	fout.setName(path + fnameout);
-	if (!(fout.open(IO_WriteOnly | IO_Truncate)))
+	if (!(fout.open(QIODevice::WriteOnly | QIODevice::Truncate)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening new history file %s\n", (const char *)fnameout.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening new history file %s\n", qPrintable(fnameout));
 		f.close();
 		return;
 	}
@@ -377,7 +368,7 @@ void HistoryManager::convHist2ekgForm(UinsList uins)
 	QDateTime datetime, sdatetime;
 	QRegExp sep("\\s"), sep2("::");
 	our = foreign = false;
-	UinType myUin=config_file.readNumEntry("General","UIN");
+	UinType myUin = config_file.readNumEntry("General","UIN");
 	while ((line = stream.readLine()) != QString::null)
 	{
 //		our = !line.find(QRegExp("^\\S+\\s::\\s\\d{2,2}\\s\\d{2,2}\\s\\d{4,4},\\s\\(\\d{2,2}:\\d{2,2}:\\d{2,2}\\)$"));
@@ -494,16 +485,16 @@ void HistoryManager::convSms2ekgForm()
 
 	fname = "sms";
 	f.setName(path + fname);
-	if (!(f.open(IO_ReadWrite)))
+	if (!(f.open(QIODevice::ReadWrite)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening sms history file %s\n", (const char *)fname.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening sms history file %s\n", qPrintable(fname));
 		return;
 	}
 	fnameout = fname + ".new";
 	fout.setName(path + fnameout);
-	if (!(fout.open(IO_WriteOnly | IO_Truncate)))
+	if (!(fout.open(QIODevice::WriteOnly | QIODevice::Truncate)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening new sms history file %s\n", (const char *)fnameout.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening new sms history file %s\n", qPrintable(fnameout));
 		f.close();
 		return;
 	}
@@ -557,9 +548,9 @@ void HistoryManager::convSms2ekgForm()
 			datetime.setTime(QTime(czas.left(2).toInt(), czas.mid(3, 2).toInt(), czas.right(2).toInt()));
 			linelist.append(QString::number(-datetime.secsTo(
 				QDateTime(QDate(1970, 1, 1), QTime(0 ,0)))));
-			CONST_FOREACH(user, *userlist)
-				if ((*user).mobile() == mobile)
-					uin = (*user).ID("Gadu").toUInt();
+			foreach(const UserListElement &user, *userlist)
+				if (user.mobile() == mobile)
+					uin = user.ID("Gadu").toUInt();
 			header = false;
 		}
 		else
@@ -607,9 +598,9 @@ int HistoryManager::getHistoryEntriesCountPrivate(const QString &filename) const
 	QByteArray buffer;
 
 	f.setName(path + filename + ".idx");
-	if (!(f.open(IO_ReadOnly)))
+	if (!(f.open(QIODevice::ReadOnly)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", (const char *)filename.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(filename));
 		return 0;
 	}
 	lines = f.size() / sizeof(int);
@@ -626,7 +617,7 @@ int HistoryManager::getHistoryEntriesCount(const UinsList &uins)
 	kdebugf();
 	convHist2ekgForm(uins);
 	buildIndex(uins);
-	int ret=getHistoryEntriesCountPrivate(getFileNameByUinsList(uins));
+	int ret = getHistoryEntriesCountPrivate(getFileNameByUinsList(uins));
 	kdebugf2();
 	return ret;
 }
@@ -638,18 +629,18 @@ int HistoryManager::getHistoryEntriesCount(const QString &mobile)
 	buildIndex();
 	int ret;
 	if (mobile == QString::null)
-		ret= getHistoryEntriesCountPrivate("sms");
+		ret = getHistoryEntriesCountPrivate("sms");
 	else
-		ret= getHistoryEntriesCountPrivate(mobile);
+		ret = getHistoryEntriesCountPrivate(mobile);
 	kdebugf2();
 	return ret;
 }
 
-QValueList<HistoryEntry> HistoryManager::getHistoryEntries(UinsList uins, int from, int count, int mask)
+QList<HistoryEntry> HistoryManager::getHistoryEntries(UinsList uins, int from, int count, int mask)
 {
 	kdebugf();
 
-	QValueList<HistoryEntry> entries;
+	QList<HistoryEntry> entries;
 	QStringList tokens;
 	QFile f, fidx;
 	QString path = ggPath("history/");
@@ -661,14 +652,14 @@ QValueList<HistoryEntry> HistoryManager::getHistoryEntries(UinsList uins, int fr
 	else
 		filename = "sms";
 	f.setName(path + filename);
-	if (!(f.open(IO_ReadOnly)))
+	if (!(f.open(QIODevice::ReadOnly)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", (const char *)filename.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(filename));
 		return entries;
 	}
 
 	fidx.setName(f.name() + ".idx");
-	if (!fidx.open(IO_ReadOnly))
+	if (!fidx.open(QIODevice::ReadOnly))
 		return entries;
 	fidx.at(from * sizeof(int));
 	fidx.readBlock((char *)&offs, (Q_LONG)sizeof(int));
@@ -829,11 +820,11 @@ uint HistoryManager::getHistoryDate(QTextStream &stream)
 	return (tokens[pos].toUInt() / 86400);
 }
 
-QValueList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
+QList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 {
 	kdebugf();
 
-	QValueList<HistoryDate> entries;
+	QList<HistoryDate> entries;
 	HistoryDate newdate;
 	QFile f, fidx;
 	QString path = ggPath("history/");
@@ -850,16 +841,16 @@ QValueList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 
 	filename = getFileNameByUinsList(uins);
 	f.setName(path + filename);
-	if (!(f.open(IO_ReadOnly)))
+	if (!(f.open(QIODevice::ReadOnly)))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", (const char *)filename.local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(filename));
 		return entries;
 	}
 	QTextStream stream(&f);
 	stream.setCodec(codec_latin2);
 
 	fidx.setName(f.name() + ".idx");
-	if (!fidx.open(IO_ReadOnly))
+	if (!fidx.open(QIODevice::ReadOnly))
 		return entries;
 
 	oldidx = actidx = 0;
@@ -885,7 +876,7 @@ QValueList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 				break;
 			fidx.at(actidx * sizeof(int));
 			fidx.readBlock((char *)&offs, (Q_LONG)sizeof(int));
-			f.at(offs);
+			stream.seek(offs);
 			actdate = getHistoryDate(stream);
 //			if (++num%10 == 0)
 //				qApp->processEvents();
@@ -902,7 +893,7 @@ QValueList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 				actidx = (leftidx + rightidx) / 2;
 				fidx.at(actidx * sizeof(int));
 				fidx.readBlock((char *)&offs, (Q_LONG)sizeof(int));
-				f.at(offs);
+				stream.seek(offs);
 				actdate = getHistoryDate(stream);
 				if (actdate > olddate)
 					rightidx = actidx;
@@ -916,7 +907,7 @@ QValueList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 			{
 				fidx.at(actidx * sizeof(int));
 				fidx.readBlock((char *)&offs, (Q_LONG)sizeof(int));
-				f.at(offs);
+				stream.seek(offs);
 				actdate = getHistoryDate(stream);
 			}
 			newdate.date.setTime_t(actdate * 86400);
@@ -927,27 +918,26 @@ QValueList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 
 	fidx.close();
 	f.close();
-
+	kdebugmf(KDEBUG_INFO, "entries count = %d\n", entries.count());
 	kdebugf2();
 	return entries;
 }
 
-QValueList<UinsList> HistoryManager::getUinsLists() const
+QList<UinsList> HistoryManager::getUinsLists() const
 {
 	kdebugf();
-	QValueList<UinsList> entries;
+	QList<UinsList> entries;
 	QDir dir(ggPath("history/"), "*.idx");
 	QStringList struins;
 	UinsList uins;
 
-	QStringList entryList = dir.entryList();
-	FOREACH(entry, entryList)
+	foreach(QString entry, dir.entryList())
 	{
-		struins = QStringList::split("_", (*entry).remove(QRegExp(".idx$")));
+		struins = QStringList::split("_", entry.remove(QRegExp(".idx$")));
 		uins.clear();
 		if (struins[0] != "sms")
-			CONST_FOREACH(struin, struins)
-				uins.append((*struin).toUInt());
+			foreach(const QString &struin, struins)
+				uins.append(struin.toUInt());
 		entries.append(uins);
 	}
 
@@ -969,14 +959,14 @@ void HistoryManager::buildIndexPrivate(const QString &filename)
 		return;
 	QFile fin(filename);
 	QFile fout(fnameout);
-	if (!fin.open(IO_ReadOnly))
+	if (!fin.open(QIODevice::ReadOnly))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error opening history file: %s\n", (const char *)fin.name().local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error opening history file: %s\n", qPrintable(fin.name()));
 		return;
 	}
-	if (!fout.open(IO_WriteOnly | IO_Truncate))
+	if (!fout.open(QIODevice::WriteOnly | QIODevice::Truncate))
 	{
-		kdebugmf(KDEBUG_ERROR, "Error creating history index file: %s\n", (const char *)fout.name().local8Bit());
+		kdebugmf(KDEBUG_ERROR, "Error creating history index file: %s\n", qPrintable(fout.name()));
 		fin.close();
 		return;
 	}
@@ -1020,6 +1010,79 @@ void HistoryManager::buildIndexPrivate(const QString &filename)
 	kdebugf2();
 }
 
+void HistoryManager::createMessageDates(const UinsList uins)
+{
+	int entriesCount = getHistoryEntriesCount(uins);
+	if (entriesCount < 1)
+		return;
+
+	QList<HistoryEntry> entries = getHistoryEntries(uins, 0, entriesCount, HISTORYMANAGER_ENTRY_ALL_MSGS);
+
+	QFile messageDatesFile(ggPath("history/") + getFileNameByUinsList(uins) + ".message_dates");
+	messageDatesFile.open(QIODevice::WriteOnly);
+	QDataStream messageDatesStream(&messageDatesFile);
+
+	QDate currentDate;
+	HistoryEntry entry;
+	foreach (entry, entries)
+	{
+		if (entry.date.date() != currentDate && currentDate.isValid())
+		{
+			messageDatesStream << currentDate;
+			currentDate = entry.date.date();
+		}
+		else if (!currentDate.isValid())
+			currentDate = entry.date.date();
+	}
+
+	messageDatesFile.close();
+
+	if (currentDate.isValid())
+		LastDate[uins] = currentDate;
+}
+
+void HistoryManager::updateMessageDates(const UinsList uins)
+{
+	QDate date = QDate::currentDate();
+	if (LastDate.contains(uins))
+		if (LastDate[uins] == date)
+			return;
+
+	QFile messageDatesFile(ggPath("history/") + getFileNameByUinsList(uins) + ".message_dates");
+	if (!messageDatesFile.exists())
+	{
+		createMessageDates(uins);
+		return;
+	}
+
+	messageDatesFile.open(QIODevice::WriteOnly | QIODevice::Append);
+	QDataStream messageDatesStream(&messageDatesFile);
+	messageDatesStream << date;
+	messageDatesFile.close();
+
+	LastDate[uins] = date;
+}
+
+QList<QDate> HistoryManager::getMessageDates(const UinsList &uins)
+{
+	QFile messageDatesFile(ggPath("history/") + getFileNameByUinsList(uins) + ".message_dates");
+	if (!messageDatesFile.exists())
+		createMessageDates(uins);
+
+	QList<QDate> result;
+	messageDatesFile.open(QIODevice::ReadOnly);
+	QDataStream messageDatesStream(&messageDatesFile);
+
+	while (!messageDatesStream.atEnd())
+	{
+		QDate date;
+		messageDatesStream >> date;
+		result << date;
+	}
+
+	return result;
+}
+
 void HistoryManager::buildIndex(const UinsList &uins)
 {
 	kdebugf();
@@ -1053,7 +1116,7 @@ QStringList HistoryManager::mySplit(const QChar &sep, const QString &str)
 		{
 			if (letter == '\\')
 			{
-				switch (str[idx + 1])
+				switch (str[idx + 1].toAscii())
 				{
 					case 'n':
 						token.append('\n');
@@ -1128,7 +1191,7 @@ int HistoryManager::getHistoryEntryIndexByDate(const UinsList &uins, const QDate
 {
 	kdebugf();
 
-	QValueList<HistoryEntry> entries;
+	QList<HistoryEntry> entries;
 	int count = getHistoryEntriesCount(uins);
 	int start, end;
 
@@ -1171,13 +1234,15 @@ void HistoryManager::messageReceived(Protocol * /*protocol*/, UserListElements s
 	if (!config_file.readBoolEntry("History", "Logging"))
 		return;
 	kdebugf();
-	int occur = msg.contains(QRegExp("<img [^>]* gg_crc[^>]*>"));
+	int occur = msg.count(QRegExp("<img [^>]* gg_crc[^>]*>"));
+
 	UinType sender0 = senders[0].ID("Gadu").toUInt();
-	kdebugm(KDEBUG_INFO, "sender: %d msg: '%s' occur:%d\n", sender0, msg.local8Bit().data(), occur);
+	kdebugm(KDEBUG_INFO, "sender: %d msg: '%s' occur:%d\n", sender0, qPrintable(msg), occur);
 	UinsList uins;//TODO: throw out UinsList as soon as possible!
-	CONST_FOREACH(u, senders)
-		if ((*u).usesProtocol("Gadu"))
-			uins.append((*u).ID("Gadu").toUInt());
+	foreach(const UserListElement &u, senders)
+		if (u.usesProtocol("Gadu"))
+			uins.append(u.ID("Gadu").toUInt());
+
 	if (bufferedMessages.find(sender0) != bufferedMessages.end() || occur > 0)
 	{
 		kdebugm(KDEBUG_INFO, "buffering\n");
@@ -1197,20 +1262,22 @@ void HistoryManager::imageReceivedAndSaved(UinType sender, uint32_t size, uint32
 	if (!config_file.readBoolEntry("History", "Logging"))
 		return;
 	kdebugf();
-	kdebugm(KDEBUG_INFO, "sender: %d, size: %d, crc:%u, path:%s\n", sender, size, crc32, path.local8Bit().data());
+
+	kdebugm(KDEBUG_INFO, "sender: %d, size: %d, crc:%u, path:%s\n", sender, size, crc32, qPrintable(path));
 	QString reg = GaduImagesManager::loadingImageHtml(sender, size, crc32);
 	QString imagehtml = GaduImagesManager::imageHtml(path);
-	QMap<UinType, QValueList<BuffMessage> >::iterator it = bufferedMessages.find(sender);
+	QMap<UinType, QList<BuffMessage> >::iterator it = bufferedMessages.find(sender);
 	if (it != bufferedMessages.end())
 	{
 //		kdebugm(KDEBUG_INFO, "sender found\n");
-		QValueList<BuffMessage> &messages = it.data();
-		FOREACH(msg, messages)
+		QList<BuffMessage> &messages = it.data();
+		QList<BuffMessage>::iterator msg;
+		for (msg = messages.begin(); msg != messages.end(); ++msg)
 		{
 //			kdebugm(KDEBUG_INFO, "counter:%d\n", (*msg).counter);
 			if ((*msg).counter)
 			{
-				int occur = (*msg).message.contains(reg);
+				int occur = (*msg).message.count(reg);
 //				kdebugm(KDEBUG_INFO, "occur:%d\n", occur);
 				if (occur)
 				{
@@ -1248,6 +1315,9 @@ void HistoryManager::addMyMessage(const UinsList &senders, const QString &msg)
 	}
 	else
 		appendMessage(senders, senders[0], msg, true, 0, true, current);
+
+	updateMessageDates(senders);
+
 	kdebugf2();
 }
 
@@ -1255,7 +1325,7 @@ void HistoryManager::checkImageTimeout(UinType uin)
 {
 	kdebugf();
 	time_t currentTime = time(NULL);
-	QValueList<BuffMessage> &msgs = bufferedMessages[uin];
+	QList<BuffMessage> &msgs = bufferedMessages[uin];
 	while (!msgs.isEmpty())
 	{
 		BuffMessage &msg = msgs.front();
@@ -1280,10 +1350,10 @@ void HistoryManager::checkImageTimeout(UinType uin)
 void HistoryManager::checkImagesTimeouts()
 {
 	kdebugf();
-	QValueList<UinType> uins = bufferedMessages.keys();
+	QList<UinType> uins = bufferedMessages.keys();
 
-	CONST_FOREACH(uin, uins)
-		checkImageTimeout(*uin);
+	foreach(const UinType &uin, uins)
+		checkImageTimeout(uin);
 	kdebugf2();
 }
 
