@@ -7,12 +7,19 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QtGui/QApplication>
+#include <QtGui/QGridLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QListWidget>
+
 #include "chat_widget.h"
 #include "chat_manager.h"
 #include "config_file.h"
 #include "configuration_window_widgets.h"
 #include "connection_error_notification.h"
+#include "custom_input.h"
 #include "debug.h"
+#include "gadu.h"
 #include "kadu.h"
 #include "misc.h"
 #include "new_message_notification.h"
@@ -21,7 +28,8 @@
 #include "status_changed_notification.h"
 #include "userbox.h"
 
-extern "C" int notify_init()
+
+extern "C" KADU_EXPORT int notify_init(bool firstLoad)
 {
 	kdebugf();
 
@@ -32,7 +40,7 @@ extern "C" int notify_init()
 	return 0;
 }
 
-extern "C" void notify_close()
+extern "C" KADU_EXPORT void notify_close()
 {
 	kdebugf();
 
@@ -44,9 +52,12 @@ extern "C" void notify_close()
 }
 
 NotifyGroupBox::NotifyGroupBox(const QString &notificator, const QString &caption, QWidget *parent, char *name)
-	: QGroupBox(1, Qt::Horizontal, caption, parent, name), Notificator(notificator)
+	: QGroupBox(caption, parent), Notificator(notificator)
 {
 	setCheckable(true);
+	QHBoxLayout *layout = new QHBoxLayout(this);
+	Q_UNUSED(layout)
+
 	connect(this, SIGNAL(toggled(bool)), this, SLOT(toggledSlot(bool)));
 }
 
@@ -67,6 +78,7 @@ Notify::Notify(QObject *parent, const char *name)
 	// TODO: workaround
 	connect(kadu, SIGNAL(messageReceivedSignal(Protocol *, UserListElements, const QString&, time_t)),
 			this, SLOT(messageReceived(Protocol *, UserListElements, const QString&, time_t)));
+	// TODO:
 	connect(userlist, SIGNAL(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)),
 		this, SLOT(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)));
 
@@ -88,15 +100,16 @@ Notify::~Notify()
 	disconnect(gadu, SIGNAL(connectionError(Protocol *, const QString &, const QString &)), this, SLOT(connectionError(Protocol *, const QString &, const QString &)));
 	disconnect(gadu, SIGNAL(messageReceived(Protocol *, UserListElements, const QString&, time_t)),
 			this, SLOT(messageReceived(Protocol *, UserListElements, const QString&, time_t)));
+	// TODO:
 	disconnect(userlist, SIGNAL(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)),
 		this, SLOT(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)));
 
 	if (!Notifiers.isEmpty())
 	{
 		kdebugm(KDEBUG_WARNING, "WARNING: not unregistered notifiers found! (%u)\n", Notifiers.size());
-		QValueList<QString> notifierNames = Notifiers.keys();
-		CONST_FOREACH(name, notifierNames)
-			unregisterNotifier(*name);
+		QStringList notifierNames = Notifiers.keys();
+		foreach(const QString &name, notifierNames)
+			unregisterNotifier(name);
 	}
 
 	kdebugf2();
@@ -112,10 +125,10 @@ void Notify::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigu
 	QStringList captions;
 	QStringList values;
 
-	CONST_FOREACH(notifyEvent, NotifyEvents)
+	foreach(const NotifyEvent &notifyEvent, NotifyEvents)
 	{
-		captions.append(qApp->translate("@default", (*notifyEvent).description));
-		values.append((*notifyEvent).name);
+		captions.append(qApp->translate("@default", notifyEvent.description));
+		values.append(notifyEvent.name);
 	}
 
 	notifications->setItems(values, captions);
@@ -127,14 +140,14 @@ void Notify::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigu
 	notifyUsersLayout->setSpacing(5);
 	notifyUsersLayout->setMargin(5);
 
-	allUsers = new QListBox(notifyUsers);
+	allUsers = new QListWidget(notifyUsers);
 	QPushButton *moveToNotifyList = new QPushButton(tr("Move to 'Notify list'"), notifyUsers);
 
 	notifyUsersLayout->addWidget(new QLabel(tr("User list"), notifyUsers), 0, 0);
 	notifyUsersLayout->addWidget(allUsers, 1, 0);
 	notifyUsersLayout->addWidget(moveToNotifyList, 2, 0);
 
-	notifiedUsers = new QListBox(notifyUsers);
+	notifiedUsers = new QListWidget(notifyUsers);
 	QPushButton *moveToAllList = new QPushButton(tr("Move to 'User list'"), notifyUsers);
 
 	notifyUsersLayout->addWidget(new QLabel(tr("Notify list"), notifyUsers), 0, 1);
@@ -146,28 +159,28 @@ void Notify::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigu
 
 	statusGroupBox->addWidgets(0, notifyUsers);
 
-	CONST_FOREACH(user, *userlist)
-		if ((*user).usesProtocol("Gadu") && !(*user).isAnonymous())
-			if (!(*user).notify())
-				allUsers->insertItem((*user).altNick());
+	foreach(const UserListElement &user, *userlist)
+		if (user.usesProtocol("Gadu") && !user.isAnonymous())
+			if (!user.notify())
+				allUsers->addItem(user.altNick());
 			else
-				notifiedUsers->insertItem((*user).altNick());
+				notifiedUsers->addItem(user.altNick());
 
-	allUsers->sort();
-	notifiedUsers->sort();
-	allUsers->setSelectionMode(QListBox::Extended);
-	notifiedUsers->setSelectionMode(QListBox::Extended);
+	allUsers->sortItems();
+	notifiedUsers->sortItems();
+	allUsers->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	notifiedUsers->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
-	connect(notifiedUsers, SIGNAL(doubleClicked(QListBoxItem *)), this, SLOT(moveToAllList()));
-	connect(allUsers, SIGNAL(doubleClicked(QListBoxItem *)), this, SLOT(moveToNotifyList()));
+	connect(notifiedUsers, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(moveToAllList()));
+	connect(allUsers, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(moveToNotifyList()));
 
 	connect(mainConfigurationWindow->widgetById("notify/notifyAll"), SIGNAL(toggled(bool)), notifyUsers, SLOT(setDisabled(bool)));
 	connect(mainConfigurationWindow, SIGNAL(configurationWindowApplied()), this, SLOT(configurationWindowApplied()));
 
 	notificationsGroupBox = mainConfigurationWindow->configGroupBox("Notifications", "General", "Notifications");
 
-	FOREACH(notifierData, Notifiers)
-		addConfigurationWidget(*notifierData, notifierData.key());
+	foreach(const QString &key, Notifiers.keys())
+		addConfigurationWidget(Notifiers[key], key);
 
 	eventSwitched(0);
 }
@@ -176,7 +189,8 @@ void Notify::mainConfigurationWindowDestroyed()
 {
 	notificationsGroupBox = 0;
 
-	FOREACH(notifierData, Notifiers)
+	QMap<QString, NotifierData>::iterator notifierData;
+	for (notifierData = Notifiers.begin(); notifierData != Notifiers.end(); ++notifierData)
 		(*notifierData).configurationWidget = 0;
 }
 
@@ -193,11 +207,11 @@ void Notify::addConfigurationWidget(NotifierData &notifier, const QString &name)
 		notifier.configurationWidget = notifyConfigurationWidget;
 		notifyConfigurationWidget->loadNotifyConfigurations();
 	}
-	else
-	{
-		configurationGroupBox->setFlat(true);
-		configurationGroupBox->setLineWidth(0);
-	}
+//	else
+//	{
+//		configurationGroupBox->setFlat(true);
+//		configurationGroupBox->setLineWidth(0);
+//	}
 
 	notificationsGroupBox->addWidget(configurationGroupBox, true);
 	configurationGroupBox->show();
@@ -220,16 +234,18 @@ void Notify::eventSwitched(int index)
 	kdebugf();
 
 	CurrentEvent = notifications->currentItemValue();
-	FOREACH(notifierData, Notifiers)
+	foreach(const QString &key, Notifiers.keys())
 	{
-		if (!(*notifierData).events.contains(CurrentEvent))
-			(*notifierData).events[CurrentEvent] = config_file.readBoolEntry("Notify", CurrentEvent + '_' + notifierData.key());
+		NotifierData notifierData = Notifiers[key];
 
-		if ((*notifierData).configurationWidget)
-			(*notifierData).configurationWidget->switchToEvent(CurrentEvent);
+		if (!notifierData.events.contains(CurrentEvent))
+			notifierData.events[CurrentEvent] = config_file.readBoolEntry("Notify", CurrentEvent + '_' + key);
 
-		if ((*notifierData).configurationGroupBox)
-			(*notifierData).configurationGroupBox->setChecked((*notifierData).events[CurrentEvent]);
+		if (notifierData.configurationWidget)
+			notifierData.configurationWidget->switchToEvent(CurrentEvent);
+
+		if (notifierData.configurationGroupBox)
+			notifierData.configurationGroupBox->setChecked(notifierData.events[CurrentEvent]);
 	}
 }
 
@@ -237,21 +253,23 @@ void Notify::configurationWindowApplied()
 {
 	int count = notifiedUsers->count();
 	for (int i = 0; i < count; i++)
-		userlist->byAltNick(notifiedUsers->text(i)).setNotify(true);
+		userlist->byAltNick(notifiedUsers->item(i)->text()).setNotify(true);
 
 	count = allUsers->count();
 	for (int i = 0; i < count; i++)
-		userlist->byAltNick(allUsers->text(i)).setNotify(false);
+		userlist->byAltNick(allUsers->item(i)->text()).setNotify(false);
 
 	userlist->writeToConfig();
 
-	FOREACH(notifierData, Notifiers)
+	foreach(const QString &key, Notifiers.keys())
 	{
-		if ((*notifierData).configurationWidget)
-			(*notifierData).configurationWidget->saveNotifyConfigurations();
+		NotifierData notifierData = Notifiers[key];
 
-		FOREACH(event, ((*notifierData).events))
-			config_file.writeEntry("Notify", event.key() + '_' + notifierData.key(), *event);
+		if (notifierData.configurationWidget)
+			notifierData.configurationWidget->saveNotifyConfigurations();
+
+		foreach(const QString &eventKey, notifierData.events.keys())
+			config_file.writeEntry("Notify", eventKey + '_' + key, notifierData.events[eventKey]);
 	}
 }
 
@@ -267,13 +285,14 @@ void Notify::moveToAllList()
 	int count = notifiedUsers->count();
 
 	for (int i = count - 1; i >= 0; i--)
-		if (notifiedUsers->isSelected(i))
+		if (notifiedUsers->item(i)->isSelected())
 		{
-			allUsers->insertItem(notifiedUsers->text(i));
-			notifiedUsers->removeItem(i);
+			allUsers->addItem(notifiedUsers->item(i)->text());
+			QListWidgetItem *it = notifiedUsers->takeItem(i);
+			delete it;
 		}
 
-	allUsers->sort();
+	allUsers->sortItems();
 }
 
 void Notify::moveToNotifyList()
@@ -281,13 +300,14 @@ void Notify::moveToNotifyList()
 	int count = allUsers->count();
 
 	for (int i = count - 1; i >= 0; i--)
-		if (allUsers->isSelected(i))
+		if (allUsers->item(i)->isSelected())
 		{
-			notifiedUsers->insertItem(allUsers->text(i));
-			allUsers->removeItem(i);
+			notifiedUsers->addItem(allUsers->item(i)->text());
+			QListWidgetItem *it = allUsers->takeItem(i);
+			delete it;
 		}
 
-	notifiedUsers->sort();
+	notifiedUsers->sortItems();
 }
 
 void Notify::statusChanged(UserListElement elem, QString protocolName,
@@ -344,7 +364,7 @@ void Notify::messageReceived(Protocol *protocol, UserListElements senders, const
 	if (!chat) // new chat
 		notify(new MessageNotification(MessageNotification::NewChat, senders, msg, protocol->protocolID()));
 	else // new message in chat
-		if (!chat->hasFocus() || !config_file.readBoolEntry("Notify", "NewMessageOnlyIfInactive"))
+		if (!chat->edit()->hasFocus() || !config_file.readBoolEntry("Notify", "NewMessageOnlyIfInactive"))
 			notify(new MessageNotification(MessageNotification::NewMessage, senders, msg, protocol->protocolID()));
 
 	kdebugf2();
@@ -381,12 +401,9 @@ void Notify::unregisterEvent(const QString &name)
 {
 	kdebugf();
 
-	FOREACH(it, NotifyEvents)// look for matching event
-		if ((*it).name == name)
-		{
-			NotifyEvents.remove(it);
-			break;
-		}
+	NotifyEvent remove;
+	remove.name = name;
+	NotifyEvents.removeAll(remove);
 
 	kdebugf2();
 }
@@ -406,7 +423,7 @@ void Notify::registerNotifier(const QString &name, Notifier *notifier)
 	if (Notifiers.contains(name))
 	{
 		kdebugm(KDEBUG_WARNING, "WARNING: '%s' already exists in notifiers! "
-		"strange... unregistering old Notifier\n", name.local8Bit().data());
+		"strange... unregistering old Notifier\n", qPrintable(name));
 
 		unregisterNotifier(name);
 	}
@@ -417,12 +434,12 @@ void Notify::registerNotifier(const QString &name, Notifier *notifier)
 		QStringList addToMe;
 		addToMe << "toAvailable" << "toBusy" << "toInvisible" << "toNotAvailable";
 
-		CONST_FOREACH(i, addToMe)
+		foreach(const QString &i, addToMe)
 		{
-			if (!config_file.readBoolEntry("Notify", *i + '_' + name))
+			if (!config_file.readBoolEntry("Notify", i + '_' + name))
 			{
-				notifier->copyConfiguration("StatusChanged", *i);
-				config_file.writeEntry("Notify", *i + '_' + name, true);
+				notifier->copyConfiguration("StatusChanged", i);
+				config_file.writeEntry("Notify", i + '_' + name, true);
 			}
 		}
 
@@ -451,7 +468,7 @@ void Notify::unregisterNotifier(const QString &name)
 
 	if (!Notifiers.contains(name))
 	{
-		kdebugm(KDEBUG_WARNING, "WARNING: '%s' not registered!\n", name.local8Bit().data());
+		kdebugm(KDEBUG_WARNING, "WARNING: '%s' not registered!\n", qPrintable(name));
 		return;
 	}
 
@@ -468,7 +485,7 @@ QStringList Notify::notifiersList() const
 	return QStringList(Notifiers.keys());
 }
 
-const QValueList<Notify::NotifyEvent> &Notify::notifyEvents()
+const QList<Notify::NotifyEvent> &Notify::notifyEvents()
 {
 	return NotifyEvents;
 }
@@ -483,20 +500,26 @@ void Notify::notify(Notification *notification)
 
 	notification->acquire();
 
-	CONST_FOREACH(i, Notifiers)
-		if (config_file.readBoolEntry("Notify", notifyType + '_' + i.key()))
+	foreach(const QString &key, Notifiers.keys())
+	{
+		NotifierData notifier = Notifiers[key];
+
+		if (config_file.readBoolEntry("Notify", notifyType + '_' + key))
 		{
-			(*i).notifier->notify(notification);
+			notifier.notifier->notify(notification);
 			foundNotifier = true;
-			foundNotifierWithCallbackSupported = foundNotifierWithCallbackSupported || ((*i).notifier->callbackCapacity() == CallbackSupported);
+			foundNotifierWithCallbackSupported = foundNotifierWithCallbackSupported || (notifier.notifier->callbackCapacity() == CallbackSupported);
 		}
+	}
 
 	if (!foundNotifierWithCallbackSupported)
-		CONST_FOREACH(i, Notifiers)
+		foreach(const QString &key, Notifiers.keys())
 		{
-			if ((*i).notifier->callbackCapacity() == CallbackSupported)
+			NotifierData notifier = Notifiers[key];
+
+			if (notifier.notifier->callbackCapacity() == CallbackSupported)
 			{
-				(*i).notifier->notify(notification);
+				notifier.notifier->notify(notification);
 				foundNotifier = true;
 				foundNotifierWithCallbackSupported = true;
 				break;
