@@ -1,95 +1,76 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="11"/>
         <source>Notifications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="8"/>
         <source>General</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="14"/>
         <source>Event</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="20"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="23"/>
         <source>New messages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="26"/>
         <source>Notify about new messages only when window is inactive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="30"/>
         <source>Status change</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="33"/>
         <source>Ignore status changes from available / busy to busy / available</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="36"/>
         <source>Ignore changes right after connection to the server</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="38"/>
         <source>This option will supersede tooltips with users&apos; status
  changes upon establishing connection to the server</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="41"/>
         <source>Notify about all users</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../connection_error_notification.cpp" line="37"/>
         <source>Connection error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="19"/>
         <source>User changed status to online</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="20"/>
         <source>User changed status to busy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="21"/>
         <source>User changed status to invisible</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="22"/>
         <source>User changed status to offline</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="17"/>
         <source>New chat</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="18"/>
         <source>New message</source>
         <translation type="unfinished"></translation>
     </message>
@@ -97,12 +78,10 @@
 <context>
     <name>ConnectionErrorNotification</name>
     <message>
-        <location filename="../connection_error_notification.cpp" line="56"/>
         <source>Connection error</source>
         <translation type="unfinished">Erreur de connexion</translation>
     </message>
     <message>
-        <location filename="../connection_error_notification.cpp" line="57"/>
         <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
         <translation type="unfinished"></translation>
     </message>
@@ -110,12 +89,10 @@
 <context>
     <name>MessageNotification</name>
     <message>
-        <location filename="../new_message_notification.cpp" line="36"/>
         <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="41"/>
         <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -123,27 +100,22 @@
 <context>
     <name>Notify</name>
     <message>
-        <location filename="../notify.cpp" line="513"/>
         <source>Unable to find notifier for %1 event</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="132"/>
         <source>Move to &apos;Notify list&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="134"/>
         <source>User list</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="139"/>
         <source>Move to &apos;User list&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="141"/>
         <source>Notify list</source>
         <translation type="unfinished"></translation>
     </message>
@@ -151,17 +123,14 @@
 <context>
     <name>StatusChangedNotification</name>
     <message>
-        <location filename="../status_changed_notification.cpp" line="44"/>
         <source>Status changed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="40"/>
         <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="42"/>
         <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
