@@ -1,96 +1,77 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="11"/>
         <source>Notifications</source>
         <translation>Notifiche</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="8"/>
         <source>General</source>
         <translation>Generale</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="14"/>
         <source>Event</source>
         <translation>Evento</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="20"/>
         <source>Options</source>
         <translation>Opzioni</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="23"/>
         <source>New messages</source>
         <translation>Nuovo messaggi</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="26"/>
         <source>Notify about new messages only when window is inactive</source>
         <translation>Notifica nuovi messaggi per la finestra inattiva</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="30"/>
         <source>Status change</source>
         <translation>Cambiamente dello status</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="33"/>
         <source>Ignore status changes from available / busy to busy / available</source>
         <translation>Ignora i cambiament dello status da disponibile / occupato a disponibile / occupato</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="36"/>
         <source>Ignore changes right after connection to the server</source>
         <translation>Non mostrare descrizioni dopo la conessione con server</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="38"/>
         <source>This option will supersede tooltips with users&apos; status
  changes upon establishing connection to the server</source>
         <translation>Questa opzione disattiva comparsa delle notifiche con status dei contatti
 durante primo colegamento Kadu con serwer</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="41"/>
         <source>Notify about all users</source>
         <translation>Notifica tutti i contatti</translation>
     </message>
     <message>
-        <location filename="../connection_error_notification.cpp" line="37"/>
         <source>Connection error</source>
         <translation>Errore conessione</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="19"/>
         <source>User changed status to online</source>
         <translation>Contatto ha cambiato status a Accessibile</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="20"/>
         <source>User changed status to busy</source>
         <translation>Contatto ha cambiato status a Occupato</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="21"/>
         <source>User changed status to invisible</source>
         <translation>Contatto ha cambiato status a Invisibile</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="22"/>
         <source>User changed status to offline</source>
         <translation>Contatto ha cambiato status a Fuori line</translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="17"/>
         <source>New chat</source>
         <translation>Nuovo chat</translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="18"/>
         <source>New message</source>
         <translation>Nuovo messaggio</translation>
     </message>
@@ -98,12 +79,10 @@ durante primo colegamento Kadu con serwer</translation>
 <context>
     <name>ConnectionErrorNotification</name>
     <message>
-        <location filename="../connection_error_notification.cpp" line="56"/>
         <source>Connection error</source>
         <translation>Errore conessione</translation>
     </message>
     <message>
-        <location filename="../connection_error_notification.cpp" line="57"/>
         <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
         <translation>&lt;b&gt;Errore:&lt;/b&gt; (%1) %2</translation>
     </message>
@@ -111,12 +90,10 @@ durante primo colegamento Kadu con serwer</translation>
 <context>
     <name>MessageNotification</name>
     <message>
-        <location filename="../new_message_notification.cpp" line="36"/>
         <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="41"/>
         <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -124,27 +101,22 @@ durante primo colegamento Kadu con serwer</translation>
 <context>
     <name>Notify</name>
     <message>
-        <location filename="../notify.cpp" line="513"/>
         <source>Unable to find notifier for %1 event</source>
         <translation>Non posso trovare notifier per evento %1</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="132"/>
         <source>Move to &apos;Notify list&apos;</source>
         <translation>Riporta nella &apos;Lista Notifiche&apos;</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="134"/>
         <source>User list</source>
         <translation>Lista contatti</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="139"/>
         <source>Move to &apos;User list&apos;</source>
         <translation>Riporta nella &apos;Lista Contatti&apos;</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="141"/>
         <source>Notify list</source>
         <translation>Lista notifiche</translation>
     </message>
@@ -152,17 +124,14 @@ durante primo colegamento Kadu con serwer</translation>
 <context>
     <name>StatusChangedNotification</name>
     <message>
-        <location filename="../status_changed_notification.cpp" line="44"/>
         <source>Status changed</source>
         <translation>Cambiamento dello status</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="40"/>
         <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; ha cambiato status a &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="42"/>
         <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; ha cambiato status a &lt;i&gt;%2&lt;/i&gt;</translation>
     </message>
