@@ -1,113 +1,87 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="pl">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="11"/>
         <source>Notifications</source>
         <translation>Powiadomienia</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="8"/>
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="14"/>
         <source>Event</source>
         <translation>Zdarzenie</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="20"/>
         <source>Options</source>
         <translation>Opcje</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="23"/>
         <source>New messages</source>
         <translation>Nowa wiadomość</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="26"/>
         <source>Notify about new messages only when window is inactive</source>
         <translation>Informuj o nowych wiadomościach tylko gdy okno rozmowy jest nieaktywne</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="30"/>
         <source>Status change</source>
         <translation>Zmiany statusów</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="33"/>
         <source>Ignore status changes from available / busy to busy / available</source>
         <translation>Ignoruj zmiany statusów z dostępny / zajęty na zajęty / dostępny</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="36"/>
         <source>Ignore changes right after connection to the server</source>
         <translation>Ignoruj zmiany statusów po połączeniu z serwerem</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="38"/>
         <source>This option will supersede tooltips with users&apos; status
  changes upon establishing connection to the server</source>
         <translation>Ta opcja zlikwiduje powiadomienia o zmianach statusów przy łączeniu do serwera</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="41"/>
         <source>Notify about all users</source>
         <translation>Informuj o wszystkich kontaktach</translation>
     </message>
     <message>
-        <location filename="../connection_error_notification.cpp" line="37"/>
         <source>Connection error</source>
         <translation>Błąd połączenia</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="19"/>
         <source>User changed status to online</source>
         <translation>Kontakt zmienił status na &apos;Dostępny&apos;</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="20"/>
         <source>User changed status to busy</source>
         <translation>Kontakt zmienił status na &apos;Zajęty&apos;</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="21"/>
         <source>User changed status to invisible</source>
         <translation>Kontakt zmienił status na &apos;Ukryty&apos;</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="22"/>
         <source>User changed status to offline</source>
         <translation>Kontakt zmienił status na &apos;Niedostępny&apos;</translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="17"/>
         <source>New chat</source>
         <translation>Nowa rozmowa</translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="18"/>
         <source>New message</source>
         <translation>Nowa wiadomość</translation>
     </message>
-    <message>
-        <location filename="../.configuration-ui-translations.cpp" line="29"/>
-        <source>Allow opening chat with events other than &apos;New chat&apos;</source>
-        <translation type="obsolete">Zezwalaj na otwierania okna rozmowy przy zdarzeniach innych niż &apos;Nowa rozmowa&apos;</translation>
-    </message>
 </context>
 <context>
     <name>ConnectionErrorNotification</name>
     <message>
-        <location filename="../connection_error_notification.cpp" line="56"/>
         <source>Connection error</source>
         <translation>Błąd połączenia</translation>
     </message>
     <message>
-        <location filename="../connection_error_notification.cpp" line="57"/>
         <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
         <translation>&lt;b&gt;Błąd:&lt;/b&gt; (%1) %2</translation>
     </message>
@@ -115,12 +89,10 @@
 <context>
     <name>MessageNotification</name>
     <message>
-        <location filename="../new_message_notification.cpp" line="36"/>
         <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
         <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../new_message_notification.cpp" line="41"/>
         <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
         <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;</translation>
     </message>
@@ -128,27 +100,22 @@
 <context>
     <name>Notify</name>
     <message>
-        <location filename="../notify.cpp" line="513"/>
         <source>Unable to find notifier for %1 event</source>
         <translation>Nie znaleziono powiadomienia dla zdarzenia %1</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="132"/>
         <source>Move to &apos;Notify list&apos;</source>
         <translation>Przesuń do &quot;Listy powiadomień&quot;</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="134"/>
         <source>User list</source>
         <translation>Lista kontaktów</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="139"/>
         <source>Move to &apos;User list&apos;</source>
         <translation>Przesuń do &quot;Listy kontaktów&quot;</translation>
     </message>
     <message>
-        <location filename="../notify.cpp" line="141"/>
         <source>Notify list</source>
         <translation>Lista powiadomień</translation>
     </message>
@@ -156,17 +123,14 @@
 <context>
     <name>StatusChangedNotification</name>
     <message>
-        <location filename="../status_changed_notification.cpp" line="44"/>
         <source>Status changed</source>
         <translation>Zmiany statusu</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="40"/>
         <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
     </message>
     <message>
-        <location filename="../status_changed_notification.cpp" line="42"/>
         <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;</translation>
     </message>
