@@ -7,10 +7,14 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qcheckbox.h>
-#include <qgrid.h>
-#include <qlayout.h>
-#include <qstring.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QGridLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QListWidget>
+#include <QtCore/QProcess>
+#include <QtGui/QTextEdit>
 
 #include "action.h"
 #include "config_file.h"
@@ -21,14 +25,15 @@
 #include "kadu.h"
 #include "message_box.h"
 #include "modules.h"
-#include "sms.h"
 #include "userbox.h"
 
+#include "sms.h"
+
 /**
  * @ingroup sms
  * @{
  */
-extern "C" int sms_init()
+extern "C" KADU_EXPORT int sms_init(bool firstLoad)
 {
 	kdebugf();
 
@@ -37,18 +42,16 @@ extern "C" int sms_init()
 
 	QObject::connect(kadu->userbox(), SIGNAL(doubleClicked(UserListElement)),
 			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
-	QObject::connect(kadu->userbox(), SIGNAL(mouseButtonClicked(int, QListBoxItem*,const QPoint&)),
-			smsConfigurationUiHandler, SLOT(onUserClicked(int, QListBoxItem*, const QPoint&)));
+	QObject::connect(kadu->userbox(), SIGNAL(mouseButtonClicked(int, Q3ListBoxItem*,const QPoint&)),
+			smsConfigurationUiHandler, SLOT(onUserClicked(int, Q3ListBoxItem*, const QPoint&)));
 	QObject::connect(kadu->userbox(), SIGNAL(returnPressed(UserListElement)),
 			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
-	QObject::connect(UserBox::userboxmenu, SIGNAL(popup()), smsConfigurationUiHandler, SLOT(onPopupMenuCreate()));
 
-	config_file.addVariable("SMS", "Priority", QString::null);
 	kdebugf2();
 	return 0;
 }
 
-extern "C" void sms_close()
+extern "C" KADU_EXPORT void sms_close()
 {
 	kdebugf();
 
@@ -56,9 +59,8 @@ extern "C" void sms_close()
 			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
 	QObject::disconnect(kadu->userbox(), SIGNAL(returnPressed(UserListElement)),
 			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
-	QObject::disconnect(kadu->userbox(), SIGNAL(mouseButtonClicked(int, QListBoxItem*,const QPoint&)),
-			smsConfigurationUiHandler, SLOT(onUserClicked(int, QListBoxItem*, const QPoint&)));
-	QObject::disconnect(UserBox::userboxmenu, SIGNAL(popup()), smsConfigurationUiHandler, SLOT(onPopupMenuCreate()));
+	QObject::disconnect(kadu->userbox(), SIGNAL(mouseButtonClicked(int, Q3ListBoxItem*,const QPoint&)),
+			smsConfigurationUiHandler, SLOT(onUserClicked(int, Q3ListBoxItem*, const QPoint&)));
 
 	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/sms.ui"), smsConfigurationUiHandler);
 	delete smsConfigurationUiHandler;
@@ -70,23 +72,30 @@ extern "C" void sms_close()
 /********** SmsImageDialog **********/
 
 SmsImageDialog::SmsImageDialog(QWidget* parent, const QByteArray& image)
-	: QDialog(parent, "SmsImageDialog"), code_edit(0)
+	: QDialog(parent), code_edit(0)
 {
 	kdebugf();
 
-	ImageWidget *image_widget = new ImageWidget(this, image);
-	QLabel* label=new QLabel(tr("Enter text from the picture:"), this);
-	code_edit=new QLineEdit(this);
+	ImageWidget *image_widget = new ImageWidget(image, this);
+	QLabel* label = new QLabel(tr("Enter text from the picture:"), this);
+	code_edit = new QLineEdit(this);
 
 	QGridLayout *grid = new QGridLayout(this, 3, 2, 10, 10);
 	grid->addMultiCellWidget(image_widget, 0, 0, 0, 1);
 	grid->addWidget(label, 1, 0);
 	grid->addWidget(code_edit, 1, 1);
-	QHBox *buttons = new QHBox(this);
-	buttons->setSpacing(10);
-	QPushButton *okButton = new QPushButton(tr("Ok"), buttons);
-	QPushButton *cancelButton = new QPushButton(tr("Cancel"), buttons);
-	grid->addMultiCellWidget(buttons, 2, 2, 0, 1);
+	
+	QWidget *buttonsWidget = new QWidget(this);
+	QHBoxLayout *buttonsLayout = new QHBoxLayout(buttonsWidget);
+
+	QPushButton *okButton = new QPushButton(tr("Ok"), buttonsWidget);
+	QPushButton *cancelButton = new QPushButton(tr("Cancel"), buttonsWidget);
+
+	buttonsLayout->setSpacing(10);
+	buttonsLayout->addWidget(okButton);
+	buttonsLayout->addWidget(cancelButton);
+
+	grid->addMultiCellWidget(buttonsWidget, 2, 2, 0, 1);
 
 	connect(code_edit, SIGNAL(returnPressed()), this, SLOT(onReturnPressed()));
 	connect(okButton, SIGNAL(clicked()), this, SLOT(onReturnPressed()));
@@ -112,12 +121,12 @@ void SmsImageDialog::onReturnPressed()
 
 /********** SmsGateway **********/
 
-SmsGateway::SmsGateway(QObject* parent, const char *name)
-	: QObject(parent, name), State(SMS_LOADING_PAGE), Number(), Signature(), Message(), Http()
+SmsGateway::SmsGateway(QObject* parent)
+	: QObject(parent), State(SMS_LOADING_PAGE), Number(), Signature(), Message(), Http()
 {
-	QObject::connect(&Http, SIGNAL(finished()), this, SLOT(httpFinished()));
-	QObject::connect(&Http, SIGNAL(redirected(QString)), this, SLOT(httpRedirected(QString)));
-	QObject::connect(&Http, SIGNAL(error()), this, SLOT(httpError()));
+	connect(&Http, SIGNAL(finished()), this, SLOT(httpFinished()));
+	connect(&Http, SIGNAL(redirected(QString)), this, SLOT(httpRedirected(QString)));
+	connect(&Http, SIGNAL(error()), this, SLOT(httpError()));
 }
 
 void SmsGateway::httpError()
@@ -130,8 +139,8 @@ void SmsGateway::httpError()
 
 /********** SmsSender **********/
 
-SmsSender::SmsSender(QObject* parent, const char *name)
-	: QObject(parent, name), Gateway(0)
+SmsSender::SmsSender(QObject* parent)
+	: QObject(parent), Gateway(0)
 {
 }
 
@@ -141,7 +150,7 @@ SmsSender::~SmsSender()
 	emit finished(false);
 	if (Gateway)
 	{
-		QObject::disconnect(Gateway, SIGNAL(finished(bool)), this, SLOT(onFinished(bool)));
+		disconnect(Gateway, SIGNAL(finished(bool)), this, SLOT(onFinished(bool)));
 		delete Gateway;
 	}
 	kdebugf2();
@@ -156,9 +165,9 @@ void SmsSender::send(const QString& number,const QString& message, const QString
 {
 	kdebugf();
 	QString Number=number;
-	if (Number.length()==12 && Number.left(3)=="+48")
+	if (Number.length() == 12 && Number.left(3) == "+48")
 		Number=Number.right(9);
-	if (Number.length()!=9)
+	if (Number.length() != 9)
 	{
 		MessageBox::msg(tr("Mobile number is incorrect"), false, "Warning", (QWidget*)parent());
 		emit finished(false);
@@ -172,9 +181,9 @@ void SmsSender::send(const QString& number,const QString& message, const QString
 		kdebugf2();
 		return;
 	}
-	Gateway=smsConfigurationUiHandler->getGateway(Number);
+	Gateway = smsConfigurationUiHandler->getGateway(Number);
 
-	if (Gateway==NULL)
+	if (!Gateway)
 	{
 		MessageBox::msg(tr("Mobile number is incorrect or gateway is not available"), false, "Warning", (QWidget*)parent());
 		emit finished(false);
@@ -182,24 +191,27 @@ void SmsSender::send(const QString& number,const QString& message, const QString
 		return;
 	}
 
-	QObject::connect(Gateway, SIGNAL(finished(bool)), this, SLOT(onFinished(bool)));
+	connect(Gateway, SIGNAL(finished(bool)), this, SLOT(onFinished(bool)));
 	Gateway->send(Number, message, contact, signature);
 	kdebugf2();
 }
 
 /********** Sms **********/
 
-Sms::Sms(const QString& altnick, QWidget* parent, const char *name) : QWidget(parent, name, WType_TopLevel | WDestructiveClose),
+Sms::Sms(const QString& altnick, QWidget* parent) : QWidget(parent, Qt::Window),
 	body(0), recipient(0), list(0), smslen(0), l_contact(0), e_contact(0), l_signature(0),
 	e_signature(0), b_send(0), c_saveInHistory(0), smsProcess(0), Sender()
 {
 	kdebugf();
 
+	setWindowTitle(tr("Send SMS"));
+	setAttribute(Qt::WA_DeleteOnClose);
+
 	QGridLayout *grid = new QGridLayout(this, 3, 4, 10, 7);
 
-	body = new QMultiLineEdit(this);
+	body = new QTextEdit(this);
 	grid->addMultiCellWidget(body, 1, 1, 0, 3);
-	body->setWordWrap(QMultiLineEdit::WidgetWidth);
+	body->setLineWrapMode(QTextEdit::WidgetWidth);
 	body->setTabChangesFocus(true);
 	connect(body, SIGNAL(textChanged()), this, SLOT(updateCounter()));
 
@@ -214,9 +226,9 @@ Sms::Sms(const QString& altnick, QWidget* parent, const char *name) : QWidget(pa
 	grid->addWidget(recipient, 0, 1);
 
 	QStringList strlist; // lista kontaktow z przypisanym numerem telefonu
-	CONST_FOREACH(user, *userlist)
-		if (!(*user).mobile().isEmpty())
-		 	strlist.append((*user).altNick());
+	foreach(const UserListElement &user, *userlist)
+		if (!user.mobile().isEmpty())
+		 	strlist.append(user.altNick());
 	strlist.sort();
 	strlist.prepend(QString::null);
 
@@ -249,7 +261,7 @@ Sms::Sms(const QString& altnick, QWidget* parent, const char *name) : QWidget(pa
 	grid->addMultiCellWidget(c_saveInHistory, 5, 5, 0, 1);
 
 	b_send = new QPushButton(this);
-	b_send->setIconSet(icons_manager->loadIconSet("SendSMSButton"));
+	b_send->setIcon(icons_manager->loadIcon("SendSMSButton"));
 	b_send->setText(tr("&Send"));
 	b_send->setDefault(true);
 	b_send->setMaximumWidth(200);
@@ -257,12 +269,11 @@ Sms::Sms(const QString& altnick, QWidget* parent, const char *name) : QWidget(pa
 	grid->addWidget(b_send, 5, 3, Qt::AlignRight);
 
 	resize(400, 250);
-	setCaption(tr("Send SMS"));
 
 	connect(&Sender, SIGNAL(finished(bool)), this, SLOT(onSmsSenderFinished(bool)));
 
 	configurationUpdated();
-	loadGeometry(this, "Sms", "SmsDialogGeometry", 200, 200, 400, 250);
+	loadWindowGeometry(this, "Sms", "SmsDialogGeometry", 200, 200, 400, 250);
 
 	modules_manager->moduleIncUsageCount("sms");
 	kdebugf2();
@@ -270,7 +281,7 @@ Sms::Sms(const QString& altnick, QWidget* parent, const char *name) : QWidget(pa
 
 Sms::~Sms()
 {
-	saveGeometry(this, "Sms", "SmsDialogGeometry");
+	saveWindowGeometry(this, "Sms", "SmsDialogGeometry");
 
 	modules_manager->moduleDecUsageCount("sms");
 }
@@ -282,16 +293,16 @@ void Sms::configurationUpdated()
 
 void Sms::setRecipient(const QString &phone)
 {
-    kdebugf();
-    recipient->setText(phone);
-    body->setFocus();
-    kdebugf2();
+    	kdebugf();
+  	recipient->setText(phone);
+  	body->setFocus();
+  	kdebugf2();
 }
 
 void Sms::updateRecipient(const QString &newtext)
 {
 	kdebugf();
-//	kdebugmf(KDEBUG_FUNCTION_START | KDEBUG_INFO, "'%s' %d %d\n", newtext.local8Bit().data(), newtext.isEmpty(), userlist->containsAltNick(newtext));
+//	kdebugmf(KDEBUG_FUNCTION_START | KDEBUG_INFO, "'%s' %d %d\n", qPrintable(newtext), newtext.isEmpty(), userlist->containsAltNick(newtext));
 	if (newtext.isEmpty())
 	{
 		recipient->clear();
@@ -311,10 +322,10 @@ void Sms::updateList(const QString &newnumber)
 		kdebugmf(KDEBUG_FUNCTION_END, "end: new number is empty\n");
 		return;
 	}
-	CONST_FOREACH(user, *userlist)
-		if ((*user).mobile() == newnumber)
+	foreach(const UserListElement &user, *userlist)
+		if (user.mobile() == newnumber)
 		{
-			list->setCurrentText((*user).altNick());
+			list->setCurrentText(user.altNick());
 			kdebugf2();
 			return;
 		}
@@ -322,7 +333,7 @@ void Sms::updateList(const QString &newnumber)
 	kdebugf2();
 }
 
-void Sms::editReturnPressed(void)
+void Sms::editReturnPressed()
 {
 	kdebugf();
 
@@ -334,7 +345,7 @@ void Sms::editReturnPressed(void)
 	kdebugf2();
 }
 
-void Sms::sendSms(void)
+void Sms::sendSms()
 {
 	kdebugf();
 	b_send->setEnabled(false);
@@ -368,19 +379,19 @@ void Sms::sendSms(void)
 				*args.find("%n") = recipient->text();
 			if(args.find("%m") != args.end())
 				*args.find("%m") = body->text();
-			args.prepend(SmsAppPath);
-			smsProcess->setArguments(args);
+
+			smsProcess->start(SmsAppPath, args);
 		}
 		else
 		{
-			smsProcess->addArgument(SmsAppPath);
-			smsProcess->addArgument(recipient->text());
-			smsProcess->addArgument(body->text());
+			QStringList args(recipient->text());
+			args.append(body->text());
+			smsProcess->start(SmsAppPath, args);
 		}
 
-		if (!smsProcess->start())
+		if (!smsProcess->waitForStarted())
 			MessageBox::msg(tr("Could not spawn child process. Check if the program is functional"), false, "Warning", this);
-		QObject::connect(smsProcess, SIGNAL(processExited()), this, SLOT(smsSigHandler()));
+		connect(smsProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(smsSigHandler()));
 	}
 	kdebugf2();
 }
@@ -388,12 +399,12 @@ void Sms::sendSms(void)
 void Sms::smsSigHandler()
 {
 	kdebugf();
-	if (smsProcess->normalExit())
+	if (smsProcess->exitStatus() == QProcess::NormalExit)
 		MessageBox::msg(tr("The process exited normally. The SMS should be on its way"), false, "Information", this);
 	else
 		MessageBox::msg(tr("The process exited abnormally. The SMS may not be sent"), false, "Warning", this);
 	delete smsProcess;
-	smsProcess = NULL;
+	smsProcess = 0;
 
 	c_saveInHistory->setEnabled(true);
 	e_contact->setEnabled(true);
@@ -434,7 +445,7 @@ void Sms::onSmsSenderFinished(bool success)
 
 void Sms::keyPressEvent(QKeyEvent *e)
 {
-	if (e->key() == Key_Escape)
+	if (e->key() == Qt::Key_Escape)
 	{
 		e->accept();
 		close();
@@ -444,35 +455,30 @@ void Sms::keyPressEvent(QKeyEvent *e)
 }
 
 SmsConfigurationUiHandler::SmsConfigurationUiHandler()
-	: menuid(0), gateways()
+	: menuid(0), gateways(), gatewayListWidget(0)
 {
 	kdebugf();
 
 	createDefaultConfiguration();
 
-	UserBox::userboxmenu->addItemAtPos(2, "SendSms", tr("Send SMS"), this, SLOT(onSendSmsToUser()),
-                HotKey::shortCutFromFile("ShortCuts", "kadu_sendsms"));
-
-	QPopupMenu *MainMenu = kadu->mainMenu();
-	menuid = MainMenu->insertItem(icons_manager->loadIcon("SendSms"), tr("Send SMS"), this, SLOT(onSendSms()), 0, -1, 10);
-	icons_manager->registerMenuItem(MainMenu, tr("Send SMS"), "SendSms");
-
-	Action* send_sms_action = new Action("SendSms", tr("Send SMS"), "sendSmsAction", Action::TypeGlobal);
-	connect(send_sms_action, SIGNAL(activated(const UserGroup*, const QWidget*, bool)),
-		this, SLOT(sendSmsActionActivated(const UserGroup*)));
-
+	sendSmsActionDescription = new ActionDescription(
+		ActionDescription::TypeGlobal, "sendSmsAction",
+		this, SLOT(sendSmsActionActivated(QAction *, bool)),
+		"SendSms", tr("Send SMS"), false
+	);
+	sendSmsActionDescription->setShortcut("kadu_sendsms");
+	UserBox::insertActionDescription(2, sendSmsActionDescription);
+	kadu->insertMenuActionDescription(10, sendSmsActionDescription);
 	kdebugf2();
 }
 
 SmsConfigurationUiHandler::~SmsConfigurationUiHandler()
 {
 	kdebugf();
-	int sendsmstem = UserBox::userboxmenu->getItem(tr("Send SMS"));
-	UserBox::userboxmenu->removeItem(sendsmstem);
-	kadu->mainMenu()->removeItem(menuid);
 
-	Action *send_sms_action = KaduActions["sendSmsAction"];
-	delete send_sms_action;
+	UserBox::removeActionDescription(sendSmsActionDescription);
+	kadu->removeMenuActionDescription(sendSmsActionDescription);
+	delete sendSmsActionDescription;
 	kdebugf2();
 }
 
@@ -495,14 +501,12 @@ void SmsConfigurationUiHandler::onSmsBuildInCheckToggle(bool value)
 
 void SmsConfigurationUiHandler::configurationUpdated()
 {
-	QStringList priority;
-	QListBoxItem *item = gatewayListBox->firstItem();
+	if (!gatewayListWidget)
+		return;
 
-	while (item)
-	{
-		priority += item->text();
-		item = item->next();
-	}
+	QStringList priority;
+	for (int index = 0; index < gatewayListWidget->count(); ++index)
+			priority += gatewayListWidget->item(index)->text();
 
 	// FIXME: : instead of ;
 	config_file.writeEntry("SMS", "Priority", priority.join(";"));
@@ -510,13 +514,24 @@ void SmsConfigurationUiHandler::configurationUpdated()
 
 void SmsConfigurationUiHandler::newSms(QString nick)
 {
-	(new Sms(nick, kadu, "sms"))->show();
+	(new Sms(nick, kadu))->show();
 }
 
-void SmsConfigurationUiHandler::onUserClicked(int button, QListBoxItem* /*item*/, const QPoint& /*pos*/)
+void SmsConfigurationUiHandler::onUserClicked(int button, Q3ListBoxItem* item, const QPoint& /*pos*/)
 {
-	if (button==4)
-		onSendSmsToUser();
+	if (button == 4)
+	{
+		UserBox *userbox = dynamic_cast<UserBox *>(item->listBox());
+		if (userbox)
+		{
+			UserListElements users = userbox->selectedUsers();
+ 			if (users.count() != 1)
+ 				return;
+
+ 			if (!users[0].mobile().isEmpty())
+ 				newSms(users[0].altNick());
+		}
+	}
 }
 
 void SmsConfigurationUiHandler::onUserDblClicked(UserListElement user)
@@ -527,33 +542,13 @@ void SmsConfigurationUiHandler::onUserDblClicked(UserListElement user)
 	kdebugf2();
 }
 
-void SmsConfigurationUiHandler::onSendSmsToUser()
-{
-	kdebugf();
-	UserListElements users;
-	UserBox *activeUserBox = kadu->userbox()->activeUserBox();
-	if (activeUserBox==NULL)
-		return;
-	users = activeUserBox->selectedUsers();
-	if (users.count() != 1)
-		return;
-	if (!users[0].mobile().isEmpty())
-		newSms(users[0].altNick());
-	kdebugf2();
-}
-
-void SmsConfigurationUiHandler::onSendSms()
-{
-	newSms(QString::null);
-}
-
 void SmsConfigurationUiHandler::registerGateway(QString name, isValidFunc* f)
 {
 	kdebugf();
-	QStringList priority=QStringList::split(";", config_file.readEntry("SMS", "Priority"));
+	QStringList priority = QStringList::split(";", config_file.readEntry("SMS", "Priority"));
 	if (!priority.contains(name))
 	{
-		priority+=name;
+		priority += name;
 		config_file.writeEntry("SMS", "Priority", priority.join(";"));
 	}
 	gateways.insert(name, f);
@@ -572,12 +567,12 @@ SmsGateway* SmsConfigurationUiHandler::getGateway(const QString& number)
 	kdebugf();
 	QStringList priorities = QStringList::split(";", config_file.readEntry("SMS", "Priority"));
 
-	CONST_FOREACH(gate, priorities)
+	foreach(const QString &gate, priorities)
 	{
-		if (gateways.contains(*gate))
+		if (gateways.contains(gate))
 		{
-			isValidFunc *f=gateways[*gate];
-			SmsGateway *Gateway=f(number, this);
+			isValidFunc *f = gateways[gate];
+			SmsGateway *Gateway = f(number, this);
 			if (Gateway)
 			{
 				kdebugf2();
@@ -592,69 +587,67 @@ SmsGateway* SmsConfigurationUiHandler::getGateway(const QString& number)
 
 void SmsConfigurationUiHandler::onUpButton()
 {
-	unsigned int index = gatewayListBox->currentItem();
-	if (index == 0)
+	int index = gatewayListWidget->currentRow();
+	if (index < 1)
 		return;
 
-	QString text = gatewayListBox->text(index);
-	gatewayListBox->removeItem(index);
-	gatewayListBox->insertItem(text, --index);
-	gatewayListBox->setSelected(gatewayListBox->findItem(text), true);
+	QListWidgetItem * item = gatewayListWidget->takeItem(index);
+	gatewayListWidget->insertItem(--index, item);
+	item->setSelected(true);
+	gatewayListWidget->setCurrentItem(item);
 }
 
 void SmsConfigurationUiHandler::onDownButton()
 {
-	unsigned int index = gatewayListBox->currentItem();
-	if (index == gatewayListBox->count() - 1)
+	int index = gatewayListWidget->currentRow();
+	if (index == gatewayListWidget->count() - 1 || index == -1)
 		return;
 
-	QString text = gatewayListBox->text(index);
-	gatewayListBox->removeItem(index);
-	gatewayListBox->insertItem(text, ++index);
-	gatewayListBox->setSelected(gatewayListBox->findItem(text), true);
+	QListWidgetItem *item = gatewayListWidget->takeItem(index);
+	gatewayListWidget->insertItem(++index, item);
+	item->setSelected(true);
+	gatewayListWidget->setCurrentItem(item);
 }
 
-void SmsConfigurationUiHandler::onPopupMenuCreate()
+void SmsConfigurationUiHandler::sendSmsActionActivated(QAction *sender, bool toggled)
 {
 	kdebugf();
 
-	UserBox *activeUserBox = kadu->userbox()->activeUserBox();
-	if (activeUserBox == NULL) //to sie zdarza...
-		return;
+	KaduMainWindow *window = dynamic_cast<KaduMainWindow *>(sender->parent());
+	if (window)
+	{
+		UserListElements users = window->userListElements();
 
-	UserListElements users = activeUserBox->selectedUsers();
-	if ((users[0]).mobile().isEmpty() || users.count() != 1)
-		UserBox::userboxmenu->setItemVisible(UserBox::userboxmenu->getItem(tr("Send SMS")), false);
-
-	kdebugf2();
-}
-
-void SmsConfigurationUiHandler::sendSmsActionActivated(const UserGroup* users)
-{
-	kdebugf();
-
-	if (users != NULL && users->count() == 1 && !(*users->begin()).mobile().isEmpty())
-		newSms((*users->begin()).altNick());
-	else
-		newSms(QString::null);
+		if (users.count() == 1 && !users[0].mobile().isEmpty())
+		{
+			newSms(users[0].altNick());
+			return;
+		}
+	}
+	newSms(QString::null);
 
 	kdebugf2();
 }
 
 void SmsConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
 {
+	connect(mainConfigurationWindow, SIGNAL(destroyed(QObject *)), this, SLOT(mainConfigurationWindowDestroyed()));
+
 	useBuiltIn = dynamic_cast<QCheckBox *>(mainConfigurationWindow->widgetById("sms/useBuildInApp"));
 	customApp = dynamic_cast<QLineEdit *>(mainConfigurationWindow->widgetById("sms/customApp"));
 	useCustomString = dynamic_cast<QCheckBox *>(mainConfigurationWindow->widgetById("sms/useCustomString"));
 	customString = dynamic_cast<QLineEdit *>(mainConfigurationWindow->widgetById("sms/customString"));
 
 	ConfigGroupBox *gatewayGroupBox = mainConfigurationWindow->configGroupBox("SMS", "General", "Gateways");
-	QHBox *gatewayHBox = new QHBox(gatewayGroupBox->widget());
-	gatewayHBox->setSpacing(5);
 
-	gatewayListBox = new QListBox(gatewayHBox);
+	QWidget *gatewayWidget = new QWidget(gatewayGroupBox->widget());
 
-	QWidget *buttons = new QWidget(gatewayHBox);
+	QHBoxLayout *gatewayLayout = new QHBoxLayout(gatewayWidget);
+	gatewayLayout->setSpacing(5);
+
+	gatewayListWidget = new QListWidget(gatewayWidget);
+
+	QWidget *buttons = new QWidget(gatewayWidget);
 	QVBoxLayout *buttonsLayout = new QVBoxLayout(buttons);
 	buttonsLayout->setSpacing(5);
 
@@ -665,10 +658,13 @@ void SmsConfigurationUiHandler::mainConfigurationWindowCreated(MainConfiguration
 	buttonsLayout->addWidget(down);
 	buttonsLayout->addStretch(100);
 
+	gatewayLayout->addWidget(gatewayListWidget);
+	gatewayLayout->addWidget(buttons);
+
 	connect(up, SIGNAL(clicked()), this, SLOT(onUpButton()));
 	connect(down, SIGNAL(clicked()), this, SLOT(onDownButton()));
 
-	gatewayGroupBox->addWidgets(new QLabel(tr("Gateways priorites"), gatewayGroupBox->widget()), gatewayHBox);
+	gatewayGroupBox->addWidgets(new QLabel(tr("Gateways priorites"), gatewayGroupBox->widget()), gatewayWidget);
 	
 	connect(useBuiltIn, SIGNAL(toggled(bool)), this, SLOT(onSmsBuildInCheckToggle(bool)));
 	connect(useCustomString, SIGNAL(toggled(bool)), customString, SLOT(setEnabled(bool)));
@@ -676,17 +672,23 @@ void SmsConfigurationUiHandler::mainConfigurationWindowCreated(MainConfiguration
 // TODO: fix it, should be ':' not ';'
 	QStringList priority = QStringList::split(";", config_file.readEntry("SMS", "Priority"));
 
-	CONST_FOREACH(gate, priority)
-		if (gateways.contains(*gate))
-			gatewayListBox->insertItem(*gate);
+	foreach(const QString &gate, priority)
+		if (gateways.contains(gate))
+			gatewayListWidget->addItem(gate);
 
-	CONST_FOREACH(gate, gateways)
-		if (gatewayListBox->index(gatewayListBox->findItem(gate.key())) == -1)
-			gatewayListBox->insertItem(gate.key());
+	foreach(const QString &key, gateways.keys())
+		if (gatewayListWidget->findItems(key, 0).isEmpty())
+			gatewayListWidget->addItem(key);
+}
+
+void SmsConfigurationUiHandler::mainConfigurationWindowDestroyed()
+{
+	gatewayListWidget = 0; // protect configurationUpdated
 }
 
 void SmsConfigurationUiHandler::createDefaultConfiguration()
 {
+	config_file.addVariable("SMS", "Priority", QString::null);
 	config_file.addVariable("SMS", "BuiltInApp", true);
 	config_file.addVariable("SMS", "SmsNick", "");
 	config_file.addVariable("SMS", "UseCustomString", false);
