@@ -8,7 +8,7 @@
  ***************************************************************************/
 
 
-#define QT_CLEAN_NAMESPACE
+///#define QT_CLEAN_NAMESPACE
 // Avoid compilation error: http://www.kadu.net/forum/viewtopic.php?p=84272#84272
 // >   In file included from /usr/include/X11/extensions/XI.h:55,
 // >                    from /usr/include/X11/extensions/XInput.h:56,
@@ -19,10 +19,11 @@
 // >   /opt/qt/include/qglobal.h:706: error: 'INT32' has a previous declaration as 'typedef int INT32'
 
 
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qlineedit.h>
-#include <qspinbox.h>
+#include <QApplication>
+#include <QCursor>
+#include <QDesktopWidget>
+#include <QLineEdit>
+#include <QSpinBox>
 
 #include "config_file.h"
 #include "debug.h"
@@ -135,9 +136,10 @@ void PanelKadu::createDefaultConfiguration()
 	config_file.addVariable( "PanelKadu", "PanelLength"            , PANELKADU_DEFAULTLENGTH         );
 	config_file.addVariable( "PanelKadu", "ActivationTime"         , PANELKADU_DEFAULTACTIVATIONTIME );
 	config_file.addVariable( "PanelKadu", "HideTime"               , PANELKADU_DEFAULTHIDETIME       );
+	config_file.addVariable( "PanelKadu", "HidingMargin"           , 0                               );
 	config_file.addVariable( "PanelKadu", "UseActivationRanges"    , false                           );
 	config_file.addVariable( "PanelKadu", "ActivationRanges"       , ""                              );
-	config_file.addVariable( "PanelKadu", "DontHidePanelWhenActive", true                            );
+	config_file.addVariable( "PanelKadu", "DontHidePanelWhenActive", false                           );
 }
 
 
@@ -151,6 +153,7 @@ void PanelKadu::configurationUpdated()
 	panelLength             = config_file.readNumEntry(  "PanelKadu", "PanelLength"             );
 	activationTime          = config_file.readNumEntry(  "PanelKadu", "ActivationTime"          );
 	hideTime                = config_file.readNumEntry(  "PanelKadu", "HideTime"                );
+	hidingMargin            = config_file.readNumEntry(  "PanelKadu", "HidingMargin"            );
 	useActivationRanges     = config_file.readBoolEntry( "PanelKadu", "UseActivationRanges"     );
 	activationRanges        = config_file.readEntry(     "PanelKadu", "ActivationRanges"        );
 	dontHidePanelWhenActive = config_file.readBoolEntry( "PanelKadu", "DontHidePanelWhenActive" );
@@ -241,10 +244,10 @@ bool PanelKadu::isInActivationRanges( int number )
 		range = QStringList::split( "-", *it, true );
 		if( range.count() != 2 )
 			return true;
-		a = (*(range.at(0))).toInt( &ok, 10 );
+		a = range.at(0).toInt( &ok, 10 );
 		if( ! ok )
 			return true;
-		b = (*(range.at(1))).toInt( &ok, 10 );
+		b = range.at(1).toInt( &ok, 10 );
 		if( ! ok )
 			return true;
 		if( ( number >= a ) && ( number <= b ) )
@@ -348,12 +351,12 @@ void PanelKadu::checkMouse()
 	else if( kadu->isVisible() && ( ( ! dontHidePanelWhenActive ) || ( ! kadu->isActiveWindow() ) ) )  // panel is show and can be hidden
 	{
 		activationTimer->stop();
-		if( sidecursordist >= windowsize )  // cursor distance from the edge is greater than the panel size
+		if( sidecursordist >= windowsize+hidingMargin )  // cursor distance from the edge is greater than the panel size
 		{
 			if( ! hidingTimer->isActive() )
 				hidingTimer->start( hideTime, true );
 		}
-		else if( ( ( sidecursorpos < position ) || ( sidecursorpos > position+length ) ) )  // cursor is outside the panel
+		else if( ( ( sidecursorpos < position-hidingMargin ) || ( sidecursorpos > position+length+hidingMargin ) ) )  // cursor is outside the panel
 		{
 			if( sidecursordist > 0 )  // cursor is not touching the edge
 			{
