@@ -2,8 +2,8 @@
 	#define PANELKADU_H
 
 
-#include <qobject.h>
-#include <qtimer.h>
+#include <QObject>
+#include <QTimer>
 
 #include "configuration_aware_object.h"
 #include "main_configuration_window.h"
@@ -50,6 +50,7 @@ class PanelKadu : public ConfigurationUiHandler, ConfigurationAwareObject
 		int panelLength;                // configuration value
 		int activationTime;             // configuration value
 		int hideTime;                   // configuration value
+		int hidingMargin;               // configuration value
 		bool useActivationRanges;       // configuration value
 		QString activationRanges;       // configuration value
 		bool dontHidePanelWhenActive;   // configuration value
