@@ -1,7 +1,8 @@
 #ifndef POWERKADU_H
 #define POWERKADU_H
 
-#include <qobject.h>
+#include <QtCore/QObject>
+#include "action.h"
 
 class AboutDialog;
 
@@ -12,10 +13,10 @@ class PowerKadu : public QObject
 	public:
 		PowerKadu();
 		~PowerKadu();
+
 	private:
-		int pos;
-		int separatorPos;
 		AboutDialog *aboutDialog;
+		ActionDescription *powerKaduMenuActionDescription;
 
 	private slots:
 		void onAboutPowerKadu();
