@@ -78,6 +78,22 @@ It&apos;s a high security risk!</source>
         <source>%1 weeks and %2 days ago at </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 weeks and day ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week and day ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week and %2 days ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>d MMMM yyyy at </source>
         <translation type="unfinished"></translation>
@@ -319,7 +335,7 @@ It&apos;s a high security risk!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 217.17.41.82;217.17.41.83;217.17.41.84;217.17.41.144)</source>
+        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -430,18 +446,34 @@ It&apos;s a high security risk!</source>
         <source>Online</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Busy</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Invisible</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Offline</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>On startup, set last description</source>
         <translation type="unfinished"></translation>
@@ -1017,6 +1049,26 @@ It&apos;s a high security risk!</source>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start on startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically start on system startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>About</name>
@@ -1118,14 +1170,6 @@ It&apos;s a high security risk!</source>
         <source>Leave conference</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Edit window:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This is where you type in the text to be sent</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Insert image</source>
         <translation type="unfinished"></translation>
@@ -1218,22 +1262,38 @@ from now on. Are you sure you want to leave this conference?</source>
     </message>
 </context>
 <context>
-    <name>DockArea</name>
+    <name>CustomInput</name>
     <message>
-        <source>Create new toolbar</source>
+        <source>Undo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Block toolbars</source>
+        <source>Redo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select All</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>GaduFormater</name>
-    <message>
-        <source>###TOO MANY IMAGES###</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>###IMAGE BLOCKED###</source>
         <translation type="unfinished"></translation>
@@ -1383,10 +1443,6 @@ Too many attempts with bad password</source>
         <source>Kadu: %1</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Open chat window</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Notify about user</source>
         <translation type="unfinished"></translation>
@@ -1415,18 +1471,10 @@ Too many attempts with bad password</source>
         <source>Manage &amp;ignored</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Configuration</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Personal information</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Add user</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>H&amp;elp</source>
         <translation type="unfinished"></translation>
@@ -1439,10 +1487,6 @@ Too many attempts with bad password</source>
         <source>&amp;Hide Kadu</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Kadu</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Private</source>
         <translation type="unfinished"></translation>
@@ -1451,12 +1495,6 @@ Too many attempts with bad password</source>
         <source>I&amp;mport / Export userlist</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Selected users:
-%0
-will be deleted. Are you sure?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide description</source>
         <translation type="unfinished"></translation>
@@ -1465,10 +1503,6 @@ will be deleted. Are you sure?</source>
         <source>Search user in directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Search user in directory</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Copy description</source>
         <translation type="unfinished"></translation>
@@ -1489,10 +1523,6 @@ will be deleted. Are you sure?</source>
         <source>Open description link in browser</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>User management</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Write email message</source>
         <translation type="unfinished"></translation>
@@ -1501,14 +1531,6 @@ will be deleted. Are you sure?</source>
         <source>Search in directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ignore</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Block</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation type="unfinished"></translation>
@@ -1541,10 +1563,6 @@ will be deleted. Are you sure?</source>
         <source>Recent chats...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Open chat with...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>No closed chats found</source>
         <translation type="unfinished"></translation>
@@ -1557,6 +1575,54 @@ will be deleted. Are you sure?</source>
         <source>Me</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Selected users:
+%0will be deleted. Are you sure?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>KaduMainWindow</name>
+    <message>
+        <source>Create new toolbar</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>KaduTabBar</name>
@@ -1579,14 +1645,6 @@ will be deleted. Are you sure?</source>
 </context>
 <context>
     <name>KaduTextBrowser</name>
-    <message>
-        <source>Copy link &amp;location</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Save image...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save image</source>
         <translation type="unfinished"></translation>
@@ -1599,6 +1657,22 @@ will be deleted. Are you sure?</source>
         <source>Cannot save image: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainConfigurationWindow</name>
@@ -1664,10 +1738,6 @@ will be deleted. Are you sure?</source>
         <source>Loaded</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption. You can load (or unload) them by double-clicking on their names.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Module name</source>
         <translation type="unfinished"></translation>
@@ -1708,6 +1778,11 @@ will be deleted. Are you sure?</source>
         <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
+You can load (or unload) them by double-clicking on their names.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModulesManager</name>
@@ -1794,10 +1869,6 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Choose</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>OK</source>
         <translation type="unfinished"></translation>
@@ -1878,13 +1949,6 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>PixmapPreview</name>
-    <message>
-        <source>This is not an image</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>SearchDialog</name>
     <message>
@@ -2014,6 +2078,14 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <source>Insert image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SelectFont</name>
@@ -2076,13 +2148,6 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>Themes</name>
-    <message>
-        <source>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;does not contain any theme configuration file</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>TokenDialog</name>
     <message>
@@ -2112,10 +2177,6 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <source>Add new button</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Panel menu</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove toolbar?</source>
         <translation type="unfinished"></translation>
@@ -2124,19 +2185,20 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <source>No items to add found</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>ToolButton</name>
-    <message>
-        <source>Delete button</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Show text label</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Toolbar menu</source>
+        <source>Delete button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Create new toolbar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Block toolbars</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -2169,6 +2231,10 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <source>Nicks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>User management</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UserInfo</name>
@@ -2312,6 +2378,38 @@ Maybe it&apos;s not Kadu-compatible Module.</source>
         <source>User known as %1 with that UIN is already in userlist.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UserStatus</name>
