@@ -80,6 +80,22 @@ Attention danger!
         <source>%1 weeks and %2 days ago at </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 weeks and day ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week and day ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week and %2 days ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>d MMMM yyyy at </source>
         <translation type="unfinished"></translation>
@@ -321,7 +337,7 @@ Attention danger!
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 217.17.41.82;217.17.41.83;217.17.41.84;217.17.41.144)</source>
+        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -430,19 +446,35 @@ Attention danger!
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished">En ligne</translation>
+        <translation>En ligne</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation>En ligne avec description</translation>
     </message>
     <message>
         <source>Busy</source>
-        <translation type="unfinished">Je reviens toute suite</translation>
+        <translation>Je reviens toute suite</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation>Je reviens toute suite avec description</translation>
     </message>
     <message>
         <source>Invisible</source>
-        <translation type="unfinished">Invisible</translation>
+        <translation>Invisible</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation>Invisible (description.)</translation>
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Hors ligne</translation>
+        <translation>Hors ligne</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation>Hors ligne ( avec description.)</translation>
     </message>
     <message>
         <source>On startup, set last description</source>
@@ -1019,6 +1051,26 @@ Attention danger!
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start on startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically start on system startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>About</name>
@@ -1120,14 +1172,6 @@ Attention danger!
         <source>Leave conference</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Edit window:</source>
-        <translation type="unfinished">Fenêtre édition:</translation>
-    </message>
-    <message>
-        <source>This is where you type in the text to be sent</source>
-        <translation type="unfinished">C&apos;est ici que vous saisissez le texte à envoyer</translation>
-    </message>
     <message>
         <source>Insert image</source>
         <translation type="unfinished">Insère l&apos;image</translation>
@@ -1223,22 +1267,38 @@ from now on. Are you sure you want to leave this conference?</source>
     </message>
 </context>
 <context>
-    <name>DockArea</name>
+    <name>CustomInput</name>
     <message>
-        <source>Create new toolbar</source>
-        <translation>Créez un nouveau barre d&apos;outil</translation>
+        <source>Undo</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Block toolbars</source>
+        <source>Redo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select All</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>GaduFormater</name>
-    <message>
-        <source>###TOO MANY IMAGES###</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>###IMAGE BLOCKED###</source>
         <translation type="unfinished">###IMAGE BLOQUÉ###</translation>
@@ -1405,10 +1465,6 @@ Too many attempts with bad password</source>
         <source>&amp;Exit Kadu</source>
         <translation>&amp;Sortir de  Kadu</translation>
     </message>
-    <message>
-        <source>Open chat window</source>
-        <translation>Ouvre la fenêtre de conversation</translation>
-    </message>
     <message>
         <source>Notify about user</source>
         <translation>Renseigne sur le contact</translation>
@@ -1421,18 +1477,10 @@ Too many attempts with bad password</source>
         <source>Manage &amp;ignored</source>
         <translation>Administre les &amp;ignore</translation>
     </message>
-    <message>
-        <source>&amp;Configuration</source>
-        <translation>&amp;Configuration</translation>
-    </message>
     <message>
         <source>Personal information</source>
         <translation>Données personnelles</translation>
     </message>
-    <message>
-        <source>&amp;Add user</source>
-        <translation>&amp;Ajoute contact</translation>
-    </message>
     <message>
         <source>H&amp;elp</source>
         <translation>&amp;Aide</translation>
@@ -1445,10 +1493,6 @@ Too many attempts with bad password</source>
         <source>&amp;Hide Kadu</source>
         <translation>&amp;Cache Kadu</translation>
     </message>
-    <message>
-        <source>&amp;Kadu</source>
-        <translation>&amp;Menu</translation>
-    </message>
     <message>
         <source>Private</source>
         <translation>Uniquement pour les amis</translation>
@@ -1459,11 +1503,9 @@ Too many attempts with bad password</source>
     </message>
     <message>
         <source>Selected users:
-%0
-will be deleted. Are you sure?</source>
+%0will be deleted. Are you sure?</source>
         <translation>Les contacts choisis:
-%0
-serons effacés.Veuillez confirmer?</translation>
+%0serons effacés.Veuillez confirmer?</translation>
     </message>
     <message>
         <source>Hide description</source>
@@ -1473,10 +1515,6 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Search user in directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Search user in directory</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Copy description</source>
         <translation type="unfinished"></translation>
@@ -1497,10 +1535,6 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Open description link in browser</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>User management</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Write email message</source>
         <translation type="unfinished"></translation>
@@ -1509,14 +1543,6 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Search in directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ignore</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Block</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation type="unfinished">Efface</translation>
@@ -1549,10 +1575,6 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Recent chats...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Open chat with...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>No closed chats found</source>
         <translation type="unfinished"></translation>
@@ -1565,6 +1587,49 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Me</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Change status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online</source>
+        <translation type="unfinished">En ligne</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation type="unfinished">En ligne avec description</translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation type="unfinished">Je reviens toute suite</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation type="unfinished">Je reviens toute suite avec description</translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation type="unfinished">Invisible</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation type="unfinished">Invisible (description.)</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation type="unfinished">Hors ligne ( avec description.)</translation>
+    </message>
+</context>
+<context>
+    <name>KaduMainWindow</name>
+    <message>
+        <source>Create new toolbar</source>
+        <translation type="unfinished">Créez un nouveau barre d&apos;outil</translation>
+    </message>
 </context>
 <context>
     <name>KaduTabBar</name>
@@ -1587,14 +1652,6 @@ serons effacés.Veuillez confirmer?</translation>
 </context>
 <context>
     <name>KaduTextBrowser</name>
-    <message>
-        <source>Copy link &amp;location</source>
-        <translation>Veuillez copier l&apos;adresse du &amp;lien</translation>
-    </message>
-    <message>
-        <source>&amp;Save image...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save image</source>
         <translation type="unfinished"></translation>
@@ -1607,6 +1664,22 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Cannot save image: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainConfigurationWindow</name>
@@ -1672,10 +1745,6 @@ serons effacés.Veuillez confirmer?</translation>
         <source>Loaded</source>
         <translation>Chargé</translation>
     </message>
-    <message>
-        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption. You can load (or unload) them by double-clicking on their names.</source>
-        <translation>Cette zone de dialogue vous permet de contrôler les modules installés. Les modules sont responsables de nombreux dispositifs essentiels comme jouer les sons ou le criptage de message. Vous pouvez les activer (ou désactiver) par un double-clique sur leurs noms.Le module statique est impossible à désactiver.</translation>
-    </message>
     <message>
         <source>Module name</source>
         <translation>Nom de module</translation>
@@ -1716,6 +1785,11 @@ serons effacés.Veuillez confirmer?</translation>
         <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
+You can load (or unload) them by double-clicking on their names.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModulesManager</name>
@@ -1804,10 +1878,6 @@ Peut être module incompatible avec Kadu.</translation>
         <source>Remove</source>
         <translation type="unfinished">Efface</translation>
     </message>
-    <message>
-        <source>Choose</source>
-        <translation type="unfinished">Selection</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation type="unfinished">OK</translation>
@@ -1888,13 +1958,6 @@ Peut être module incompatible avec Kadu.</translation>
         <translation>&amp;Ferme</translation>
     </message>
 </context>
-<context>
-    <name>PixmapPreview</name>
-    <message>
-        <source>This is not an image</source>
-        <translation>Ceci n&apos;est pas l&apos;image</translation>
-    </message>
-</context>
 <context>
     <name>SearchDialog</name>
     <message>
@@ -2024,6 +2087,14 @@ Peut être module incompatible avec Kadu.</translation>
         <source>Insert image</source>
         <translation type="unfinished">Insère l&apos;image</translation>
     </message>
+    <message>
+        <source>Select File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SelectFont</name>
@@ -2086,13 +2157,6 @@ Peut être module incompatible avec Kadu.</translation>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>Themes</name>
-    <message>
-        <source>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;does not contain any theme configuration file</source>
-        <translation>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;nie zawiera pliku konfiguracyjnego do zestawu</translation>
-    </message>
-</context>
 <context>
     <name>TokenDialog</name>
     <message>
@@ -2122,10 +2186,6 @@ Peut être module incompatible avec Kadu.</translation>
         <source>Add new button</source>
         <translation>Ajoutez le nouveau bouton</translation>
     </message>
-    <message>
-        <source>Panel menu</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove toolbar?</source>
         <translation type="unfinished"></translation>
@@ -2134,19 +2194,20 @@ Peut être module incompatible avec Kadu.</translation>
         <source>No items to add found</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>ToolButton</name>
-    <message>
-        <source>Delete button</source>
-        <translation>Effassez le bouton</translation>
-    </message>
     <message>
         <source>Show text label</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Toolbar menu</source>
+        <source>Delete button</source>
+        <translation type="unfinished">Effassez le bouton</translation>
+    </message>
+    <message>
+        <source>Create new toolbar</source>
+        <translation type="unfinished">Créez un nouveau barre d&apos;outil</translation>
+    </message>
+    <message>
+        <source>Block toolbars</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -2179,6 +2240,10 @@ Peut être module incompatible avec Kadu.</translation>
         <source>Nicks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>User management</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UserInfo</name>
@@ -2322,6 +2387,38 @@ Peut être module incompatible avec Kadu.</translation>
         <source>User known as %1 with that UIN is already in userlist.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Online</source>
+        <translation>En ligne</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation>En ligne avec description</translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation>Je reviens toute suite</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation>Je reviens toute suite avec description</translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation>Invisible</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation>Invisible (description.)</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation>Hors ligne</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation>Hors ligne ( avec description.)</translation>
+    </message>
 </context>
 <context>
     <name>UserStatus</name>
