@@ -79,6 +79,22 @@ E un rischio per la sicurezza!</translation>
         <source>%1 weeks and %2 days ago at </source>
         <translation>%1 settimane e %2 giorni fa</translation>
     </message>
+    <message>
+        <source>%1 weeks and day ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week and day ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>week and %2 days ago at </source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>d MMMM yyyy at </source>
         <translation>d MMMM yyyy alle</translation>
@@ -429,20 +445,36 @@ E un rischio per la sicurezza!</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation>Accessibile</translation>
+        <translation type="unfinished">Accessibile</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation type="unfinished">AAccessibile(desc)</translation>
     </message>
     <message>
         <source>Busy</source>
         <translation>Occupato</translation>
     </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation type="unfinished">Occupato (desc.)</translation>
+    </message>
     <message>
         <source>Invisible</source>
         <translation>Invisibile</translation>
     </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation type="unfinished">Invisibile(desc.)</translation>
+    </message>
     <message>
         <source>Offline</source>
         <translation>Fuori linea</translation>
     </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation type="unfinished">Fuori linea(desc)</translation>
+    </message>
     <message>
         <source>On startup, set last description</source>
         <translation>Quando avviare, ispristina l&apos;ultimo status</translation>
@@ -1024,6 +1056,26 @@ E un rischio per la sicurezza!</translation>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start on startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically start on system startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>About</name>
@@ -1125,14 +1177,6 @@ E un rischio per la sicurezza!</translation>
         <source>Leave conference</source>
         <translation>Esci la conferenza</translation>
     </message>
-    <message>
-        <source>Edit window:</source>
-        <translation>Testo da inviare:</translation>
-    </message>
-    <message>
-        <source>This is where you type in the text to be sent</source>
-        <translation>Inserisci qui il testo del messaggio da spedire</translation>
-    </message>
     <message>
         <source>Insert image</source>
         <translation>Inserisci immagine</translation>
@@ -1228,22 +1272,38 @@ from now on. Are you sure you want to leave this conference?</source>
     </message>
 </context>
 <context>
-    <name>DockArea</name>
+    <name>CustomInput</name>
     <message>
-        <source>Create new toolbar</source>
-        <translation>Crea nuovo toolbar</translation>
+        <source>Undo</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Block toolbars</source>
-        <translation>Blocca toolbars</translation>
+        <source>Redo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select All</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>GaduFormater</name>
-    <message>
-        <source>###TOO MANY IMAGES###</source>
-        <translation>###PIU TROPPO IMAGINI###</translation>
-    </message>
     <message>
         <source>###IMAGE BLOCKED###</source>
         <translation>###IMAGINE BLOCCATA###</translation>
@@ -1411,10 +1471,6 @@ Di più conessioni con il password incorretto</translation>
         <source>&amp;Exit Kadu</source>
         <translation>&amp;Termina Kadu</translation>
     </message>
-    <message>
-        <source>Open chat window</source>
-        <translation>Apri finestra di Chat</translation>
-    </message>
     <message>
         <source>Notify about user</source>
         <translation>Notifica contatto</translation>
@@ -1427,18 +1483,10 @@ Di più conessioni con il password incorretto</translation>
         <source>Manage &amp;ignored</source>
         <translation>Gestione contatti &amp;ignorati</translation>
     </message>
-    <message>
-        <source>&amp;Configuration</source>
-        <translation>&amp;Configurazione</translation>
-    </message>
     <message>
         <source>Personal information</source>
         <translation>Informazioni personali</translation>
     </message>
-    <message>
-        <source>&amp;Add user</source>
-        <translation>&amp;Aggiungi un contatto</translation>
-    </message>
     <message>
         <source>H&amp;elp</source>
         <translation>Ai&amp;uto</translation>
@@ -1451,10 +1499,6 @@ Di più conessioni con il password incorretto</translation>
         <source>&amp;Hide Kadu</source>
         <translation>&amp;Nascondi Kadu</translation>
     </message>
-    <message>
-        <source>&amp;Kadu</source>
-        <translation>&amp;Menu</translation>
-    </message>
     <message>
         <source>Private</source>
         <translation>Riservato</translation>
@@ -1477,10 +1521,6 @@ Di più conessioni con il password incorretto</translation>
         <source>Search user in directory</source>
         <translation>Cerca contatto nella cartella</translation>
     </message>
-    <message>
-        <source>&amp;Search user in directory</source>
-        <translation>&amp;Cerca contatto nella cartella</translation>
-    </message>
     <message>
         <source>Copy description</source>
         <translation>Copia il descrizione</translation>
@@ -1505,10 +1545,6 @@ Di più conessioni con il password incorretto</translation>
         <source>Open description link in browser</source>
         <translation>Apri la descrizione link nel WEB browser</translation>
     </message>
-    <message>
-        <source>User management</source>
-        <translation>Configurazione degli utenti</translation>
-    </message>
     <message>
         <source>Write email message</source>
         <translation>Scrivo email</translation>
@@ -1517,14 +1553,6 @@ Di più conessioni con il password incorretto</translation>
         <source>Search in directory</source>
         <translation>Cerca nella cartella</translation>
     </message>
-    <message>
-        <source>Ignore</source>
-        <translation>Ignora</translation>
-    </message>
-    <message>
-        <source>Block</source>
-        <translation>Bloccare</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Elimina</translation>
@@ -1557,10 +1585,6 @@ Di più conessioni con il password incorretto</translation>
         <source>Recent chats...</source>
         <translation>Ultimi chat...</translation>
     </message>
-    <message>
-        <source>&amp;Open chat with...</source>
-        <translation>Apri finestra di Chat c&amp;on...</translation>
-    </message>
     <message>
         <source>No closed chats found</source>
         <translation>Non trovato i chiusi chat</translation>
@@ -1577,6 +1601,45 @@ Di più conessioni con il password incorretto</translation>
         <source>Change status</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online</source>
+        <translation type="unfinished">Accessibile</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation type="unfinished">AAccessibile(desc)</translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation type="unfinished">Occupato</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation type="unfinished">Occupato (desc.)</translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation type="unfinished">Invisibile</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation type="unfinished">Invisibile(desc.)</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation type="unfinished">Fuori linea(desc)</translation>
+    </message>
+</context>
+<context>
+    <name>KaduMainWindow</name>
+    <message>
+        <source>Create new toolbar</source>
+        <translation type="unfinished">Crea nuovo toolbar</translation>
+    </message>
 </context>
 <context>
     <name>KaduTabBar</name>
@@ -1599,14 +1662,6 @@ Di più conessioni con il password incorretto</translation>
 </context>
 <context>
     <name>KaduTextBrowser</name>
-    <message>
-        <source>Copy link &amp;location</source>
-        <translation>Copy link &amp;location</translation>
-    </message>
-    <message>
-        <source>&amp;Save image...</source>
-        <translation>&amp;Salva immaggine...</translation>
-    </message>
     <message>
         <source>Save image</source>
         <translation>Salva immaggine</translation>
@@ -1619,6 +1674,22 @@ Di più conessioni con il password incorretto</translation>
         <source>Cannot save image: %1</source>
         <translation>Non posso salvare immaggine: %1</translation>
     </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainConfigurationWindow</name>
@@ -1684,10 +1755,6 @@ Di più conessioni con il password incorretto</translation>
         <source>Loaded</source>
         <translation>Caricato</translation>
     </message>
-    <message>
-        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption. You can load (or unload) them by double-clicking on their names.</source>
-        <translation>Questa finestra di dialogo permette amministrazione dei moduli installati.  Questi moduli servono per svolgere moltitudine funzioni come riproduzione suoni o cifratura messaggi. Se vuoi attivare (o disattivare) modulo, basta cliccare due volte sul suo nome. I moduli statici non possono essere disattivati.</translation>
-    </message>
     <message>
         <source>Module name</source>
         <translation>Nome del modulo</translation>
@@ -1728,6 +1795,11 @@ Di più conessioni con il password incorretto</translation>
         <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
         <translation>&lt;b&gt;Modulo:&lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Dipende da:&lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Va in conflitto con:&lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Fornisce:&lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Autore:&lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Versione:&lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Descrizione:&lt;/b&gt;%7</translation>
     </message>
+    <message>
+        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
+You can load (or unload) them by double-clicking on their names.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModulesManager</name>
@@ -1816,10 +1888,6 @@ Possibile incompatibilità con Kadu.</translation>
         <source>Remove</source>
         <translation>Rimuovi</translation>
     </message>
-    <message>
-        <source>Choose</source>
-        <translation>Sciegli</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -1900,13 +1968,6 @@ Possibile incompatibilità con Kadu.</translation>
         <translation>&amp;Chiudi</translation>
     </message>
 </context>
-<context>
-    <name>PixmapPreview</name>
-    <message>
-        <source>This is not an image</source>
-        <translation>Questo non è un immagine</translation>
-    </message>
-</context>
 <context>
     <name>SearchDialog</name>
     <message>
@@ -2036,6 +2097,14 @@ Possibile incompatibilità con Kadu.</translation>
         <source>Insert image</source>
         <translation>Inserisci immagine</translation>
     </message>
+    <message>
+        <source>Select File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SelectFont</name>
@@ -2098,13 +2167,6 @@ Possibile incompatibilità con Kadu.</translation>
         <translation>Salva come...</translation>
     </message>
 </context>
-<context>
-    <name>Themes</name>
-    <message>
-        <source>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;does not contain any theme configuration file</source>
-        <translation>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;non contiene file di configurazione thema</translation>
-    </message>
-</context>
 <context>
     <name>TokenDialog</name>
     <message>
@@ -2134,10 +2196,6 @@ Possibile incompatibilità con Kadu.</translation>
         <source>Add new button</source>
         <translation>Aggiungi nuovo bottone</translation>
     </message>
-    <message>
-        <source>Panel menu</source>
-        <translation>Panel menu</translation>
-    </message>
     <message>
         <source>Remove toolbar?</source>
         <translation>Rimuovi il toolbar?</translation>
@@ -2146,20 +2204,21 @@ Possibile incompatibilità con Kadu.</translation>
         <source>No items to add found</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>ToolButton</name>
-    <message>
-        <source>Delete button</source>
-        <translation>Elimina bottone</translation>
-    </message>
     <message>
         <source>Show text label</source>
-        <translation>Mostra testo</translation>
+        <translation type="unfinished">Mostra testo</translation>
     </message>
     <message>
-        <source>Toolbar menu</source>
-        <translation>Toolbar menu</translation>
+        <source>Delete button</source>
+        <translation type="unfinished">Elimina bottone</translation>
+    </message>
+    <message>
+        <source>Create new toolbar</source>
+        <translation type="unfinished">Crea nuovo toolbar</translation>
+    </message>
+    <message>
+        <source>Block toolbars</source>
+        <translation type="unfinished">Blocca toolbars</translation>
     </message>
 </context>
 <context>
@@ -2191,6 +2250,10 @@ Possibile incompatibilità con Kadu.</translation>
         <source>Nicks</source>
         <translation>Sopranomi (nick)</translation>
     </message>
+    <message>
+        <source>User management</source>
+        <translation type="unfinished">Configurazione degli utenti</translation>
+    </message>
 </context>
 <context>
     <name>UserInfo</name>
@@ -2334,6 +2397,38 @@ Possibile incompatibilità con Kadu.</translation>
         <source>User known as %1 with that UIN is already in userlist.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Online</source>
+        <translation>Accessibile</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation>AAccessibile(desc)</translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation>Occupato</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation>Occupato (desc.)</translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation>Invisibile</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation>Invisibile(desc.)</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation>Fuori linea</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation>Fuori linea(desc)</translation>
+    </message>
 </context>
 <context>
     <name>UserStatus</name>
