@@ -1,4 +1,5 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS><TS version="1.1" language="pl">
 <defaultcodec></defaultcodec>
 <context>
     <name>@default</name>
@@ -74,11 +75,27 @@ Jest to wysoce ryzykowne!</translation>
     </message>
     <message>
         <source>%1 weeks ago at </source>
-        <translation>%1 tygodni temu o  </translation>
+        <translation>%1 tygodnie temu o </translation>
+    </message>
+    <message>
+        <source>%1 weeks and day ago at </source>
+        <translation>%1 tygodnie i jeden dzień temu o </translation>
     </message>
     <message>
         <source>%1 weeks and %2 days ago at </source>
-        <translation>%1 tydzień i %2 dni temu o </translation>
+        <translation>%1 tygodnie %2 dni temu o </translation>
+    </message>
+    <message>
+        <source>week ago at </source>
+        <translation>Tydzień temu o </translation>
+    </message>
+    <message>
+        <source>week and day ago at </source>
+        <translation>Tydzień i jeden dzień temu o </translation>
+    </message>
+    <message>
+        <source>week and %2 days ago at </source>
+        <translation>Tydzień i %2 dni temu o </translation>
     </message>
     <message>
         <source>d MMMM yyyy at </source>
@@ -432,14 +449,30 @@ Jest to wysoce ryzykowne!</translation>
         <source>Online</source>
         <translation>Dostępny</translation>
     </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation>Dostępny z opisem</translation>
+    </message>
     <message>
         <source>Busy</source>
         <translation>Zajęty</translation>
     </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation>Zajęty z opisem</translation>
+    </message>
     <message>
         <source>Invisible</source>
         <translation>Ukryty</translation>
     </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation>Ukryty z opisem</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation>Niedostępny z opisem</translation>
+    </message>
     <message>
         <source>Offline</source>
         <translation>Niedostępny</translation>
@@ -1036,6 +1069,26 @@ Jest to wysoce ryzykowne!</translation>
 &lt;kadu:header&gt;tekst&lt;/kadu:header&gt; - tekst nie będzie wyswietlany w trybie &apos;Usuń powtarzające się nagłówki&quot;
 </translation>
     </message>
+    <message>
+        <source>Startup</source>
+        <translation>Autostart</translation>
+    </message>
+    <message>
+        <source>Start on startup</source>
+        <translation>Uruchamiaj przy starcie systemu</translation>
+    </message>
+    <message>
+        <source>Automatically start on system startup</source>
+        <translation>Automatycznie uruchamia Kadu kiedy system startuje</translation>
+    </message>
+    <message>
+        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
+        <translation>Wyświetla tekst od anonimów bez formatowania (kolory, obrazki, czcionka).</translation>
+    </message>
+    <message>
+        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
+        <translation>Wyświetla daty w eleganckim formacie, na przykład: Dzisiaj, Wczoraj, Piątek</translation>
+    </message>
 </context>
 <context>
     <name>About</name>
@@ -1137,14 +1190,6 @@ Jest to wysoce ryzykowne!</translation>
         <source>Leave conference</source>
         <translation>Opuść konferencję</translation>
     </message>
-    <message>
-        <source>Edit window:</source>
-        <translation>Okno edycji:</translation>
-    </message>
-    <message>
-        <source>This is where you type in the text to be sent</source>
-        <translation>Tutaj wpisujesz tekst do wysłania</translation>
-    </message>
     <message>
         <source>Insert image</source>
         <translation>Wstaw obraz</translation>
@@ -1242,22 +1287,38 @@ Na pewno chcesz opuścić tę konferencję?</translation>
     </message>
 </context>
 <context>
-    <name>DockArea</name>
+    <name>CustomInput</name>
     <message>
-        <source>Create new toolbar</source>
-        <translation>Utwórz nowy pasek narzędziowy</translation>
+        <source>Undo</source>
+        <translation>Cofnij</translation>
     </message>
     <message>
-        <source>Block toolbars</source>
-        <translation>Blokuj paski narzędziowe</translation>
+        <source>Redo</source>
+        <translation>Ponów</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Wytnij</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation>Kopiuj</translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation>Wklej</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Wyczyść</translation>
+    </message>
+    <message>
+        <source>Select All</source>
+        <translation>Zaznacz wszystko</translation>
     </message>
 </context>
 <context>
     <name>GaduFormater</name>
-    <message>
-        <source>###TOO MANY IMAGES###</source>
-        <translation>###ZBYT DUŻO OBRAZKÓW###</translation>
-    </message>
     <message>
         <source>###IMAGE BLOCKED###</source>
         <translation>###ZDJĘCIE ZABLOKOWANE###</translation>
@@ -1425,10 +1486,6 @@ Zbyt wiele prób połączeń z niepoprawnym hasłem</translation>
         <source>&amp;Exit Kadu</source>
         <translation>&amp;Zakończ Kadu</translation>
     </message>
-    <message>
-        <source>Open chat window</source>
-        <translation>Rozpocznij rozmowę</translation>
-    </message>
     <message>
         <source>Notify about user</source>
         <translation>Powiadom o kontakcie</translation>
@@ -1441,18 +1498,10 @@ Zbyt wiele prób połączeń z niepoprawnym hasłem</translation>
         <source>Manage &amp;ignored</source>
         <translation>Zarządzaj i&amp;gnorowanymi</translation>
     </message>
-    <message>
-        <source>&amp;Configuration</source>
-        <translation>&amp;Konfiguracja</translation>
-    </message>
     <message>
         <source>Personal information</source>
         <translation>Dane osobiste</translation>
     </message>
-    <message>
-        <source>&amp;Add user</source>
-        <translation>&amp;Dodaj kontakt</translation>
-    </message>
     <message>
         <source>H&amp;elp</source>
         <translation>&amp;Pomoc</translation>
@@ -1465,10 +1514,6 @@ Zbyt wiele prób połączeń z niepoprawnym hasłem</translation>
         <source>&amp;Hide Kadu</source>
         <translation>Uk&amp;ryj Kadu</translation>
     </message>
-    <message>
-        <source>&amp;Kadu</source>
-        <translation>&amp;Menu</translation>
-    </message>
     <message>
         <source>Private</source>
         <translation>Tylko dla znajomych</translation>
@@ -1492,14 +1537,6 @@ Czy na pewno tego chcesz?</translation>
         <source>Search user in directory</source>
         <translation>Znajdź kontakt w katalogu</translation>
     </message>
-    <message>
-        <source>&amp;Search user in directory</source>
-        <translation>Zna&amp;jdź kontakt w katalogu</translation>
-    </message>
-    <message>
-        <source>User management</source>
-        <translation>Zarządzanie kontaktami</translation>
-    </message>
     <message>
         <source>Copy description</source>
         <translation>Kopiuj opis</translation>
@@ -1532,14 +1569,6 @@ Czy na pewno tego chcesz?</translation>
         <source>Search in directory</source>
         <translation>Znajdź w katalogu</translation>
     </message>
-    <message>
-        <source>Ignore</source>
-        <translation>Ignoruj</translation>
-    </message>
-    <message>
-        <source>Block</source>
-        <translation>Blokuj</translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation>Usuń</translation>
@@ -1572,10 +1601,6 @@ Czy na pewno tego chcesz?</translation>
         <source>Recent chats...</source>
         <translation>Ostatnie rozmowy...</translation>
     </message>
-    <message>
-        <source>&amp;Open chat with...</source>
-        <translation>&amp;Rozpocznij rozmowę z ...</translation>
-    </message>
     <message>
         <source>No closed chats found</source>
         <translation>Brak zamkniętych rozmów</translation>
@@ -1592,6 +1617,45 @@ Czy na pewno tego chcesz?</translation>
         <source>Change status</source>
         <translation>Zmiana statusu</translation>
     </message>
+    <message>
+        <source>Menu</source>
+        <translation>Menu</translation>
+    </message>
+    <message>
+        <source>Online</source>
+        <translation>Dostępny</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation>Dostępny z opisem</translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation>Zajęty</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation>Zajęty z opisem</translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation>Ukryty</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation>Ukryty z opisem</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation>Niedostępny z opisem</translation>
+    </message>
+</context>
+<context>
+    <name>KaduMainWindow</name>
+    <message>
+        <source>Create new toolbar</source>
+        <translation>Utwórz nowy pasek narzędziowy</translation>
+    </message>
 </context>
 <context>
     <name>KaduTabBar</name>
@@ -1614,14 +1678,6 @@ Czy na pewno tego chcesz?</translation>
 </context>
 <context>
     <name>KaduTextBrowser</name>
-    <message>
-        <source>Copy link &amp;location</source>
-        <translation>Kopiuj &amp;adres odnośnika</translation>
-    </message>
-    <message>
-        <source>&amp;Save image...</source>
-        <translation>&amp;Zapisz obrazek...</translation>
-    </message>
     <message>
         <source>Save image</source>
         <translation>Zapisz obrazek</translation>
@@ -1634,6 +1690,22 @@ Czy na pewno tego chcesz?</translation>
         <source>Cannot save image: %1</source>
         <translation>Nie można zapisać obrazka: %1</translation>
     </message>
+    <message>
+        <source>Copy</source>
+        <translation>Kopiuj</translation>
+    </message>
+    <message>
+        <source>Copy Link</source>
+        <translation>Kopiuj link</translation>
+    </message>
+    <message>
+        <source>Copy Image</source>
+        <translation>Kopiuj obrazek</translation>
+    </message>
+    <message>
+        <source>Save Image</source>
+        <translation>Zapisz obrazek</translation>
+    </message>
 </context>
 <context>
     <name>MainConfigurationWindow</name>
@@ -1699,10 +1771,6 @@ Czy na pewno tego chcesz?</translation>
         <source>Loaded</source>
         <translation>Załadowany</translation>
     </message>
-    <message>
-        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption. You can load (or unload) them by double-clicking on their names.</source>
-        <translation>To okno dialogowe daje możliwość zarządzania zainstalowanymi modułami. Moduły są odpowiedzialne za wiele funkcji takich jak odtwarzanie dźwięków lub szyfrowanie wiadomości. Jeśli zechcesz włączyć (lub wyłączyć) któryś z nich, wystarczy dwukrotnie kliknąć na jego nazwie. Modułu statycznego nie można wyłączyć.</translation>
-    </message>
     <message>
         <source>Module name</source>
         <translation>Nazwa modułu</translation>
@@ -1743,6 +1811,12 @@ Czy na pewno tego chcesz?</translation>
         <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
         <translation>&lt;b&gt;Moduł: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Wymaga: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Konflikt z: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Dostarcza: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Autor: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Wersja: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Opis: &lt;/b&gt;%7</translation>
     </message>
+    <message>
+        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
+You can load (or unload) them by double-clicking on their names.</source>
+        <translation>To okno dialogowe daje możliwość zarządzania zainstalowanymi modułąmi. Moduły są odpowiedzialne za wiele funkcji takich jak odtwarzanie dźwięków lub szyfrowanie wiadomości.
+Jeśli zechcesz włączyć (lub wyłączyć) któryś z nich, wystarczy dwukrotnie kliknąć na jego nazwie. Modułu statycznego nie można wyłączyć.</translation>
+    </message>
 </context>
 <context>
     <name>ModulesManager</name>
@@ -1831,10 +1905,6 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <source>Remove</source>
         <translation>Usuń</translation>
     </message>
-    <message>
-        <source>Choose</source>
-        <translation>Wybierz</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -1915,13 +1985,6 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <translation>&amp;Zamknij</translation>
     </message>
 </context>
-<context>
-    <name>PixmapPreview</name>
-    <message>
-        <source>This is not an image</source>
-        <translation>To nie jest obrazek</translation>
-    </message>
-</context>
 <context>
     <name>SearchDialog</name>
     <message>
@@ -2051,6 +2114,14 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <source>Insert image</source>
         <translation>Wstaw obraz</translation>
     </message>
+    <message>
+        <source>Select File</source>
+        <translation>Wybierz plik</translation>
+    </message>
+    <message>
+        <source>Select audio File</source>
+        <translation>Wybierz plik dźwiękowy</translation>
+    </message>
 </context>
 <context>
     <name>SelectFont</name>
@@ -2113,13 +2184,6 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <translation>Zapisz jako...</translation>
     </message>
 </context>
-<context>
-    <name>Themes</name>
-    <message>
-        <source>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;does not contain any theme configuration file</source>
-        <translation>&lt;i&gt;%1&lt;/i&gt;&lt;br/&gt;nie zawiera pliku konfiguracyjnego do zestawu</translation>
-    </message>
-</context>
 <context>
     <name>TokenDialog</name>
     <message>
@@ -2149,10 +2213,6 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <source>Add new button</source>
         <translation>Dodaj nowy przycisk</translation>
     </message>
-    <message>
-        <source>Panel menu</source>
-        <translation>Menu paska narzędziowego</translation>
-    </message>
     <message>
         <source>Remove toolbar?</source>
         <translation>Usunąć pasek narzędziowy?</translation>
@@ -2161,20 +2221,21 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <source>No items to add found</source>
         <translation>Nie znaleziono elementów do dodania</translation>
     </message>
-</context>
-<context>
-    <name>ToolButton</name>
-    <message>
-        <source>Delete button</source>
-        <translation>Usuń przycisk</translation>
-    </message>
     <message>
         <source>Show text label</source>
         <translation>Etykieta tekstowa</translation>
     </message>
     <message>
-        <source>Toolbar menu</source>
-        <translation>Menu paska narzędziowego</translation>
+        <source>Delete button</source>
+        <translation>Usuń przycisk</translation>
+    </message>
+    <message>
+        <source>Create new toolbar</source>
+        <translation>Utwórz nowy pasek narzędziowy</translation>
+    </message>
+    <message>
+        <source>Block toolbars</source>
+        <translation>Blokuj paski narzędziowe</translation>
     </message>
 </context>
 <context>
@@ -2206,6 +2267,10 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <source>Nicks</source>
         <translation>Pseudonimy</translation>
     </message>
+    <message>
+        <source>User management</source>
+        <translation>Zarządzanie kontaktami</translation>
+    </message>
 </context>
 <context>
     <name>UserInfo</name>
@@ -2349,6 +2414,38 @@ Być może nie jest to moduł kompatybilny z Kadu.</translation>
         <source>Icon:</source>
         <translation>Ikona:</translation>
     </message>
+    <message>
+        <source>Online</source>
+        <translation>Dostępny</translation>
+    </message>
+    <message>
+        <source>Online (d.)</source>
+        <translation>Dostępny z opisem</translation>
+    </message>
+    <message>
+        <source>Busy</source>
+        <translation>Zajęty</translation>
+    </message>
+    <message>
+        <source>Busy (d.)</source>
+        <translation>Zajęty z opisem</translation>
+    </message>
+    <message>
+        <source>Invisible</source>
+        <translation>Ukryty</translation>
+    </message>
+    <message>
+        <source>Invisible (d.)</source>
+        <translation>Ukryty z opisem</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation>Niedostępny</translation>
+    </message>
+    <message>
+        <source>Offline (d.)</source>
+        <translation>Niedostępny z opisem</translation>
+    </message>
 </context>
 <context>
     <name>UserStatus</name>
